!+
      SUBROUTINE DRYAIR
! ---------------------------------------------------------------------------
! PURPOSE - Load common block /FLUDPC/
!.....AIR TABLES FOR FLUID SUBPROGRAM.
                                                                        

!      WRITTEN BY: THEODORE E. FESSLER, NASA TM X-3572, AUGUST 1977     
!      REWRITTEN BY: LT. MARK D. KLEM & MARGARET P. PROCTOR, JANUARY 198
!                                                                       
!      THE ORIGINAL PROGRAM WAS WRITTEN IN SFTRAN, BUT THIS PROGRAM IS  
!      REWRITTEN IN STANDARD FORTRAN 77 TO RUN PRIMARILY ON PERSONAL    
!      COMPUTERS AND CAN ALSO RUN ON MAINFRAMES. MUCH OF THE OLD CODE WA
!      COMMENTED OUT BUT LEFT INTACT FOR DOCUMENTATION AND REFERENCE    
!      PURPOSES.                                                        
!                                                                       

  INTERFACE
    SUBROUTINE Fluid(T,P,RHO,PROPS,NP,ENTRY,VAPOR,ERROR,igoto)
      REAL,INTENT(IN OUT):: t
      REAL,INTENT(IN OUT):: p
      REAL,INTENT(IN OUT):: rho
      REAL,INTENT(OUT),DIMENSION(:):: props
      INTEGER,INTENT(IN):: np
      INTEGER,INTENT(IN):: entry
      LOGICAL,INTENT(OUT):: vapor
      INTEGER,INTENT(OUT):: error
      INTEGER,INTENT(IN):: igoto
    END Subroutine Fluid
  END INTERFACE


!                -- UNITS --
                                                                        
!       R = 0.28722 JOULES / GRAM - DEG. K      C(1)                    
!       TCRIT = 132.52 DEG. K                   C(2)                    
!       PCRIT = 3.766 MEGA-NEWTONS / METER**2   C(3)                    
!       DCRIT = 0.3130 GRAMS / CENTIMETER**3    C(4)                    
!       VISCOSITY = GRAMS / CENTIMETER - SEC.        PROP(7)            
!       CONDUCTIVITY = WATTS / CENTIMETER - DEG. K   PROP(8)            
                                                                        
                                                                        
!.....IMPLEMENTATION OF THE AIR PROPERTIES PRESENTED IN:                
                                                                        
!     DIE THERMODYNAMISCHEN EIGENSCHAFTEN DER LUFT  --                  
!       IM TEMPERATURBEREICH ZWISCHEN -210 DEG. C AND                   
!       +1250 DEG. C BIS ZU DRUCKEN VON 4500 BAR.                       
                                                                        
!           BY H. D. BAEHR AND K. SCHWIER (1961)                        
                                                                        
                                                                        
!.....THIS TABLE COVERS 150 TO 1500 DEG. K, UP TO 0.6 GRAMS/CM**3.      
                                                                        
                                                                        
!********************************************************************** 
      REAL G(29,4),TT(27),DD(30),GG(27,30,8),SAT(40,8),C(8)
      INTEGER M(4)
       INTEGER ERROR,ENTRY 
       DIMENSION PROPS(8) 
       LOGICAL VAPOR 
!********************************************************************** 
                                                                        
      DIMENSION X0001(100),X0101(100),X0201(100),X0301(100),X0401(100), &
     &          X0501(100),X0601(100),X0701(100),X0801(100),X0901(100), &
     &          X1001(100),X1101(100),X1201(100),X1301(100),X1401(100), &
     &          X1501(87)                                               
                                                                        
      DIMENSION Z(1587) 
!********************************************************************** 
       COMMON /FLUDPC/ G,TT,DD,GG,SAT,C,M,NG,N1,N2,N3,NS 
!********************************************************************** 
      EQUIVALENCE (X0001,Z(0001)), (X0101,Z(0101)), (X0201,Z(0201)),    &
     &            (X0301,Z(0301)), (X0401,Z(0401)), (X0501,Z(0501)),    &
     &            (X0601,Z(0601)), (X0701,Z(0701)), (X0801,Z(0801)),    &
     &            (X0901,Z(0901)), (X1001,Z(1001)), (X1101,Z(1101)),    &
     &            (X1201,Z(1201)), (X1301,Z(1301)), (X1401,Z(1401)),    &
     &            (X1501,Z(1501))                                       
                                                                        
!********************************************************************** 

!********************************************************************** 
                                                                        
      DATA X0001/ 1.1300E+0, 1.2000E+0, 1.5000E+0, 1.9000E+0, 2.4000E+0,&
     & 3.1000E+0, 3.9000E+0, 5.0000E+0, 6.3000E+0, 8.0000E+0, 1.0000E+1,&
     & 1.1300E+1, 1.6892E+1, 1.7042E+1, 1.7598E+1, 1.8188E+1, 1.8778E+1,&
     & 1.9422E+1, 2.0011E+1, 2.0670E+1, 2.1312E+1, 2.2013E+1, 2.2701E+1,&
     & 2.3091E+1, 1.1897E+1, 1.2059E+1, 1.2751E+1, 1.3673E+1, 1.4830E+1,&
     & 1.6462E+1, 1.8365E+1, 2.1079E+1, 2.4457E+1, 2.9134E+1, 3.4934E+1,&
     & 3.8834E+1, 2.4917E+0, 2.4917E+0, 2.4920E+0, 2.4944E+0, 2.5037E+0,&
     & 2.5350E+0, 2.5979E+0, 2.7127E+0, 2.8546E+0, 3.0131E+0, 3.1502E+0,&
     & 3.2180E+0, 1.1300E+0, 1.2000E+0, 1.5000E+0, 1.9000E+0, 2.4000E+0,&
     & 3.1000E+0, 3.9000E+0, 5.0000E+0, 6.3000E+0, 8.0000E+0, 1.0000E+1,&
     & 1.1300E+1, 1.0000E-5, 3.0000E-4, 7.0000E-4, 2.0000E-3, 5.0000E-3,&
     & 1.0000E-2, 2.0000E-2, 5.0000E-2, 1.0000E-1, 2.0000E-1, 5.0000E-1,&
     & 9.0000E-1, 1.4000E+0, 1.7000E+0, 2.0000E+0, 1.1862E+0, 1.1862E+0,&
     & 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0,&
     & 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1861E+0, 1.1861E+0,&
     & 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0,&
     & 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0, 1.1859E+0 /          
      DATA X0101/ 1.1860E+0, 1.1861E+0, 1.1862E+0, 1.1862E+0, 1.1862E+0,&
     & 1.1863E+0, 1.1863E+0, 1.1863E+0, 1.1863E+0, 1.1863E+0, 1.1863E+0,&
     & 1.1854E+0, 1.1855E+0, 1.1859E+0, 1.1861E+0, 1.1862E+0, 1.1863E+0,&
     & 1.1864E+0, 1.1864E+0, 1.1864E+0, 1.1864E+0, 1.1864E+0, 1.1864E+0,&
     & 1.1842E+0, 1.1846E+0, 1.1855E+0, 1.1860E+0, 1.1863E+0, 1.1865E+0,&
     & 1.1866E+0, 1.1866E+0, 1.1867E+0, 1.1867E+0, 1.1868E+0, 1.1868E+0,&
     & 1.1822E+0, 1.1829E+0, 1.1848E+0, 1.1858E+0, 1.1864E+0, 1.1867E+0,&
     & 1.1869E+0, 1.1871E+0, 1.1872E+0, 1.1873E+0, 1.1873E+0, 1.1873E+0,&
     & 1.1784E+0, 1.1797E+0, 1.1833E+0, 1.1854E+0, 1.1866E+0, 1.1873E+0,&
     & 1.1877E+0, 1.1880E+0, 1.1882E+0, 1.1883E+0, 1.1884E+0, 1.1885E+0,&
     & 1.1674E+0, 1.1706E+0, 1.1791E+0, 1.1842E+0, 1.1872E+0, 1.1891E+0,&
     & 1.1901E+0, 1.1909E+0, 1.1914E+0, 1.1918E+0, 1.1921E+0, 1.1922E+0,&
     & 1.1509E+0, 1.1568E+0, 1.1725E+0, 1.1824E+0, 1.1884E+0, 1.1922E+0,&
     & 1.1944E+0, 1.1960E+0, 1.1970E+0, 1.1978E+0, 1.1984E+0, 1.1986E+0,&
     & 1.1239E+0, 1.1339E+0, 1.1614E+0, 1.1798E+0, 1.1915E+0, 1.1989E+0,&
     & 1.2032E+0, 1.2062E+0, 1.2081E+0, 1.2095E+0, 1.2104E+0, 1.2108E+0,&
     & 1.0723E+0, 1.0909E+0, 1.1432E+0, 1.1788E+0, 1.2021E+0 /          
      DATA X0201/ 1.2175E+0, 1.2255E+0, 1.2305E+0, 1.2329E+0, 1.2341E+0,&
     & 1.2345E+0, 1.2346E+0, 1.0494E+0, 1.0699E+0, 1.1331E+0, 1.1811E+0,&
     & 1.2129E+0, 1.2349E+0, 1.2463E+0, 1.2529E+0, 1.2557E+0, 1.2565E+0,&
     & 1.2563E+0, 1.2559E+0, 1.0280E+0, 1.0486E+0, 1.1173E+0, 1.1712E+0,&
     & 1.2069E+0, 1.2298E+0, 1.2407E+0, 1.2461E+0, 1.2475E+0, 1.2469E+0,&
     & 1.2453E+0, 1.2443E+0, 1.0017E+0, 1.0239E+0, 1.0951E+0, 1.1477E+0,&
     & 1.1789E+0, 1.1950E+0, 1.1990E+0, 1.1970E+0, 1.1921E+0, 1.1857E+0,&
     & 1.1795E+0, 1.1762E+0, 9.6214E-1, 9.8415E-1, 1.0491E+0, 1.0919E+0,&
     & 1.1122E+0, 1.1140E+0, 1.1032E+0, 1.0842E+0, 1.0639E+0, 1.0428E+0,&
     & 1.0244E+0, 1.0151E+0, 1.0001E+0, 1.0001E+0, 1.0001E+0, 1.0001E+0,&
     & 1.0001E+0, 1.0001E+0, 1.0001E+0, 1.0001E+0, 1.0001E+0, 1.0001E+0,&
     & 1.0001E+0, 1.0001E+0, 9.9998E-1, 9.9998E-1, 9.9999E-1, 9.9998E-1,&
     & 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1,&
     & 9.9999E-1, 9.9999E-1, 9.9997E-1, 9.9997E-1, 9.9998E-1, 9.9998E-1,&
     & 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9999E-1, 9.9999E-1,&
     & 9.9999E-1, 9.9998E-1, 9.9992E-1, 9.9993E-1, 9.9996E-1, 9.9997E-1,&
     & 9.9997E-1, 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9998E-1 /          
      DATA X0301/ 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9982E-1, 9.9985E-1,&
     & 9.9991E-1, 9.9994E-1, 9.9995E-1, 9.9996E-1, 9.9996E-1, 9.9997E-1,&
     & 9.9997E-1, 9.9997E-1, 9.9997E-1, 9.9997E-1, 9.9965E-1, 9.9970E-1,&
     & 9.9983E-1, 9.9989E-1, 9.9991E-1, 9.9993E-1, 9.9994E-1, 9.9994E-1,&
     & 9.9995E-1, 9.9995E-1, 9.9995E-1, 9.9995E-1, 9.9930E-1, 9.9940E-1,&
     & 9.9966E-1, 9.9979E-1, 9.9983E-1, 9.9988E-1, 9.9989E-1, 9.9990E-1,&
     & 9.9990E-1, 9.9991E-1, 9.9991E-1, 9.9991E-1, 9.9826E-1, 9.9850E-1,&
     & 9.9913E-1, 9.9945E-1, 9.9959E-1, 9.9969E-1, 9.9973E-1, 9.9975E-1,&
     & 9.9976E-1, 9.9977E-1, 9.9977E-1, 9.9978E-1, 9.9662E-1, 9.9707E-1,&
     & 9.9826E-1, 9.9886E-1, 9.9916E-1, 9.9935E-1, 9.9943E-1, 9.9948E-1,&
     & 9.9950E-1, 9.9952E-1, 9.9953E-1, 9.9954E-1, 9.9361E-1, 9.9443E-1,&
     & 9.9654E-1, 9.9761E-1, 9.9824E-1, 9.9862E-1, 9.9879E-1, 9.9888E-1,&
     & 9.9894E-1, 9.9898E-1, 9.9902E-1, 9.9903E-1, 9.8549E-1, 9.8725E-1,&
     & 9.9157E-1, 9.9384E-1, 9.9534E-1, 9.9630E-1, 9.9679E-1, 9.9712E-1,&
     & 9.9732E-1, 9.9747E-1, 9.9758E-1, 9.9763E-1, 9.7656E-1, 9.7916E-1,&
     & 9.8536E-1, 9.8895E-1, 9.9137E-1, 9.9316E-1, 9.9418E-1, 9.9490E-1,&
     & 9.9536E-1, 9.9570E-1, 9.9593E-1, 9.9604E-1, 9.6859E-1 /          
      DATA X0401/ 9.7114E-1, 9.7805E-1, 9.8284E-1, 9.8644E-1, 9.8926E-1,&
     & 9.9096E-1, 9.9221E-1, 9.9302E-1, 9.9361E-1, 9.9401E-1, 9.9420E-1,&
     & 9.6398E-1, 9.6640E-1, 9.7374E-1, 9.7947E-1, 9.8399E-1, 9.8760E-1,&
     & 9.8980E-1, 9.9141E-1, 9.9243E-1, 9.9317E-1, 9.9367E-1, 9.9389E-1,&
     & 9.5904E-1, 9.6162E-1, 9.7000E-1, 9.7705E-1, 9.8292E-1, 9.8770E-1,&
     & 9.9063E-1, 9.9277E-1, 9.9409E-1, 9.9500E-1, 9.9558E-1, 9.9582E-1,&
     & 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0005E+0, 1.0006E+0, 1.0006E+0,&
     & 1.0007E+0, 1.0008E+0, 1.0008E+0, 1.0009E+0, 1.0009E+0, 1.0009E+0,&
     & 9.9995E-1, 9.9995E-1, 9.9995E-1, 9.9995E-1, 9.9994E-1, 9.9994E-1,&
     & 9.9993E-1, 9.9993E-1, 9.9992E-1, 9.9992E-1, 9.9991E-1, 9.9991E-1,&
     & 9.9992E-1, 9.9993E-1, 9.9994E-1, 9.9994E-1, 9.9994E-1, 9.9993E-1,&
     & 9.9993E-1, 9.9992E-1, 9.9991E-1, 9.9991E-1, 9.9990E-1, 9.9990E-1,&
     & 9.9984E-1, 9.9985E-1, 9.9990E-1, 9.9992E-1, 9.9992E-1, 9.9993E-1,&
     & 9.9992E-1, 9.9991E-1, 9.9990E-1, 9.9989E-1, 9.9989E-1, 9.9988E-1,&
     & 9.9963E-1, 9.9968E-1, 9.9980E-1, 9.9987E-1, 9.9989E-1, 9.9990E-1,&
     & 9.9990E-1, 9.9988E-1, 9.9987E-1, 9.9985E-1, 9.9984E-1, 9.9984E-1,&
     & 9.9930E-1, 9.9939E-1, 9.9965E-1, 9.9979E-1, 9.9983E-1 /          
      DATA X0501/ 9.9987E-1, 9.9986E-1, 9.9984E-1, 9.9982E-1, 9.9979E-1,&
     & 9.9978E-1, 9.9977E-1, 9.9865E-1, 9.9882E-1, 9.9934E-1, 9.9962E-1,&
     & 9.9972E-1, 9.9979E-1, 9.9979E-1, 9.9975E-1, 9.9971E-1, 9.9967E-1,&
     & 9.9964E-1, 9.9962E-1, 9.9677E-1, 9.9719E-1, 9.9842E-1, 9.9910E-1,&
     & 9.9938E-1, 9.9954E-1, 9.9954E-1, 9.9947E-1, 9.9938E-1, 9.9929E-1,&
     & 9.9921E-1, 9.9918E-1, 9.9390E-1, 9.9468E-1, 9.9693E-1, 9.9816E-1,&
     & 9.9876E-1, 9.9908E-1, 9.9908E-1, 9.9895E-1, 9.9878E-1, 9.9861E-1,&
     & 9.9847E-1, 9.9840E-1, 9.8882E-1, 9.9022E-1, 9.9409E-1, 9.9617E-1,&
     & 9.9744E-1, 9.9802E-1, 9.9805E-1, 9.9782E-1, 9.9752E-1, 9.9721E-1,&
     & 9.9695E-1, 9.9682E-1, 9.7542E-1, 9.7840E-1, 9.8611E-1, 9.9029E-1,&
     & 9.9310E-1, 9.9449E-1, 9.9473E-1, 9.9442E-1, 9.9388E-1, 9.9325E-1,&
     & 9.9270E-1, 9.9243E-1, 9.6058E-1, 9.6506E-1, 9.7599E-1, 9.8225E-1,&
     & 9.8632E-1, 9.8872E-1, 9.8935E-1, 9.8904E-1, 9.8825E-1, 9.8724E-1,&
     & 9.8629E-1, 9.8581E-1, 9.4611E-1, 9.5042E-1, 9.6202E-1, 9.6968E-1,&
     & 9.7512E-1, 9.7852E-1, 9.7957E-1, 9.7929E-1, 9.7827E-1, 9.7689E-1,&
     & 9.7557E-1, 9.7489E-1, 9.3558E-1, 9.3952E-1, 9.5136E-1, 9.6021E-1,&
     & 9.6689E-1, 9.7129E-1, 9.7289E-1, 9.7291E-1, 9.7199E-1 /          
      DATA X0601/ 9.7061E-1, 9.6924E-1, 9.6852E-1, 9.2123E-1, 9.2534E-1,&
     & 9.3859E-1, 9.4931E-1, 9.5808E-1, 9.6438E-1, 9.6732E-1, 9.6843E-1,&
     & 9.6822E-1, 9.6734E-1, 9.6627E-1, 9.6566E-1, 9.9994E-1, 9.9994E-1,&
     & 9.9997E-1, 9.9999E-1, 9.9999E-1, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0001E+0, 1.0001E+0,&
     & 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0004E+0, 1.0004E+0,&
     & 1.0002E+0, 1.0001E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0013E+0, 1.0013E+0,&
     & 1.0007E+0, 1.0003E+0, 1.0002E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0033E+0, 1.0033E+0,&
     & 1.0017E+0, 1.0008E+0, 1.0005E+0, 1.0002E+0, 1.0001E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0066E+0, 1.0066E+0,&
     & 1.0035E+0, 1.0017E+0, 1.0010E+0, 1.0004E+0, 1.0002E+0, 1.0001E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0130E+0, 1.0130E+0,&
     & 1.0068E+0, 1.0033E+0, 1.0019E+0, 1.0008E+0, 1.0003E+0, 1.0001E+0,&
     & 1.0000E+0, 1.0000E+0, 9.9999E-1, 9.9999E-1, 1.0307E+0 /          
      DATA X0701/ 1.0307E+0, 1.0160E+0, 1.0076E+0, 1.0047E+0, 1.0019E+0,&
     & 1.0008E+0, 1.0003E+0, 1.0001E+0, 1.0000E+0, 9.9999E-1, 9.9999E-1,&
     & 1.0574E+0, 1.0559E+0, 1.0289E+0, 1.0136E+0, 1.0088E+0, 1.0037E+0,&
     & 1.0016E+0, 1.0006E+0, 1.0002E+0, 1.0001E+0, 1.0000E+0, 9.9999E-1,&
     & 1.1046E+0, 1.0962E+0, 1.0489E+0, 1.0229E+0, 1.0162E+0, 1.0072E+0,&
     & 1.0034E+0, 1.0014E+0, 1.0006E+0, 1.0003E+0, 1.0001E+0, 1.0001E+0,&
     & 1.2235E+0, 1.1876E+0, 1.0953E+0, 1.0462E+0, 1.0362E+0, 1.0190E+0,&
     & 1.0107E+0, 1.0057E+0, 1.0032E+0, 1.0018E+0, 1.0010E+0, 1.0008E+0,&
     & 1.3325E+0, 1.2530E+0, 1.1355E+0, 1.0733E+0, 1.0605E+0, 1.0367E+0,&
     & 1.0230E+0, 1.0136E+0, 1.0082E+0, 1.0049E+0, 1.0030E+0, 1.0023E+0,&
     & 1.2914E+0, 1.2376E+0, 1.1560E+0, 1.1015E+0, 1.0873E+0, 1.0580E+0,&
     & 1.0385E+0, 1.0238E+0, 1.0148E+0, 1.0090E+0, 1.0056E+0, 1.0044E+0,&
     & 1.2529E+0, 1.2213E+0, 1.1723E+0, 1.1250E+0, 1.1094E+0, 1.0742E+0,&
     & 1.0499E+0, 1.0311E+0, 1.0195E+0, 1.0119E+0, 1.0075E+0, 1.0058E+0,&
     & 1.2537E+0, 1.2311E+0, 1.2015E+0, 1.1555E+0, 1.1435E+0, 1.1008E+0,&
     & 1.0691E+0, 1.0437E+0, 1.0276E+0, 1.0170E+0, 1.0107E+0, 1.0083E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0 /          
      DATA X0801/ 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0002E+0, 1.0001E+0, 1.0001E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0004E+0, 1.0003E+0, 1.0002E+0, 1.0001E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0011E+0, 1.0009E+0, 1.0004E+0, 1.0002E+0,&
     & 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0027E+0, 1.0023E+0, 1.0011E+0, 1.0005E+0,&
     & 1.0003E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0054E+0, 1.0045E+0, 1.0022E+0, 1.0010E+0,&
     & 1.0005E+0, 1.0002E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0107E+0, 1.0089E+0, 1.0044E+0, 1.0020E+0,&
     & 1.0010E+0, 1.0004E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0259E+0, 1.0216E+0, 1.0108E+0, 1.0053E+0,&
     & 1.0026E+0, 1.0010E+0, 1.0004E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0,&
     & 9.9999E-1, 9.9998E-1, 1.0501E+0, 1.0415E+0, 1.0212E+0, 1.0110E+0,&
     & 1.0050E+0, 1.0021E+0, 1.0009E+0, 1.0003E+0, 1.0001E+0 /          
      DATA X0901/ 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0988E+0, 1.0799E+0,&
     & 1.0401E+0, 1.0212E+0, 1.0094E+0, 1.0039E+0, 1.0017E+0, 1.0007E+0,&
     & 1.0003E+0, 1.0003E+0, 1.0004E+0, 1.0004E+0, 1.2734E+0, 1.1960E+0,&
     & 1.0763E+0, 1.0344E+0, 1.0164E+0, 1.0058E+0, 1.0016E+0, 1.0000E+0,&
     & 9.9988E-1, 1.0004E+0, 1.0010E+0, 1.0014E+0, 1.2413E+0, 1.1834E+0,&
     & 1.0910E+0, 1.0491E+0, 1.0271E+0, 1.0135E+0, 1.0067E+0, 1.0031E+0,&
     & 1.0018E+0, 1.0016E+0, 1.0019E+0, 1.0022E+0, 1.4597E+0, 1.3408E+0,&
     & 1.1650E+0, 1.0966E+0, 1.0618E+0, 1.0429E+0, 1.0343E+0, 1.0296E+0,&
     & 1.0277E+0, 1.0269E+0, 1.0269E+0, 1.0270E+0, 1.4831E+0, 1.3839E+0,&
     & 1.2060E+0, 1.1256E+0, 1.0812E+0, 1.0575E+0, 1.0485E+0, 1.0459E+0,&
     & 1.0469E+0, 1.0496E+0, 1.0527E+0, 1.0544E+0, 1.3915E+0, 1.3366E+0,&
     & 1.2089E+0, 1.1413E+0, 1.0902E+0, 1.0600E+0, 1.0519E+0, 1.0583E+0,&
     & 1.0743E+0, 1.0976E+0, 1.1238E+0, 1.1394E+0, 1.0003E+0, 1.0003E+0,&
     & 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0,&
     & 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0,&
     & 1.0003E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0,&
     & 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0002E+0 /          
      DATA X1001/ 1.0002E+0, 1.0003E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0,&
     & 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0,&
     & 9.9997E-1, 1.0001E+0, 1.0003E+0, 1.0004E+0, 1.0005E+0, 1.0005E+0,&
     & 1.0005E+0, 1.0006E+0, 1.0006E+0, 1.0006E+0, 1.0006E+0, 1.0006E+0,&
     & 9.9942E-1, 9.9968E-1, 1.0003E+0, 1.0006E+0, 1.0008E+0, 1.0008E+0,&
     & 1.0009E+0, 1.0009E+0, 1.0009E+0, 1.0009E+0, 1.0009E+0, 1.0009E+0,&
     & 9.9852E-1, 9.9904E-1, 1.0003E+0, 1.0009E+0, 1.0012E+0, 1.0014E+0,&
     & 1.0014E+0, 1.0014E+0, 1.0014E+0, 1.0014E+0, 1.0014E+0, 1.0014E+0,&
     & 9.9676E-1, 9.9778E-1, 1.0002E+0, 1.0015E+0, 1.0021E+0, 1.0024E+0,&
     & 1.0025E+0, 1.0026E+0, 1.0026E+0, 1.0026E+0, 1.0026E+0, 1.0026E+0,&
     & 9.9181E-1, 9.9422E-1, 1.0002E+0, 1.0033E+0, 1.0050E+0, 1.0057E+0,&
     & 1.0060E+0, 1.0062E+0, 1.0062E+0, 1.0063E+0, 1.0063E+0, 1.0063E+0,&
     & 9.8455E-1, 9.8915E-1, 1.0005E+0, 1.0068E+0, 1.0101E+0, 1.0116E+0,&
     & 1.0122E+0, 1.0124E+0, 1.0125E+0, 1.0125E+0, 1.0125E+0, 1.0124E+0,&
     & 9.7251E-1, 9.8184E-1, 1.0038E+0, 1.0154E+0, 1.0212E+0, 1.0236E+0,&
     & 1.0243E+0, 1.0243E+0, 1.0239E+0, 1.0234E+0, 1.0230E+0, 1.0228E+0,&
     & 9.5710E-1, 9.8528E-1, 1.0341E+0, 1.0505E+0, 1.0556E+0 /          
      DATA X1101/ 1.0557E+0, 1.0533E+0, 1.0497E+0, 1.0461E+0, 1.0426E+0,&
     & 1.0397E+0, 1.0383E+0, 1.0245E+0, 1.0401E+0, 1.0683E+0, 1.0784E+0,&
     & 1.0790E+0, 1.0759E+0, 1.0715E+0, 1.0663E+0, 1.0615E+0, 1.0571E+0,&
     & 1.0535E+0, 1.0517E+0, 8.7039E-1, 9.2266E-1, 1.0049E+0, 1.0297E+0,&
     & 1.0343E+0, 1.0292E+0, 1.0216E+0, 1.0130E+0, 1.0054E+0, 9.9848E-1,&
     & 9.9293E-1, 9.9026E-1, 8.1430E-1, 8.5701E-1, 9.3513E-1, 9.6208E-1,&
     & 9.6497E-1, 9.5595E-1, 9.4243E-1, 9.2590E-1, 9.1070E-1, 8.9621E-1,&
     & 8.8418E-1, 8.7826E-1, 7.8402E-1, 8.0550E-1, 8.4813E-1, 8.6060E-1,&
     & 8.5796E-1, 8.3749E-1, 8.0715E-1, 7.6727E-1, 7.2774E-1, 6.8737E-1,&
     & 6.5167E-1, 6.3331E-1, 1.0270E-4, 1.0852E-4, 1.3216E-4, 1.6083E-4,&
     & 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4, 3.7208E-4, 4.2995E-4,&
     & 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4, 1.3216E-4, 1.6083E-4,&
     & 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4, 3.7208E-4, 4.2995E-4,&
     & 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4, 1.3216E-4, 1.6083E-4,&
     & 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4, 3.7208E-4, 4.2995E-4,&
     & 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4, 1.3216E-4, 1.6083E-4,&
     & 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4, 3.7208E-4 /          
      DATA X1201/ 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4, 1.0852E-4,&
     & 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4, 2.7312E-4, 3.2170E-4,&
     & 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4, 1.0270E-4 /          
      DATA X1301/ 1.0852E-4, 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4,&
     & 2.7312E-4, 3.2170E-4, 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4,&
     & 1.0270E-4, 1.0852E-4, 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4,&
     & 2.7312E-4, 3.2170E-4, 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4,&
     & 1.0270E-4, 1.0852E-4, 1.3216E-4, 1.6083E-4, 1.9302E-4, 2.3292E-4,&
     & 2.7312E-4, 3.2170E-4, 3.7208E-4, 4.2995E-4, 4.8994E-4, 5.2547E-4,&
     & 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4, 2.7637E-4, 3.4411E-4,&
     & 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4, 8.1534E-4, 8.8201E-4,&
     & 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4, 2.7637E-4, 3.4411E-4,&
     & 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4, 8.1534E-4, 8.8201E-4,&
     & 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4, 2.7637E-4, 3.4411E-4,&
     & 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4, 8.1534E-4, 8.8201E-4,&
     & 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4, 2.7637E-4, 3.4411E-4,&
     & 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4, 8.1534E-4, 8.8201E-4,&
     & 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4, 2.7637E-4, 3.4411E-4,&
     & 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4, 8.1534E-4, 8.8201E-4,&
     & 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4, 2.7637E-4 /          
      DATA X1401/ 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4, 7.0298E-4,&
     & 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4, 1.7984E-4, 2.2412E-4,&
     & 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4, 5.9525E-4 /          
      DATA X1501/ 7.0298E-4, 8.1534E-4, 8.8201E-4, 1.3704E-4, 1.4526E-4,&
     & 1.7984E-4, 2.2412E-4, 2.7637E-4, 3.4411E-4, 4.1481E-4, 5.0256E-4,&
     & 5.9525E-4, 7.0298E-4, 8.1534E-4, 8.8201E-4, 5.2822E-1, 6.0368E-1,&
     & 6.7914E-1, 7.5460E-1, 8.3006E-1, 9.0552E-1, 9.8098E-1, 1.0000E+0,&
     & 5.3372E-3, 2.1243E-2, 6.2294E-2, 1.4732E-1, 2.9793E-1, 5.3585E-1,&
     & 8.8051E-1, 1.0000E+0, 2.7559E+0, 2.6192E+0, 2.4712E+0, 2.3045E+0,&
     & 2.1169E+0, 1.8974E+0, 1.5355E+0, 1.0000E+0, 3.1949E-3, 1.1502E-2,&
     & 3.1629E-2, 7.1565E-2, 1.4441E-1, 2.7668E-1, 5.8466E-1, 1.0000E+0,&
     & 1.1166E+1, 1.1873E+1, 1.2583E+1, 1.3304E+1, 1.4052E+1, 1.4853E+1,&
     & 1.5849E+1, 1.6664E+1, 2.1809E+1, 2.0835E+1, 2.0079E+1, 1.9452E+1,&
     & 1.8902E+1, 1.8352E+1, 1.7544E+1, 1.6664E+1, 5.6192E+0, 6.0212E0,&
     & 6.4836E0, 7.0138E0, 7.6298E0, 8.3655E+0, 9.3692E+0, 1.0200E+1,&
     & 1.1109E+1, 1.1320E+1, 1.1485E+1, 1.1588E+1, 1.1613E+1, 1.1507E+1,&
     & 1.1021E+1, 1.0200E+1, 2.8722E-1, 1.3252E+2, 3.7660E+0, 3.1300E-1,&
     & 1.0000E-3, 1.0000E-3, 1.0000E-3, 1.0000E-3 /                     
                                                                        
!----------------------------------------------------------------------------

       NG = 12
       N1 = 12 
       N2 = 15 
       N3 = 8 
       NS = 8 
       DO 20 I=1,4 
         DO 10 J=1,12 
           G(J,I) = Z(J+(I-1)*12) 
   10    END DO
   20  END DO

       DO 30 I=1,12 
         TT(I) = Z(I+48) 
   30 END DO

       DO 40 I=1,15
         DD(I) = Z(I+60) 
   40  CONTINUE

       KK=75 
       DO 70 I=1,8 
         DO 60 J=1,15 
           DO 50 K=1,12 
             KK=KK+1 
             GG(K,J,I) = Z(KK) 
   50      CONTINUE 
   60    CONTINUE 
   70  CONTINUE

       DO 90 I=1,8 
         DO 80 J=1,8 
           SAT(J,I) = Z(J+(I-1)*8+1515) 
   80    CONTINUE 
   90  CONTINUE

      DO 100 I=1,8 
        C(I) = Z(I+1579) 
  100  CONTINUE 

      IGOTO = 4
      CALL FLUID(TEMP,PRES,DENS,PROPS,NP,ENTRY,VAPOR,ERROR,IGOTO)

      RETURN                                                                        
      END Subroutine DryAir
