!+
      SUBROUTINE STEAM
! ---------------------------------------------------------------------------
! PURPOSE - Load common block /FLUDPC/
!.....STEAM TABLES FOR FLUID SUBPROGRAM.                                

!      WRITTEN BY: THEODORE E. FESSLER, NASA TM X-3572, AUGUST 1977     
!      REWRITTEN BY: LT. MARK D. KLEM & MARGARET P. PROCTOR, JANUARY 198
!                                                                       
!      THE ORIGINAL PROGRAM WAS WRITTEN IN SFTRAN, BUT THIS PROGRAM IS  
!      REWRITTEN IN STANDARD FORTRAN 77 TO RUN PRIMARILY ON PERSONAL    
!      COMPUTERS AND CAN ALSO RUN ON MAINFRAMES. MUCH OF THE OLD CODE WA
!      COMMENTED OUT BUT LEFT INTACT FOR DOCUMENTATION AND REFERENCE    
!      PURPOSES.                                                        
!                                                                       

  INTERFACE
    SUBROUTINE Fluid(T,P,RHO,PROPS,NP,ENTRY,VAPOR,ERROR,igoto)
      REAL,INTENT(IN OUT):: t
      REAL,INTENT(IN OUT):: p
      REAL,INTENT(IN OUT):: rho
      REAL,INTENT(OUT),DIMENSION(:):: props
      INTEGER,INTENT(IN):: np
      INTEGER,INTENT(IN):: entry
      LOGICAL,INTENT(OUT):: vapor
      INTEGER,INTENT(OUT):: error
      INTEGER,INTENT(IN):: igoto
    END Subroutine Fluid
  END INTERFACE


!                -- UNITS --                                            
                                                                        
!       R = 0.46151 JOULES / GRAM - DEG. K      C(1)                    
!       TCRIT = 647.29 DEG. K                   C(2)                    
!       PCRIT = 22.089 MEGA-NEWTONS / METER**2  C(3)                    
!       DCRIT = 0.317   GRAMS / CENTIMETER**3   C(4)                    
!       VISCOSITY = GRAMS / CENTIMETER - SEC.        PROP(7)            
!       CONDUCTIVITY = WATTS / CENTIMETER - DEG. K   PROP(8)            
                                                                        
!***  DIMENSION G(20,4),TT(20),DD(30),GG(20,30,8),SAT(40,8),C(8),M(4)   
!********************************************************************** 
      DIMENSION G(29,4),TT(27),DD(30),GG(27,30,8),SAT(40,8),C(8),M(4) 
       INTEGER ERROR,ENTRY 
       DIMENSION PROPS(8) 
       LOGICAL VAPOR 
!********************************************************************** 
                                                                        
      DIMENSION X0001(100),X0101(100),X0201(100),X0301(100),X0401(100), &
     &          X0501(100),X0601(100),X0701(100),X0801(100),X0901(100), &
     &          X1001(100),X1101(100),X1201(100),X1301(100),X1401(100), &
     &          X1501(100),X1601(100),X1701(100),X1801(100),X1901(100), &
     &          X2001(100),X2101(100),X2201(100),X2301(100),X2401(100), &
     &          X2501(100),X2601(100),X2701(100),X2801(100),X2901(100), &
     &          X3001(100),X3101(100),X3201(100),X3301(100),X3401(100), &
     &          X3501(100),X3601(100),X3701(100),X3801(100),X3901(100), &
     &          X4001(100),X4101(100),X4201(100),X4301(100),X4401(100), &
     &          X4501(100),X4601(100),X4701(100),X4801(100),X4901(100), &
     &          X5001(100),X5101(100),X5201(58)                         
                                                                        
      DIMENSION Z(5258) 
!********************************************************************** 
       COMMON /FLUDPC/ G,TT,DD,GG,SAT,C,M,NG,N1,N2,N3,NS 
!********************************************************************** 
      EQUIVALENCE (X0001,Z(0001)), (X0101,Z(0101)), (X0201,Z(0201)),    &
     &            (X0301,Z(0301)), (X0401,Z(0401)), (X0501,Z(0501)),    &
     &            (X0601,Z(0601)), (X0701,Z(0701)), (X0801,Z(0801)),    &
     &            (X0901,Z(0901)), (X1001,Z(1001)), (X1101,Z(1101)),    &
     &            (X1201,Z(1201)), (X1301,Z(1301)), (X1401,Z(1401)),    &
     &            (X1501,Z(1501)), (X1601,Z(1601)), (X1701,Z(1701)),    &
     &            (X1801,Z(1801)), (X1901,Z(1901)), (X2001,Z(2001)),    &
     &            (X2101,Z(2101)), (X2201,Z(2201)), (X2301,Z(2301)),    &
     &            (X2401,Z(2401)), (X2501,Z(2501)), (X2601,Z(2601)),    &
     &            (X2701,Z(2701)), (X2801,Z(2801)), (X2901,Z(2901)),    &
     &            (X3001,Z(3001)), (X3101,Z(3101)), (X3201,Z(3201)),    &
     &            (X3301,Z(3301)), (X3401,Z(3401)), (X3501,Z(3501)),    &
     &            (X3601,Z(3601)), (X3701,Z(3701)), (X3801,Z(3801)),    &
     &            (X3901,Z(3901)), (X4001,Z(4001)), (X4101,Z(4101)),    &
     &            (X4201,Z(4201)), (X4301,Z(4301)), (X4401,Z(4401)),    &
     &            (X4501,Z(4501)), (X4601,Z(4601)), (X4701,Z(4701)),    &
     &            (X4801,Z(4801)), (X4901,Z(4901)), (X5001,Z(5001)),    &
     &            (X5101,Z(5101)), (X5201,Z(5201))                      
                                                                        
!********************************************************************** 
!********************************************************************** 
                                                                        
      DATA X0001/ 6.1150E-1, 7.1000E-1, 7.6000E-1, 8.3000E-1, 8.9000E-1,&
     & 9.3000E-1, 9.4000E-1, 9.6000E-1, 9.8000E-1, 9.9000E-1, 1.0000E+0,&
     & 1.0100E+0, 1.0300E+0, 1.0800E+0, 1.1000E+0, 1.3000E+0, 1.5000E+0,&
     & 2.0000E+0, 2.4000E+0, 2.7000E+0, 2.8629E+1, 2.9099E+1, 2.9317E+1,&
     & 2.9604E+1, 2.9835E+1, 2.9982E+1, 3.0018E+1, 3.0089E+1, 3.0159E+1,&
     & 3.0194E+1, 3.0228E+1, 3.0263E+1, 3.0330E+1, 3.0495E+1, 3.0560E+1,&
     & 3.1164E+1, 3.1709E+1, 3.2903E+1, 3.3744E+1, 3.4331E+1, 1.6534E+1,&
     & 1.6784E+1, 1.6914E+1, 1.7100E+1, 1.7261E+1, 1.7371E+1, 1.7399E+1,&
     & 1.7454E+1, 1.7510E+1, 1.7538E+1, 1.7567E+1, 1.7595E+1, 1.7652E+1,&
     & 1.7795E+1, 1.7853E+1, 1.8455E+1, 1.9096E+1, 2.0874E+1, 2.2479E+1,&
     & 2.3792E+1, 3.1164E+0, 3.1856E+0, 3.2244E+0, 3.2815E+0, 3.3327E+0,&
     & 3.3678E+0, 3.3766E+0, 3.3944E+0, 3.4124E+0, 3.4215E+0, 3.4305E+0,&
     & 3.4396E+0, 3.4579E+0, 3.5041E+0, 3.5228E+0, 3.7138E+0, 3.9106E+0,&
     & 4.4164E+0, 4.8288E+0, 5.1406E+0, 6.1150E-1, 7.1200E-1, 7.6400E-1,&
     & 8.3500E-1, 8.9100E-1, 9.3600E-1, 9.4600E-1, 9.6400E-1, 9.8300E-1,&
     & 9.9000E-1, 9.9500E-1, 9.9900E-1, 1.0300E+0, 1.0800E+0, 1.1000E+0,&
     & 1.3000E+0, 1.5000E+0, 2.0000E+0, 2.4000E+0, 2.7000E+0/           
      DATA X0101/ 1.0000E-5, 2.0000E-4, 3.5000E-3, 1.7000E-2, 3.5000E-2,&
     & 7.8000E-2, 1.5000E-1, 2.1000E-1, 2.5300E-1, 2.8000E-1, 3.5800E-1,&
     & 4.3000E-1, 5.0000E-1, 5.7500E-1, 6.6000E-1, 8.4000E-1, 1.1800E+0,&
     & 1.4000E+0, 1.5000E+0, 1.6000E+0, 1.7000E+0, 1.8000E+0, 1.9400E+0,&
     & 2.0000E+0, 2.0900E+0, 2.2300E+0, 2.4500E+0, 2.6500E+0, 2.7800E+0,&
     & 2.9800E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0,&
     & 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0,&
     & 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6077E+0, 1.6077E+0,&
     & 1.6077E+0, 1.6077E+0, 1.6077E+0, 1.6058E+0, 1.6066E+0, 1.6068E+0,&
     & 1.6071E+0, 1.6072E+0, 1.6072E+0, 1.6073E+0, 1.6073E+0, 1.6073E+0,&
     & 1.6073E+0, 1.6073E+0, 1.6073E+0, 1.6074E+0, 1.6074E+0, 1.6074E+0,&
     & 1.6075E+0, 1.6076E+0, 1.6076E+0, 1.6076E+0, 1.6077E+0, 1.5748E+0,&
     & 1.5892E+0, 1.5933E+0, 1.5970E+0, 1.5990E+0, 1.6003E+0, 1.6005E+0,&
     & 1.6010E+0, 1.6014E+0, 1.6015E+0, 1.6016E+0, 1.6017E+0, 1.6022E+0,&
     & 1.6030E+0, 1.6033E+0, 1.6051E+0, 1.6060E+0, 1.6070E+0, 1.6075E+0,&
     & 1.6078E+0, 1.4547E+0, 1.5145E+0, 1.5361E+0, 1.5554E+0, 1.5656E+0,&
     & 1.5719E+0, 1.5731E+0, 1.5751E+0, 1.5771E+0, 1.5778E+0/           
      DATA X0201/ 1.5783E+0, 1.5786E+0, 1.5813E+0, 1.5851E+0, 1.5863E+0,&
     & 1.5952E+0, 1.5998E+0, 1.6046E+0, 1.6067E+0, 1.6082E+0, 1.3094E+0,&
     & 1.4147E+0, 1.4563E+0, 1.4988E+0, 1.5208E+0, 1.5340E+0, 1.5366E+0,&
     & 1.5408E+0, 1.5449E+0, 1.5464E+0, 1.5473E+0, 1.5481E+0, 1.5537E+0,&
     & 1.5613E+0, 1.5639E+0, 1.5821E+0, 1.5915E+0, 1.6013E+0, 1.6055E+0,&
     & 1.6086E+0, 9.9307E-1, 1.1911E+0, 1.2731E+0, 1.3627E+0, 1.4151E+0,&
     & 1.4455E+0, 1.4512E+0, 1.4608E+0, 1.4700E+0, 1.4732E+0, 1.4754E+0,&
     & 1.4771E+0, 1.4894E+0, 1.5060E+0, 1.5118E+0, 1.5516E+0, 1.5725E+0,&
     & 1.5939E+0, 1.6025E+0, 1.6092E+0, 5.3723E-1, 8.6287E-1, 1.0009E+0,&
     & 1.1556E+0, 1.2502E+0, 1.3086E+0, 1.3195E+0, 1.3375E+0, 1.3547E+0,&
     & 1.3606E+0, 1.3646E+0, 1.3678E+0, 1.3905E+0, 1.4209E+0, 1.4314E+0,&
     & 1.5040E+0, 1.5429E+0, 1.5821E+0, 1.5972E+0, 1.6095E+0, 2.7441E-1,&
     & 6.6028E-1, 8.2587E-1, 1.0150E+0, 1.1338E+0, 1.2099E+0, 1.2245E+0,&
     & 1.2485E+0, 1.2713E+0, 1.2791E+0, 1.2845E+0, 1.2887E+0, 1.3186E+0,&
     & 1.3587E+0, 1.3725E+0, 1.4683E+0, 1.5203E+0, 1.5728E+0, 1.5932E+0,&
     & 1.6102E+0, 6.4209E-2, 5.1280E-1, 7.0470E-1, 9.2374E-1, 1.0611E+0,&
     & 1.1488E+0, 1.1655E+0, 1.1931E+0, 1.2193E+0, 1.2282E+0/           
      DATA X0301/ 1.2344E+0, 1.2392E+0, 1.2735E+0, 1.3193E+0, 1.3351E+0,&
     & 1.4450E+0, 1.5053E+0, 1.5666E+0, 1.5908E+0, 1.6112E+0, 3.8147E-2,&
     & 4.7560E-1, 6.6534E-1, 8.8400E-1, 1.0236E+0, 1.1147E+0, 1.1325E+0,&
     & 1.1620E+0, 1.1899E+0, 1.1995E+0, 1.2061E+0, 1.2112E+0, 1.2478E+0,&
     & 1.2967E+0, 1.3136E+0, 1.4314E+0, 1.4962E+0, 1.5628E+0, 1.5895E+0,&
     & 1.6121E+0,-9.8389E-2, 3.5547E-1, 5.5347E-1, 7.8462E-1, 9.3454E-1,&
     & 1.0343E+0, 1.0540E+0, 1.0871E+0, 1.1188E+0, 1.1297E+0, 1.1372E+0,&
     & 1.1431E+0, 1.1847E+0, 1.2406E+0, 1.2599E+0, 1.3958E+0, 1.4720E+0,&
     & 1.5527E+0, 1.5869E+0, 1.6157E+0,-1.3843E-1, 3.0151E-1, 4.9780E-1,&
     & 7.2827E-1, 8.7981E-1, 9.8157E-1, 1.0019E+0, 1.0364E+0, 1.0697E+0,&
     & 1.0812E+0, 1.0892E+0, 1.0954E+0, 1.1397E+0, 1.1994E+0, 1.2201E+0,&
     & 1.3677E+0, 1.4518E+0, 1.5445E+0, 1.5859E+0, 1.6201E+0,-1.4063E-1,&
     & 2.8735E-1, 4.7534E-1, 6.9751E-1, 8.4595E-1, 9.4678E-1, 9.6700E-1,&
     & 1.0014E+0, 1.0350E+0, 1.0466E+0, 1.0547E+0, 1.0610E+0, 1.1062E+0,&
     & 1.1677E+0, 1.1892E+0, 1.3441E+0, 1.4340E+0, 1.5374E+0, 1.5858E+0,&
     & 1.6245E+0,-1.0156E-1, 2.9517E-1, 4.7363E-1, 6.8457E-1, 8.2666E-1,&
     & 9.2365E-1, 9.4321E-1, 9.7665E-1, 1.0094E+0, 1.0208E+0/           
      DATA X0401/ 1.0288E+0, 1.0350E+0, 1.0798E+0, 1.1413E+0, 1.1630E+0,&
     & 1.3222E+0, 1.4168E+0, 1.5307E+0, 1.5858E+0, 1.6283E+0, 4.4357E-2,&
     & 3.7367E-1, 5.2299E-1, 7.0346E-1, 8.2655E-1, 9.1317E-1, 9.3095E-1,&
     & 9.6160E-1, 9.9203E-1, 1.0028E+0, 1.0103E+0, 1.0162E+0, 1.0590E+0,&
     & 1.1190E+0, 1.1405E+0, 1.3012E+0, 1.3994E+0, 1.5235E+0, 1.5848E+0,&
     & 1.6296E+0, 3.7003E-1, 5.6584E-1, 6.5825E-1, 7.7473E-1, 8.5860E-1,&
     & 9.2093E-1, 9.3415E-1, 9.5742E-1, 9.8118E-1, 9.8973E-1, 9.9577E-1,&
     & 1.0006E+0, 1.0365E+0, 1.0899E+0, 1.1097E+0, 1.2664E+0, 1.3678E+0,&
     & 1.5058E+0, 1.5714E+0, 1.6123E+0, 6.7805E-1, 7.6158E-1, 8.0450E-1,&
     & 8.6292E-1, 9.0869E-1, 9.4535E-1, 9.5347E-1, 9.6809E-1, 9.8349E-1,&
     & 9.8916E-1, 9.9321E-1, 9.9645E-1, 1.0215E+0, 1.0618E+0, 1.0778E+0,&
     & 1.2167E+0, 1.3117E+0, 1.4351E+0, 1.4687E+0, 1.4706E+0, 9.5093E-1,&
     & 9.2006E-1, 9.1492E-1, 9.2023E-1, 9.3410E-1, 9.5145E-1, 9.5603E-1,&
     & 9.6505E-1, 9.7549E-1, 9.7958E-1, 9.8260E-1, 9.8505E-1, 1.0056E+0,&
     & 1.0415E+0, 1.0561E+0, 1.1822E+0, 1.2653E+0, 1.3528E+0, 1.3469E+0,&
     & 1.3135E+0, 9.2787E-1, 9.0318E-1, 9.0056E-1, 9.0825E-1, 9.2325E-1,&
     & 9.4100E-1, 9.4564E-1, 9.5466E-1, 9.6504E-1, 9.6909E-1/           
      DATA X0501/ 9.7207E-1, 9.7449E-1, 9.9466E-1, 1.0296E+0, 1.0437E+0,&
     & 1.1637E+0, 1.2396E+0, 1.3075E+0, 1.2836E+0, 1.2360E+0, 9.2773E-1,&
     & 8.9478E-1, 8.9087E-1, 8.9551E-1, 9.1040E-1, 9.2749E-1, 9.3210E-1,&
     & 9.4109E-1, 9.5157E-1, 9.5568E-1, 9.5870E-1, 9.6117E-1, 9.8139E-1,&
     & 1.0157E+0, 1.0294E+0, 1.1425E+0, 1.2105E+0, 1.2587E+0, 1.2193E+0,&
     & 1.1605E+0, 8.7500E-1, 8.5815E-1, 8.5938E-1, 8.7183E-1, 8.9020E-1,&
     & 9.0967E-1, 9.1470E-1, 9.2440E-1, 9.3541E-1, 9.3969E-1, 9.4281E-1,&
     & 9.4535E-1, 9.6577E-1, 9.9944E-1, 1.0126E+0, 1.1179E+0, 1.1775E+0,&
     & 1.2078E+0, 1.1570E+0, 1.0911E+0, 7.8467E-1, 7.9956E-1, 8.1348E-1,&
     & 8.3960E-1, 8.6533E-1, 8.8885E-1, 8.9455E-1, 9.0517E-1, 9.1685E-1,&
     & 9.2129E-1, 9.2451E-1, 9.2710E-1, 9.4756E-1, 9.8023E-1, 9.9273E-1,&
     & 1.0892E+0, 1.1403E+0, 1.1562E+0, 1.0994E+0, 1.0315E+0, 7.3122E-1,&
     & 7.5630E-1, 7.7426E-1, 8.0414E-1, 8.3211E-1, 8.5738E-1, 8.6334E-1,&
     & 8.7437E-1, 8.8644E-1, 8.9094E-1, 8.9417E-1, 8.9674E-1, 9.1655E-1,&
     & 9.4680E-1, 9.5805E-1, 1.0404E+0, 1.0805E+0, 1.0855E+0, 1.0320E+0,&
     & 9.7085E-1, 7.1547E-1, 7.4043E-1, 7.5821E-1, 7.8825E-1, 8.1651E-1,&
     & 8.4212E-1, 8.4816E-1, 8.5936E-1, 8.7138E-1, 8.7582E-1/           
      DATA X0601/ 8.7898E-1, 8.8150E-1, 9.0068E-1, 9.2946E-1, 9.4003E-1,&
     & 1.0159E+0, 1.0520E+0, 1.0568E+0, 1.0092E+0, 9.5464E-1, 6.3240E-1,&
     & 6.8680E-1, 7.1573E-1, 7.5659E-1, 7.8973E-1, 8.1692E-1, 8.2303E-1,&
     & 8.3409E-1, 8.4569E-1, 8.4990E-1, 8.5289E-1, 8.5526E-1, 8.7308E-1,&
     & 8.9917E-1, 9.0861E-1, 9.7477E-1, 1.0064E+0, 1.0165E+0, 9.8330E-1,&
     & 9.4265E-1, 5.7243E-1, 6.3664E-1, 6.6881E-1, 7.1150E-1, 7.4422E-1,&
     & 7.6989E-1, 7.7553E-1, 7.8546E-1, 7.9557E-1, 7.9918E-1, 8.0173E-1,&
     & 8.0374E-1, 8.1860E-1, 8.3977E-1, 8.4731E-1, 9.0019E-1, 9.2944E-1,&
     & 9.6326E-1, 9.6491E-1, 9.5459E-1, 4.9020E-1, 5.5253E-1, 5.8163E-1,&
     & 6.1789E-1, 6.4367E-1, 6.6257E-1, 6.6647E-1, 6.7323E-1, 6.7998E-1,&
     & 6.8237E-1, 6.8404E-1, 6.8537E-1, 6.9512E-1, 7.0919E-1, 7.1434E-1,&
     & 7.5817E-1, 7.9899E-1, 9.0558E-1, 9.8405E-1, 1.0345E+0, 4.0336E-1,&
     & 4.4143E-1, 4.5917E-1, 4.8125E-1, 4.9692E-1, 5.0833E-1, 5.1076E-1,&
     & 5.1505E-1, 5.1949E-1, 5.2111E-1, 5.2226E-1, 5.2319E-1, 5.3028E-1,&
     & 5.4175E-1, 5.4641E-1, 5.9836E-1, 6.6144E-1, 8.4311E-1, 9.8528E-1,&
     & 1.0823E+0, 3.0531E-1, 3.2522E-1, 3.3514E-1, 3.4826E-1, 3.5827E-1,&
     & 3.6645E-1, 3.6832E-1, 3.7173E-1, 3.7544E-1, 3.7683E-1/           
      DATA X0701/ 3.7783E-1, 3.7864E-1, 3.8511E-1, 3.9631E-1, 4.0108E-1,&
     & 4.5786E-1, 5.2791E-1, 7.2371E-1, 8.7391E-1, 9.7610E-1, 3.7021E-2,&
     & 3.7972E-2, 3.8756E-2, 4.0205E-2, 4.1724E-2, 4.3208E-2, 4.3570E-2,&
     & 4.4251E-2, 4.5011E-2, 4.5301E-2, 4.5512E-2, 4.5683E-2, 4.7065E-2,&
     & 4.9507E-2, 5.0553E-2, 6.2747E-2, 7.6927E-2, 1.1374E-1, 1.4063E-1,&
     & 1.5858E-1, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 9.9992E-1, 9.9996E-1, 9.9997E-1,&
     & 9.9998E-1, 9.9998E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1,&
     & 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 9.9831E-1,&
     & 9.9919E-1, 9.9941E-1, 9.9959E-1, 9.9968E-1, 9.9973E-1, 9.9974E-1,&
     & 9.9976E-1, 9.9977E-1, 9.9977E-1, 9.9978E-1, 9.9978E-1, 9.9980E-1,&
     & 9.9983E-1, 9.9984E-1, 9.9991E-1, 9.9994E-1, 9.9997E-1, 9.9996E-1,&
     & 9.9995E-1, 9.9190E-1, 9.9554E-1, 9.9680E-1, 9.9783E-1, 9.9832E-1,&
     & 9.9859E-1, 9.9865E-1, 9.9873E-1, 9.9881E-1, 9.9884E-1/           
      DATA X0801/ 9.9886E-1, 9.9888E-1, 9.9899E-1, 9.9913E-1, 9.9918E-1,&
     & 9.9953E-1, 9.9972E-1, 9.9986E-1, 9.9982E-1, 9.9976E-1, 9.8385E-1,&
     & 9.9031E-1, 9.9279E-1, 9.9522E-1, 9.9636E-1, 9.9699E-1, 9.9711E-1,&
     & 9.9730E-1, 9.9748E-1, 9.9754E-1, 9.9759E-1, 9.9762E-1, 9.9786E-1,&
     & 9.9817E-1, 9.9827E-1, 9.9900E-1, 9.9940E-1, 9.9970E-1, 9.9963E-1,&
     & 9.9951E-1, 9.6424E-1, 9.7724E-1, 9.8252E-1, 9.8813E-1, 9.9125E-1,&
     & 9.9292E-1, 9.9322E-1, 9.9371E-1, 9.9417E-1, 9.9432E-1, 9.9442E-1,&
     & 9.9451E-1, 9.9508E-1, 9.9582E-1, 9.9607E-1, 9.9771E-1, 9.9860E-1,&
     & 9.9934E-1, 9.9918E-1, 9.9889E-1, 9.2914E-1, 9.5381E-1, 9.6408E-1,&
     & 9.7527E-1, 9.8184E-1, 9.8567E-1, 9.8634E-1, 9.8743E-1, 9.8842E-1,&
     & 9.8876E-1, 9.8898E-1, 9.8916E-1, 9.9037E-1, 9.9187E-1, 9.9236E-1,&
     & 9.9549E-1, 9.9721E-1, 9.9878E-1, 9.9846E-1, 9.9784E-1, 9.0305E-1,&
     & 9.3578E-1, 9.4940E-1, 9.6471E-1, 9.7395E-1, 9.7952E-1, 9.8054E-1,&
     & 9.8218E-1, 9.8366E-1, 9.8415E-1, 9.8449E-1, 9.8475E-1, 9.8651E-1,&
     & 9.8867E-1, 9.8936E-1, 9.9367E-1, 9.9605E-1, 9.9833E-1, 9.9787E-1,&
     & 9.9694E-1, 8.7839E-1, 9.2012E-1, 9.3727E-1, 9.5660E-1, 9.6822E-1,&
     & 9.7519E-1, 9.7646E-1, 9.7850E-1, 9.8033E-1, 9.8094E-1/           
      DATA X0901/ 9.8135E-1, 9.8167E-1, 9.8384E-1, 9.8645E-1, 9.8728E-1,&
     & 9.9239E-1, 9.9523E-1, 9.9801E-1, 9.9744E-1, 9.9628E-1, 8.7318E-1,&
     & 9.1498E-1, 9.3280E-1, 9.5276E-1, 9.6500E-1, 9.7256E-1, 9.7396E-1,&
     & 9.7624E-1, 9.7830E-1, 9.7897E-1, 9.7944E-1, 9.7979E-1, 9.8220E-1,&
     & 9.8510E-1, 9.8601E-1, 9.9161E-1, 9.9473E-1, 9.9781E-1, 9.9717E-1,&
     & 9.9586E-1, 8.4497E-1, 8.9551E-1, 9.1673E-1, 9.4098E-1, 9.5596E-1,&
     & 9.6539E-1, 9.6716E-1, 9.7007E-1, 9.7273E-1, 9.7360E-1, 9.7420E-1,&
     & 9.7466E-1, 9.7774E-1, 9.8140E-1, 9.8255E-1, 9.8945E-1, 9.9331E-1,&
     & 9.9722E-1, 9.9635E-1, 9.9460E-1, 8.2959E-1, 8.8232E-1, 9.0527E-1,&
     & 9.3213E-1, 9.4936E-1, 9.5955E-1, 9.6158E-1, 9.6497E-1, 9.6807E-1,&
     & 9.6910E-1, 9.6981E-1, 9.7035E-1, 9.7399E-1, 9.7829E-1, 9.7962E-1,&
     & 9.8758E-1, 9.9207E-1, 9.9665E-1, 9.9555E-1, 9.9341E-1, 8.0688E-1,&
     & 8.6548E-1, 8.9307E-1, 9.2285E-1, 9.4263E-1, 9.5442E-1, 9.5673E-1,&
     & 9.6049E-1, 9.6403E-1, 9.6520E-1, 9.6600E-1, 9.6661E-1, 9.7072E-1,&
     & 9.7554E-1, 9.7703E-1, 9.8589E-1, 9.9092E-1, 9.9607E-1, 9.9475E-1,&
     & 9.9224E-1, 7.8613E-1, 8.5156E-1, 8.8184E-1, 9.1479E-1, 9.3652E-1,&
     & 9.4966E-1, 9.5219E-1, 9.5636E-1, 9.6025E-1, 9.6154E-1/           
      DATA X1001/ 9.6242E-1, 9.6310E-1, 9.6761E-1, 9.7290E-1, 9.7453E-1,&
     & 9.8422E-1, 9.8975E-1, 9.9541E-1, 9.9386E-1, 9.9100E-1, 7.8345E-1,&
     & 8.4958E-1, 8.7810E-1, 9.1119E-1, 9.3211E-1, 9.4563E-1, 9.4824E-1,&
     & 9.5260E-1, 9.5668E-1, 9.5806E-1, 9.5900E-1, 9.5973E-1, 9.6459E-1,&
     & 9.7027E-1, 9.7203E-1, 9.8249E-1, 9.8850E-1, 9.9463E-1, 9.9285E-1,&
     & 9.8965E-1, 8.3185E-1, 8.7509E-1, 8.9433E-1, 9.1725E-1, 9.3250E-1,&
     & 9.4298E-1, 9.4509E-1, 9.4870E-1, 9.5223E-1, 9.5346E-1, 9.5432E-1,&
     & 9.5499E-1, 9.5976E-1, 9.6587E-1, 9.6776E-1, 9.7929E-1, 9.8610E-1,&
     & 9.9296E-1, 9.9088E-1, 9.8724E-1, 8.4247E-1, 8.7997E-1, 8.9674E-1,&
     & 9.1684E-1, 9.3034E-1, 9.3969E-1, 9.4158E-1, 9.4484E-1, 9.4804E-1,&
     & 9.4916E-1, 9.4994E-1, 9.5056E-1, 9.5495E-1, 9.6071E-1, 9.6255E-1,&
     & 9.7472E-1, 9.8248E-1, 9.9071E-1, 9.8920E-1, 9.8588E-1, 8.1825E-1,&
     & 8.6597E-1, 8.8713E-1, 9.1177E-1, 9.2763E-1, 9.3807E-1, 9.4012E-1,&
     & 9.4359E-1, 9.4688E-1, 9.4800E-1, 9.4877E-1, 9.4938E-1, 9.5350E-1,&
     & 9.5868E-1, 9.6039E-1, 9.7265E-1, 9.8103E-1, 9.9069E-1, 9.9044E-1,&
     & 9.8810E-1, 8.3272E-1, 8.7492E-1, 8.9352E-1, 9.1534E-1, 9.2949E-1,&
     & 9.3890E-1, 9.4075E-1, 9.4389E-1, 9.4689E-1, 9.4792E-1/           
      DATA X1101/ 9.4863E-1, 9.4919E-1, 9.5302E-1, 9.5794E-1, 9.5961E-1,&
     & 9.7196E-1, 9.8067E-1, 9.9119E-1, 9.9171E-1, 9.8996E-1, 8.3862E-1,&
     & 8.7744E-1, 8.9624E-1, 9.1650E-1, 9.3066E-1, 9.3948E-1, 9.4121E-1,&
     & 9.4412E-1, 9.4691E-1, 9.4786E-1, 9.4852E-1, 9.4903E-1, 9.5260E-1,&
     & 9.5730E-1, 9.5892E-1, 9.7145E-1, 9.8053E-1, 9.9201E-1, 9.9340E-1,&
     & 9.9229E-1, 8.5498E-1, 8.8770E-1, 9.0259E-1, 9.2090E-1, 9.3269E-1,&
     & 9.4016E-1, 9.4171E-1, 9.4438E-1, 9.4692E-1, 9.4779E-1, 9.4840E-1,&
     & 9.4887E-1, 9.5222E-1, 9.5674E-1, 9.5834E-1, 9.7113E-1, 9.8063E-1,&
     & 9.9317E-1, 9.9548E-1, 9.9504E-1, 8.6792E-1, 8.9502E-1, 9.0771E-1,&
     & 9.2358E-1, 9.3411E-1, 9.4072E-1, 9.4212E-1, 9.4456E-1, 9.4689E-1,&
     & 9.4770E-1, 9.4827E-1, 9.4871E-1, 9.5189E-1, 9.5631E-1, 9.5790E-1,&
     & 9.7103E-1, 9.8099E-1, 9.9462E-1, 9.9787E-1, 9.9811E-1, 8.6880E-1,&
     & 8.9722E-1, 9.0985E-1, 9.2470E-1, 9.3451E-1, 9.4113E-1, 9.4245E-1,&
     & 9.4469E-1, 9.4686E-1, 9.4761E-1, 9.4814E-1, 9.4856E-1, 9.5159E-1,&
     & 9.5596E-1, 9.5758E-1, 9.7135E-1, 9.8196E-1, 9.9710E-1, 1.0016E+0,&
     & 1.0027E+0, 8.6945E-1, 8.9819E-1, 9.1054E-1, 9.2526E-1, 9.3490E-1,&
     & 9.4134E-1, 9.4261E-1, 9.4477E-1, 9.4689E-1, 9.4763E-1/           
      DATA X1201/ 9.4815E-1, 9.4856E-1, 9.5157E-1, 9.5595E-1, 9.5759E-1,&
     & 9.7167E-1, 9.8255E-1, 9.9827E-1, 1.0033E+0, 1.0048E+0, 8.7769E-1,&
     & 9.0291E-1, 9.1365E-1, 9.2685E-1, 9.3565E-1, 9.4168E-1, 9.4290E-1,&
     & 9.4498E-1, 9.4704E-1, 9.4777E-1, 9.4828E-1, 9.4869E-1, 9.5169E-1,&
     & 9.5615E-1, 9.5782E-1, 9.7238E-1, 9.8364E-1, 1.0001E+0, 1.0057E+0,&
     & 1.0077E+0, 8.8229E-1, 9.0552E-1, 9.1594E-1, 9.2836E-1, 9.3672E-1,&
     & 9.4251E-1, 9.4368E-1, 9.4571E-1, 9.4776E-1, 9.4849E-1, 9.4901E-1,&
     & 9.4942E-1, 9.5248E-1, 9.5710E-1, 9.5885E-1, 9.7410E-1, 9.8578E-1,&
     & 1.0030E+0, 1.0093E+0, 1.0118E+0, 8.8771E-1, 9.0986E-1, 9.1986E-1,&
     & 9.3188E-1, 9.4003E-1, 9.4574E-1, 9.4693E-1, 9.4901E-1, 9.5113E-1,&
     & 9.5190E-1, 9.5244E-1, 9.5287E-1, 9.5609E-1, 9.6097E-1, 9.6281E-1,&
     & 9.7856E-1, 9.9012E-1, 1.0068E+0, 1.0131E+0, 1.0158E+0, 8.9254E-1,&
     & 9.1643E-1, 9.2698E-1, 9.3938E-1, 9.4753E-1, 9.5333E-1, 9.5455E-1,&
     & 9.5667E-1, 9.5882E-1, 9.5959E-1, 9.6014E-1, 9.6057E-1, 9.6381E-1,&
     & 9.6863E-1, 9.7043E-1, 9.8509E-1, 9.9507E-1, 1.0083E+0, 1.0129E+0,&
     & 1.0148E+0, 9.0083E-1, 9.2673E-1, 9.3770E-1, 9.5000E-1, 9.5808E-1,&
     & 9.6377E-1, 9.6494E-1, 9.6699E-1, 9.6905E-1, 9.6978E-1/           
      DATA X1301/ 9.7030E-1, 9.7071E-1, 9.7374E-1, 9.7817E-1, 9.7979E-1,&
     & 9.9234E-1, 1.0001E+0, 1.0089E+0, 1.0112E+0, 1.0119E+0, 9.8187E-1,&
     & 1.0097E+0, 1.0203E+0, 1.0317E+0, 1.0387E+0, 1.0432E+0, 1.0441E+0,&
     & 1.0456E+0, 1.0471E+0, 1.0476E+0, 1.0480E+0, 1.0483E+0, 1.0502E+0,&
     & 1.0529E+0, 1.0538E+0, 1.0586E+0, 1.0591E+0, 1.0540E+0, 1.0489E+0,&
     & 1.0456E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 9.9988E-1, 9.9994E-1, 9.9995E-1,&
     & 9.9997E-1, 9.9997E-1, 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9998E-1,&
     & 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9998E-1, 9.9999E-1, 9.9999E-1,&
     & 9.9999E-1, 1.0000E+0, 1.0000E+0, 1.0000E+0, 9.9999E-1, 9.9779E-1,&
     & 9.9880E-1, 9.9909E-1, 9.9934E-1, 9.9946E-1, 9.9954E-1, 9.9955E-1,&
     & 9.9958E-1, 9.9960E-1, 9.9961E-1, 9.9962E-1, 9.9962E-1, 9.9965E-1,&
     & 9.9970E-1, 9.9972E-1, 9.9984E-1, 9.9991E-1, 9.9996E-1, 9.9991E-1,&
     & 9.9986E-1, 9.8938E-1, 9.9372E-1, 9.9527E-1, 9.9662E-1, 9.9730E-1,&
     & 9.9770E-1, 9.9778E-1, 9.9791E-1, 9.9803E-1, 9.9807E-1/           
      DATA X1401/ 9.9810E-1, 9.9813E-1, 9.9829E-1, 9.9852E-1, 9.9860E-1,&
     & 9.9921E-1, 9.9956E-1, 9.9979E-1, 9.9957E-1, 9.9930E-1, 9.7837E-1,&
     & 9.8641E-1, 9.8954E-1, 9.9269E-1, 9.9426E-1, 9.9517E-1, 9.9534E-1,&
     & 9.9562E-1, 9.9589E-1, 9.9598E-1, 9.9605E-1, 9.9610E-1, 9.9646E-1,&
     & 9.9694E-1, 9.9711E-1, 9.9834E-1, 9.9908E-1, 9.9958E-1, 9.9913E-1,&
     & 9.9856E-1, 9.5041E-1, 9.6750E-1, 9.7451E-1, 9.8205E-1, 9.8635E-1,&
     & 9.8874E-1, 9.8918E-1, 9.8990E-1, 9.9058E-1, 9.9081E-1, 9.9097E-1,&
     & 9.9110E-1, 9.9197E-1, 9.9312E-1, 9.9350E-1, 9.9623E-1, 9.9785E-1,&
     & 9.9912E-1, 9.9814E-1, 9.9681E-1, 8.9781E-1, 9.3208E-1, 9.4644E-1,&
     & 9.6222E-1, 9.7160E-1, 9.7718E-1, 9.7818E-1, 9.7981E-1, 9.8131E-1,&
     & 9.8182E-1, 9.8217E-1, 9.8244E-1, 9.8430E-1, 9.8666E-1, 9.8743E-1,&
     & 9.9259E-1, 9.9569E-1, 9.9843E-1, 9.9657E-1, 9.9383E-1, 8.5577E-1,&
     & 9.0331E-1, 9.2293E-1, 9.4525E-1, 9.5885E-1, 9.6717E-1, 9.6871E-1,&
     & 9.7119E-1, 9.7347E-1, 9.7423E-1, 9.7475E-1, 9.7515E-1, 9.7791E-1,&
     & 9.8133E-1, 9.8244E-1, 9.8955E-1, 9.9384E-1, 9.9788E-1, 9.9524E-1,&
     & 9.9121E-1, 8.1737E-1, 8.7830E-1, 9.0355E-1, 9.3211E-1, 9.4944E-1,&
     & 9.5998E-1, 9.6192E-1, 9.6505E-1, 9.6790E-1, 9.6885E-1/           
      DATA X1501/ 9.6950E-1, 9.7000E-1, 9.7342E-1, 9.7760E-1, 9.7894E-1,&
     & 9.8741E-1, 9.9253E-1, 9.9747E-1, 9.9423E-1, 9.8924E-1, 8.0678E-1,&
     & 8.6900E-1, 8.9560E-1, 9.2554E-1, 9.4401E-1, 9.5555E-1, 9.5771E-1,&
     & 9.6124E-1, 9.6445E-1, 9.6552E-1, 9.6625E-1, 9.6681E-1, 9.7065E-1,&
     & 9.7531E-1, 9.7679E-1, 9.8609E-1, 9.9171E-1, 9.9720E-1, 9.9356E-1,&
     & 9.8796E-1, 7.5757E-1, 8.3496E-1, 8.6786E-1, 9.0518E-1, 9.2847E-1,&
     & 9.4323E-1, 9.4602E-1, 9.5063E-1, 9.5487E-1, 9.5627E-1, 9.5723E-1,&
     & 9.5796E-1, 9.6296E-1, 9.6895E-1, 9.7084E-1, 9.8242E-1, 9.8941E-1,&
     & 9.9632E-1, 9.9146E-1, 9.8406E-1, 7.2607E-1, 8.0981E-1, 8.4668E-1,&
     & 8.8916E-1, 9.1615E-1, 9.3288E-1, 9.3616E-1, 9.4161E-1, 9.4665E-1,&
     & 9.4834E-1, 9.4950E-1, 9.5038E-1, 9.5637E-1, 9.6350E-1, 9.6573E-1,&
     & 9.7922E-1, 9.8736E-1, 9.9534E-1, 9.8928E-1, 9.8027E-1, 6.8213E-1,&
     & 7.7954E-1, 8.2373E-1, 8.7231E-1, 9.0405E-1, 9.2357E-1, 9.2734E-1,&
     & 9.3356E-1, 9.3938E-1, 9.4133E-1, 9.4265E-1, 9.4366E-1, 9.5051E-1,&
     & 9.5862E-1, 9.6115E-1, 9.7630E-1, 9.8544E-1, 9.9421E-1, 9.8696E-1,&
     & 9.7647E-1, 6.4136E-1, 7.5293E-1, 8.0249E-1, 8.5718E-1, 8.9282E-1,&
     & 9.1475E-1, 9.1896E-1, 9.2596E-1, 9.3246E-1, 9.3463E-1/           
      DATA X1601/ 9.3610E-1, 9.3724E-1, 9.4487E-1, 9.5388E-1, 9.5667E-1,&
     & 9.7338E-1, 9.8345E-1, 9.9280E-1, 9.8431E-1, 9.7241E-1, 6.3609E-1,&
     & 7.4631E-1, 7.9401E-1, 8.4921E-1, 8.8427E-1, 9.0704E-1, 9.1147E-1,&
     & 9.1884E-1, 9.2577E-1, 9.2811E-1, 9.2972E-1, 9.3096E-1, 9.3929E-1,&
     & 9.4911E-1, 9.5214E-1, 9.7031E-1, 9.8124E-1, 9.9098E-1, 9.8123E-1,&
     & 9.6801E-1, 7.0435E-1, 7.8069E-1, 8.1468E-1, 8.5510E-1, 8.8205E-1,&
     & 9.0054E-1, 9.0427E-1, 9.1064E-1, 9.1687E-1, 9.1904E-1, 9.2055E-1,&
     & 9.2174E-1, 9.3015E-1, 9.4092E-1, 9.4426E-1, 9.6447E-1, 9.7671E-1,&
     & 9.8673E-1, 9.7520E-1, 9.6043E-1, 7.1489E-1, 7.8374E-1, 8.1448E-1,&
     & 8.5124E-1, 8.7584E-1, 8.9285E-1, 8.9629E-1, 9.0219E-1, 9.0798E-1,&
     & 9.1001E-1, 9.1141E-1, 9.1252E-1, 9.2043E-1, 9.3071E-1, 9.3397E-1,&
     & 9.5506E-1, 9.6864E-1, 9.8032E-1, 9.7062E-1, 9.5812E-1, 6.6946E-1,&
     & 7.5783E-1, 7.9655E-1, 8.4131E-1, 8.7011E-1, 8.8908E-1, 8.9280E-1,&
     & 8.9904E-1, 9.0496E-1, 9.0697E-1, 9.0836E-1, 9.0944E-1, 9.1679E-1,&
     & 9.2587E-1, 9.2883E-1, 9.4959E-1, 9.6410E-1, 9.7946E-1, 9.7481E-1,&
     & 9.6699E-1, 6.9632E-1, 7.7393E-1, 8.0798E-1, 8.4753E-1, 8.7313E-1,&
     & 8.9009E-1, 8.9341E-1, 8.9904E-1, 9.0439E-1, 9.0623E-1/           
      DATA X1701/ 9.0749E-1, 9.0847E-1, 9.1522E-1, 9.2370E-1, 9.2652E-1,&
     & 9.4718E-1, 9.6228E-1, 9.8004E-1, 9.7843E-1, 9.7328E-1, 7.0459E-1,&
     & 7.7881E-1, 8.1250E-1, 8.4961E-1, 8.7451E-1, 8.9046E-1, 8.9354E-1,&
     & 8.9871E-1, 9.0363E-1, 9.0529E-1, 9.0644E-1, 9.0733E-1, 9.1349E-1,&
     & 9.2141E-1, 9.2411E-1, 9.4480E-1, 9.6061E-1, 9.8112E-1, 9.8277E-1,&
     & 9.8043E-1, 7.3096E-1, 7.9395E-1, 8.2251E-1, 8.5571E-1, 8.7697E-1,&
     & 8.9075E-1, 8.9351E-1, 8.9814E-1, 9.0253E-1, 9.0403E-1, 9.0507E-1,&
     & 9.0587E-1, 9.1150E-1, 9.1894E-1, 9.2153E-1, 9.4244E-1, 9.5907E-1,&
     & 9.8248E-1, 9.8740E-1, 9.8780E-1, 7.5635E-1, 8.0859E-1, 8.3228E-1,&
     & 8.6035E-1, 8.7859E-1, 8.9052E-1, 8.9294E-1, 8.9705E-1, 9.0097E-1,&
     & 9.0233E-1, 9.0327E-1, 9.0400E-1, 9.0918E-1, 9.1624E-1, 9.1877E-1,&
     & 9.4010E-1, 9.5762E-1, 9.8383E-1, 9.9171E-1, 9.9452E-1, 7.6453E-1,&
     & 8.1410E-1, 8.3591E-1, 8.6130E-1, 8.7775E-1, 8.8868E-1, 8.9083E-1,&
     & 8.9445E-1, 8.9791E-1, 8.9910E-1, 8.9994E-1, 9.0059E-1, 9.0533E-1,&
     & 9.1209E-1, 9.1460E-1, 9.3683E-1, 9.5556E-1, 9.8488E-1, 9.9567E-1,&
     & 1.0007E+0, 7.6553E-1, 8.1517E-1, 8.3632E-1, 8.6116E-1, 8.7710E-1,&
     & 8.8753E-1, 8.8957E-1, 8.9298E-1, 8.9628E-1, 8.9743E-1/           
      DATA X1801/ 8.9823E-1, 8.9886E-1, 9.0348E-1, 9.1020E-1, 9.1272E-1,&
     & 9.3542E-1, 9.5458E-1, 9.8466E-1, 9.9600E-1, 1.0014E+0, 7.8188E-1,&
     & 8.2294E-1, 8.4071E-1, 8.6198E-1, 8.7595E-1, 8.8535E-1, 8.8722E-1,&
     & 8.9039E-1, 8.9352E-1, 8.9462E-1, 8.9539E-1, 8.9600E-1, 9.0052E-1,&
     & 9.0725E-1, 9.0981E-1, 9.3321E-1, 9.5282E-1, 9.8303E-1, 9.9414E-1,&
     & 9.9917E-1, 7.8835E-1, 8.2458E-1, 8.4070E-1, 8.5971E-1, 8.7231E-1,&
     & 8.8090E-1, 8.8262E-1, 8.8560E-1, 8.8860E-1, 8.8967E-1, 8.9043E-1,&
     & 8.9103E-1, 8.9554E-1, 9.0243E-1, 9.0509E-1, 9.2929E-1, 9.4869E-1,&
     & 9.7573E-1, 9.8330E-1, 9.8540E-1, 7.9016E-1, 8.2156E-1, 8.3569E-1,&
     & 8.5264E-1, 8.6410E-1, 8.7210E-1, 8.7377E-1, 8.7671E-1, 8.7972E-1,&
     & 8.8080E-1, 8.8157E-1, 8.8218E-1, 8.8680E-1, 8.9385E-1, 8.9654E-1,&
     & 9.1926E-1, 9.3414E-1, 9.4438E-1, 9.3833E-1, 9.3118E-1, 7.8093E-1,&
     & 8.1302E-1, 8.2716E-1, 8.4375E-1, 8.5462E-1, 8.6235E-1, 8.6396E-1,&
     & 8.6677E-1, 8.6961E-1, 8.7062E-1, 8.7133E-1, 8.7190E-1, 8.7607E-1,&
     & 8.8213E-1, 8.8431E-1, 8.9905E-1, 9.0270E-1, 8.8564E-1, 8.6464E-1,&
     & 8.4998E-1, 7.7336E-1, 8.0692E-1, 8.2107E-1, 8.3686E-1, 8.4705E-1,&
     & 8.5397E-1, 8.5537E-1, 8.5774E-1, 8.6008E-1, 8.6089E-1/           
      DATA X1901/ 8.6145E-1, 8.6190E-1, 8.6506E-1, 8.6920E-1, 8.7053E-1,&
     & 8.7502E-1, 8.6788E-1, 8.3288E-1, 8.0650E-1, 7.9069E-1, 7.6482E-1,&
     & 7.9752E-1, 8.1003E-1, 8.2276E-1, 8.2943E-1, 8.3278E-1, 8.3330E-1,&
     & 8.3403E-1, 8.3454E-1, 8.3466E-1, 8.3473E-1, 8.3477E-1, 8.3471E-1,&
     & 8.3338E-1, 8.3247E-1, 8.1541E-1, 7.9249E-1, 7.4435E-1, 7.2051E-1,&
     & 7.0861E-1, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0048E+0, 1.0022E+0, 1.0015E+0,&
     & 1.0009E+0, 1.0007E+0, 1.0005E+0, 1.0005E+0, 1.0005E+0, 1.0004E+0,&
     & 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0004E+0, 1.0003E+0, 1.0003E+0,&
     & 1.0002E+0, 1.0001E+0, 1.0000E+0, 9.9996E-1, 9.9995E-1, 1.0894E+0,&
     & 1.0418E+0, 1.0282E+0, 1.0173E+0, 1.0124E+0, 1.0098E+0, 1.0094E+0,&
     & 1.0086E+0, 1.0080E+0, 1.0077E+0, 1.0076E+0, 1.0075E+0, 1.0067E+0,&
     & 1.0057E+0, 1.0053E+0, 1.0032E+0, 1.0019E+0, 9.9998E-1, 9.9934E-1,&
     & 9.9913E-1, 1.4350E+0, 1.2261E+0, 1.1533E+0, 1.0928E+0, 1.0652E+0,&
     & 1.0508E+0, 1.0482E+0, 1.0441E+0, 1.0404E+0, 1.0392E+0/           
      DATA X2001/ 1.0383E+0, 1.0377E+0, 1.0332E+0, 1.0278E+0, 1.0261E+0,&
     & 1.0154E+0, 1.0092E+0, 1.0000E+0, 9.9673E-1, 9.9564E-1, 1.8875E+0,&
     & 1.5032E+0, 1.3564E+0, 1.2131E+0, 1.1467E+0, 1.1120E+0, 1.1059E+0,&
     & 1.0962E+0, 1.0873E+0, 1.0844E+0, 1.0824E+0, 1.0808E+0, 1.0704E+0,&
     & 1.0579E+0, 1.0540E+0, 1.0315E+0, 1.0192E+0, 1.0003E+0, 9.9314E-1,&
     & 9.9067E-1, 3.0813E+0, 2.2584E+0, 1.9265E+0, 1.5765E+0, 1.3846E+0,&
     & 1.2841E+0, 1.2666E+0, 1.2385E+0, 1.2132E+0, 1.2049E+0, 1.1993E+0,&
     & 1.1949E+0, 1.1657E+0, 1.1318E+0, 1.1216E+0, 1.0685E+0, 1.0436E+0,&
     & 1.0018E+0, 9.8405E-1, 9.7748E-1, 5.4106E+0, 3.7469E+0, 3.0595E+0,&
     & 2.3118E+0, 1.8775E+0, 1.6278E+0, 1.5844E+0, 1.5151E+0, 1.4530E+0,&
     & 1.4327E+0, 1.4189E+0, 1.4083E+0, 1.3378E+0, 1.2580E+0, 1.2347E+0,&
     & 1.1267E+0, 1.0850E+0, 1.0058E+0, 9.6732E-1, 9.5209E-1, 7.2605E+0,&
     & 4.9717E+0, 4.0132E+0, 2.9533E+0, 2.3200E+0, 1.9406E+0, 1.8719E+0,&
     & 1.7627E+0, 1.6650E+0, 1.6330E+0, 1.6114E+0, 1.5948E+0, 1.4847E+0,&
     & 1.3616E+0, 1.3262E+0, 1.1713E+0, 1.1187E+0, 1.0094E+0, 9.5214E-1,&
     & 9.2874E-1, 8.9663E+0, 6.0393E+0, 4.8140E+0, 3.4599E+0, 2.6514E+0,&
     & 2.1675E+0, 2.0800E+0, 1.9410E+0, 1.8167E+0, 1.7761E+0/           
      DATA X2101/ 1.7486E+0, 1.7276E+0, 1.5881E+0, 1.4331E+0, 1.3888E+0,&
     & 1.2012E+0, 1.1420E+0, 1.0118E+0, 9.4075E-1, 9.1130E-1, 9.4468E+0,&
     & 6.4137E+0, 5.1335E+0, 3.7047E+0, 2.8376E+0, 2.3067E+0, 2.2089E+0,&
     & 2.0511E+0, 1.9102E+0, 1.8641E+0, 1.8330E+0, 1.8092E+0, 1.6513E+0,&
     & 1.4764E+0, 1.4266E+0, 1.2190E+0, 1.1561E+0, 1.0132E+0, 9.3345E-1,&
     & 9.0019E-1, 1.1490E+1, 7.7903E+0, 6.2180E+0, 4.4502E+0, 3.3628E+0,&
     & 2.6858E+0, 2.5591E+0, 2.3529E+0, 2.1657E+0, 2.1046E+0, 2.0633E+0,&
     & 2.0316E+0, 1.8228E+0, 1.5928E+0, 1.5279E+0, 1.2664E+0, 1.1942E+0,&
     & 1.0160E+0, 9.1204E-1, 8.6811E-1, 1.3039E+1, 8.8435E+0, 7.0549E+0,&
     & 5.0334E+0, 3.7803E+0, 2.9909E+0, 2.8420E+0, 2.5983E+0, 2.3747E+0,&
     & 2.3010E+0, 2.2513E+0, 2.2132E+0, 1.9621E+0, 1.6869E+0, 1.6096E+0,&
     & 1.3050E+0, 1.2255E+0, 1.0172E+0, 8.9248E-1, 8.3949E-1, 1.4395E+1,&
     & 9.7539E+0, 7.7781E+0, 5.5251E+0, 4.1282E+0, 3.2435E+0, 3.0759E+0,&
     & 2.8005E+0, 2.5470E+0, 2.4632E+0, 2.4065E+0, 2.3630E+0, 2.0771E+0,&
     & 1.7646E+0, 1.6772E+0, 1.3378E+0, 1.2522E+0, 1.0171E+0, 8.7433E-1,&
     & 8.1356E-1, 1.5832E+1, 1.0684E+1, 8.4883E+0, 5.9939E+0, 4.4456E+0,&
     & 3.4658E+0, 3.2801E+0, 2.9754E+0, 2.6950E+0, 2.6024E+0/           
      DATA X2201/ 2.5397E+0, 2.4917E+0, 2.1761E+0, 1.8321E+0, 1.7362E+0,&
     & 1.3681E+0, 1.2766E+0, 1.0160E+0, 8.5653E-1, 7.8870E-1, 1.5982E+1,&
     & 1.0883E+1, 8.6927E+0, 6.1945E+0, 4.6250E+0, 3.6200E+0, 3.4277E+0,&
     & 3.1100E+0, 2.8143E+0, 2.7156E+0, 2.6485E+0, 2.5969E+0, 2.2577E+0,&
     & 1.8891E+0, 1.7867E+0, 1.3968E+0, 1.2996E+0, 1.0141E+0, 8.3930E-1,&
     & 7.6513E-1, 1.2185E+1, 8.7361E+0, 7.2201E+0, 5.4461E+0, 4.2877E+0,&
     & 3.5109E+0, 3.3569E+0, 3.0968E+0, 2.8461E+0, 2.7598E+0, 2.7003E+0,&
     & 2.6539E+0, 2.3309E+0, 1.9471E+0, 1.8410E+0, 1.4406E+0, 1.3348E+0,&
     & 1.0118E+0, 8.1665E-1, 7.3460E-1, 1.0317E+1, 7.4701E+0, 6.2199E+0,&
     & 4.7584E+0, 3.8056E+0, 3.1677E+0, 3.0414E+0, 2.8283E+0, 2.6230E+0,&
     & 2.5525E+0, 2.5039E+0, 2.4659E+0, 2.2025E+0, 1.8915E+0, 1.8065E+0,&
     & 1.4855E+0, 1.3773E+0, 1.0356E+0, 8.3779E-1, 7.5559E-1, 1.1332E+1,&
     & 7.8483E+0, 6.3568E+0, 4.6624E+0, 3.6045E+0, 2.9321E+0, 2.8042E+0,&
     & 2.5939E+0, 2.3992E+0, 2.3347E+0, 2.2909E+0, 2.2573E+0, 2.0394E+0,&
     & 1.8093E+0, 1.7471E+0, 1.5101E+0, 1.4082E+0, 1.0804E+0, 8.9516E-1,&
     & 8.1742E-1, 9.8936E+0, 6.9156E+0, 5.6416E+0, 4.1958E+0, 3.2940E+0,&
     & 2.7222E+0, 2.6136E+0, 2.4351E+0, 2.2703E+0, 2.2157E+0/           
      DATA X2301/ 2.1787E+0, 2.1503E+0, 1.9668E+0, 1.7745E+0, 1.7229E+0,&
     & 1.5243E+0, 1.4261E+0, 1.1082E+0, 9.2992E-1, 8.5433E-1, 9.0742E+0,&
     & 6.3281E+0, 5.1646E+0, 3.8494E+0, 3.0432E+0, 2.5394E+0, 2.4452E+0,&
     & 2.2916E+0, 2.1520E+0, 2.1064E+0, 2.0758E+0, 2.0525E+0, 1.9020E+0,&
     & 1.7458E+0, 1.7042E+0, 1.5413E+0, 1.4466E+0, 1.1395E+0, 9.6835E-1,&
     & 8.9473E-1, 7.9102E+0, 5.5625E+0, 4.5710E+0, 3.4619E+0, 2.7844E+0,&
     & 2.3652E+0, 2.2876E+0, 2.1617E+0, 2.0483E+0, 2.0116E+0, 1.9871E+0,&
     & 1.9684E+0, 1.8486E+0, 1.7254E+0, 1.6928E+0, 1.5613E+0, 1.4694E+0,&
     & 1.1732E+0, 1.0089E+0, 9.3697E-1, 6.6172E+0, 4.7507E+0, 3.9607E+0,&
     & 3.0798E+0, 2.5430E+0, 2.2122E+0, 2.1511E+0, 2.0523E+0, 1.9635E+0,&
     & 1.9349E+0, 1.9158E+0, 1.9013E+0, 1.8086E+0, 1.7144E+0, 1.6896E+0,&
     & 1.5839E+0, 1.4937E+0, 1.2077E+0, 1.0498E+0, 9.7935E-1, 5.7227E+0,&
     & 4.1309E+0, 3.4680E+0, 2.7401E+0, 2.3103E+0, 2.0571E+0, 2.0119E+0,&
     & 1.9410E+0, 1.8803E+0, 1.8611E+0, 1.8483E+0, 1.8386E+0, 1.7772E+0,&
     & 1.7155E+0, 1.6992E+0, 1.6182E+0, 1.5278E+0, 1.2542E+0, 1.1044E+0,&
     & 1.0355E+0, 5.4473E+0, 3.9268E+0, 3.2999E+0, 2.6207E+0, 2.2287E+0,&
     & 2.0054E+0, 1.9669E+0, 1.9077E+0, 1.8573E+0, 1.8414E+0/           
      DATA X2401/ 1.8309E+0, 1.8229E+0, 1.7722E+0, 1.7213E+0, 1.7078E+0,&
     & 1.6330E+0, 1.5415E+0, 1.2722E+0, 1.1255E+0, 1.0574E+0, 4.5610E+0,&
     & 3.4035E+0, 2.9271E+0, 2.4115E+0, 2.1149E+0, 1.9468E+0, 1.9180E+0,&
     & 1.8738E+0, 1.8363E+0, 1.8245E+0, 1.8167E+0, 1.8108E+0, 1.7732E+0,&
     & 1.7350E+0, 1.7246E+0, 1.6539E+0, 1.5593E+0, 1.2956E+0, 1.1536E+0,&
     & 1.0866E+0, 3.8564E+0, 2.9649E+0, 2.6041E+0, 2.2223E+0, 2.0113E+0,&
     & 1.8993E+0, 1.8814E+0, 1.8540E+0, 1.8307E+0, 1.8233E+0, 1.8183E+0,&
     & 1.8146E+0, 1.7903E+0, 1.7635E+0, 1.7552E+0, 1.6791E+0, 1.5767E+0,&
     & 1.3197E+0, 1.1850E+0, 1.1204E+0, 3.0474E+0, 2.5075E+0, 2.2929E+0,&
     & 2.0712E+0, 1.9544E+0, 1.8976E+0, 1.8878E+0, 1.8720E+0, 1.8574E+0,&
     & 1.8524E+0, 1.8490E+0, 1.8463E+0, 1.8271E+0, 1.7996E+0, 1.7891E+0,&
     & 1.6788E+0, 1.5584E+0, 1.3117E+0, 1.1922E+0, 1.1349E+0, 2.7443E+0,&
     & 2.3495E+0, 2.1944E+0, 2.0368E+0, 1.9566E+0, 1.9059E+0, 1.8957E+0,&
     & 1.8779E+0, 1.8598E+0, 1.8533E+0, 1.8487E+0, 1.8451E+0, 1.8174E+0,&
     & 1.7743E+0, 1.7574E+0, 1.5981E+0, 1.4611E+0, 1.2338E+0, 1.1379E+0,&
     & 1.0944E+0, 2.6586E+0, 2.2995E+0, 2.1605E+0, 2.0222E+0, 1.9347E+0,&
     & 1.8718E+0, 1.8585E+0, 1.8350E+0, 1.8108E+0, 1.8020E+0/           
      DATA X2501/ 1.7958E+0, 1.7908E+0, 1.7533E+0, 1.6955E+0, 1.6734E+0,&
     & 1.4804E+0, 1.3370E+0, 1.1353E+0, 1.0637E+0, 1.0348E+0, 2.5410E+0,&
     & 2.2242E+0, 2.0830E+0, 1.9041E+0, 1.7741E+0, 1.6774E+0, 1.6569E+0,&
     & 1.6209E+0, 1.5842E+0, 1.5710E+0, 1.5617E+0, 1.5543E+0, 1.4992E+0,&
     & 1.4175E+0, 1.3873E+0, 1.1544E+0, 1.0180E+0, 8.9205E-1, 8.7875E-1,&
     & 8.8436E-1, 1.0001E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0021E+0, 1.0010E+0, 1.0008E+0,&
     & 1.0005E+0, 1.0004E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0003E+0,&
     & 1.0003E+0, 1.0003E+0, 1.0003E+0, 1.0002E+0, 1.0002E+0, 1.0002E+0,&
     & 1.0001E+0, 1.0001E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0388E+0,&
     & 1.0190E+0, 1.0138E+0, 1.0095E+0, 1.0073E+0, 1.0060E+0, 1.0058E+0,&
     & 1.0054E+0, 1.0050E+0, 1.0049E+0, 1.0048E+0, 1.0047E+0, 1.0042E+0,&
     & 1.0035E+0, 1.0033E+0, 1.0017E+0, 1.0009E+0, 1.0003E+0, 1.0003E+0,&
     & 1.0004E+0, 1.2030E+0, 1.1095E+0, 1.0772E+0, 1.0509E+0, 1.0383E+0,&
     & 1.0312E+0, 1.0298E+0, 1.0277E+0, 1.0256E+0, 1.0249E+0/           
      DATA X2601/ 1.0244E+0, 1.0240E+0, 1.0213E+0, 1.0177E+0, 1.0165E+0,&
     & 1.0085E+0, 1.0044E+0, 1.0014E+0, 1.0016E+0, 1.0021E+0, 1.4644E+0,&
     & 1.2664E+0, 1.1914E+0, 1.1191E+0, 1.0867E+0, 1.0692E+0, 1.0660E+0,&
     & 1.0608E+0, 1.0559E+0, 1.0542E+0, 1.0531E+0, 1.0522E+0, 1.0460E+0,&
     & 1.0380E+0, 1.0353E+0, 1.0179E+0, 1.0094E+0, 1.0027E+0, 1.0031E+0,&
     & 1.0043E+0, 2.3993E+0, 1.8237E+0, 1.5959E+0, 1.3619E+0, 1.2401E+0,&
     & 1.1824E+0, 1.1725E+0, 1.1565E+0, 1.1421E+0, 1.1373E+0, 1.1340E+0,&
     & 1.1314E+0, 1.1140E+0, 1.0924E+0, 1.0854E+0, 1.0425E+0, 1.0220E+0,&
     & 1.0055E+0, 1.0065E+0, 1.0096E+0, 5.9112E+0, 3.8402E+0, 3.0132E+0,&
     & 2.1533E+0, 1.6944E+0, 1.4658E+0, 1.4319E+0, 1.3805E+0, 1.3364E+0,&
     & 1.3222E+0, 1.3127E+0, 1.3054E+0, 1.2573E+0, 1.2016E+0, 1.1845E+0,&
     & 1.0872E+0, 1.0438E+0, 1.0090E+0, 1.0117E+0, 1.0193E+0, 1.1535E+1,&
     & 7.0962E+0, 5.3075E+0, 3.4246E+0, 2.3951E+0, 1.8590E+0, 1.7750E+0,&
     & 1.6563E+0, 1.5620E+0, 1.5330E+0, 1.5139E+0, 1.4995E+0, 1.4076E+0,&
     & 1.3088E+0, 1.2797E+0, 1.1253E+0, 1.0613E+0, 1.0115E+0, 1.0162E+0,&
     & 1.0282E+0, 2.5310E+1, 1.4540E+1, 1.0253E+1, 5.8156E+0, 3.4680E+0,&
     & 2.3182E+0, 2.1518E+0, 1.9341E+0, 1.7743E+0, 1.7274E+0/           
      DATA X2701/ 1.6969E+0, 1.6742E+0, 1.5346E+0, 1.3934E+0, 1.3535E+0,&
     & 1.1518E+0, 1.0729E+0, 1.0134E+0, 1.0198E+0, 1.0349E+0, 2.8616E+1,&
     & 1.6758E+1, 1.1974E+1, 6.9293E+0, 4.1625E+0, 2.7134E+0, 2.4851E+0,&
     & 2.1601E+0, 1.9367E+0, 1.8734E+0, 1.8328E+0, 1.8027E+0, 1.6232E+0,&
     & 1.4494E+0, 1.4016E+0, 1.1677E+0, 1.0796E+0, 1.0146E+0, 1.0221E+0,&
     & 1.0393E+0, 7.1292E+1, 4.0976E+1, 2.8705E+1, 1.5714E+1, 8.5305E+0,&
     & 4.7162E+0, 4.1055E+0, 3.2233E+0, 2.5950E+0, 2.4419E+0, 2.3486E+0,&
     & 2.2818E+0, 1.9196E+0, 1.6190E+0, 1.5435E+0, 1.2092E+0, 1.0967E+0,&
     & 1.0189E+0, 1.0296E+0, 1.0522E+0, 1.5421E+2, 8.8117E+1, 6.1303E+1,&
     & 3.2824E+1, 1.6986E+1, 8.4905E+0, 7.1150E+0, 5.1084E+0, 3.6450E+0,&
     & 3.2753E+0, 3.0671E+0, 2.9253E+0, 2.2461E+0, 1.7769E+0, 1.6700E+0,&
     & 1.2398E+0, 1.1091E+0, 1.0236E+0, 1.0372E+0, 1.0640E+0, 3.8005E+2,&
     & 2.1525E+2, 1.4846E+2, 7.7629E+1, 3.8337E+1, 1.7356E+1, 1.3976E+1,&
     & 9.0655E+0, 5.5212E+0, 4.6396E+0, 4.1498E+0, 3.8418E+0, 2.5998E+0,&
     & 1.9165E+0, 1.7765E+0, 1.2609E+0, 1.1179E+0, 1.0290E+0, 1.0448E+0,&
     & 1.0747E+0, 1.6814E+3, 9.3588E+2, 6.3561E+2, 3.1971E+2, 1.4719E+2,&
     & 5.7537E+1, 4.3540E+1, 2.3777E+1, 1.0491E+1, 7.5571E+0/           
      DATA X2801/ 6.1083E+0, 5.3371E+0, 2.9758E+0, 2.0285E+0, 1.8565E+0,&
     & 1.2737E+0, 1.1243E+0, 1.0354E+0, 1.0530E+0, 1.0848E+0, 2.4749E+3,&
     & 1.4072E+3, 9.7240E+2, 5.0832E+2, 2.4779E+2, 1.0588E+2, 8.2499E+1,&
     & 4.7898E+1, 2.1804E+1, 1.4891E+1, 1.0843E+1, 8.1389E+0, 3.2791E+0,&
     & 2.0772E+0, 1.8853E+0, 1.2767E+0, 1.1284E+0, 1.0433E+0, 1.0617E+0,&
     & 1.0939E+0, 4.2100E+1, 2.7494E+1, 2.1218E+1, 1.4060E+1, 9.5637E+0,&
     & 6.6849E+0, 6.1341E+0, 5.2240E+0, 4.3769E+0, 4.0942E+0, 3.9020E+0,&
     & 3.7541E+0, 2.7828E+0, 1.8707E+0, 1.7321E+0, 1.2602E+0, 1.1333E+0,&
     & 1.0618E+0, 1.0761E+0, 1.1026E+0, 2.9795E+1, 1.9595E+1, 1.5213E+1,&
     & 1.0218E+1, 7.0813E+0, 5.0745E+0, 4.6907E+0, 4.0568E+0, 3.4671E+0,&
     & 3.2705E+0, 3.1367E+0, 3.0338E+0, 2.3590E+0, 1.7283E+0, 1.6342E+0,&
     & 1.2737E+0, 1.1634E+0, 1.0878E+0, 1.0664E+0, 1.0604E+0, 1.2260E+3,&
     & 6.9769E+2, 4.8252E+2, 2.5280E+2, 1.2379E+2, 5.3476E+1, 4.1886E+1,&
     & 2.4722E+1, 1.1763E+1, 8.3237E+0, 6.3074E+0, 4.9585E+0, 2.4658E+0,&
     & 1.8284E+0, 1.7195E+0, 1.3033E+0, 1.1800E+0, 1.0720E+0, 1.0091E+0,&
     & 9.6860E-1, 2.7100E+2, 1.5646E+2, 1.0960E+2, 5.9286E+1, 3.0730E+1,&
     & 1.4895E+1, 1.2237E+1, 8.2406E+0, 5.1224E+0, 4.2584E+0/           
      DATA X2901/ 3.7351E+0, 3.3729E+0, 2.2630E+0, 1.7959E+0, 1.7020E+0,&
     & 1.3050E+0, 1.1787E+0, 1.0525E+0, 9.6912E-1, 9.1171E-1, 1.5625E+2,&
     & 8.8969E+1, 6.1702E+1, 3.2767E+1, 1.6711E+1, 8.1280E+0, 6.7437E+0,&
     & 4.7310E+0, 3.2750E+0, 2.9116E+0, 2.7091E+0, 2.5813E+0, 2.0555E+0,&
     & 1.7347E+0, 1.6589E+0, 1.2977E+0, 1.1713E+0, 1.0279E+0, 9.2782E-1,&
     & 8.6088E-1, 5.6133E+1, 3.2605E+1, 2.3049E+1, 1.2890E+1, 7.2266E+0,&
     & 4.1761E+0, 3.6800E+0, 2.9536E+0, 2.4190E+0, 2.2822E+0, 2.2043E+0,&
     & 2.1506E+0, 1.8818E+0, 1.6628E+0, 1.6030E+0, 1.2833E+0, 1.1593E+0,&
     & 1.0022E+0, 8.9417E-1, 8.3050E-1, 1.7852E+1, 1.1087E+1, 8.3108E+0,&
     & 5.3147E+0, 3.5979E+0, 2.6305E+0, 2.4657E+0, 2.2148E+0, 2.0138E+0,&
     & 1.9563E+0, 1.9207E+0, 1.8948E+0, 1.7444E+0, 1.5902E+0, 1.5430E+0,&
     & 1.2639E+0, 1.1448E+0, 9.7998E-1, 8.7436E-1, 8.2197E-1, 8.8059E+0,&
     & 5.7183E+0, 4.4618E+0, 3.1222E+0, 2.3717E+0, 1.9643E+0, 1.8974E+0,&
     & 1.7987E+0, 1.7248E+0, 1.7020E+0, 1.6867E+0, 1.6750E+0, 1.5959E+0,&
     & 1.4941E+0, 1.4593E+0, 1.2323E+0, 1.1234E+0, 9.6116E-1, 8.7030E-1,&
     & 8.3203E-1, 6.7251E+0, 4.4661E+0, 3.5553E+0, 2.5965E+0, 2.0719E+0,&
     & 1.7984E+0, 1.7556E+0, 1.6948E+0, 1.6435E+0, 1.6267E+0/           
      DATA X3001/ 1.6151E+0, 1.6061E+0, 1.5424E+0, 1.4551E+0, 1.4244E+0,&
     & 1.2180E+0, 1.1147E+0, 9.5858E-1, 8.7541E-1, 8.4091E-1, 3.1248E+0,&
     & 2.4974E+0, 2.2309E+0, 1.9315E+0, 1.7479E+0, 1.6339E+0, 1.6126E+0,&
     & 1.5779E+0, 1.5445E+0, 1.5327E+0, 1.5244E+0, 1.5179E+0, 1.4694E+0,&
     & 1.3988E+0, 1.3733E+0, 1.1964E+0, 1.1032E+0, 9.6131E-1, 8.8939E-1,&
     & 8.5867E-1, 1.7967E+0, 1.7026E+0, 1.6517E+0, 1.5797E+0, 1.5209E+0,&
     & 1.4724E+0, 1.4615E+0, 1.4415E+0, 1.4201E+0, 1.4123E+0, 1.4067E+0,&
     & 1.4022E+0, 1.3681E+0, 1.3169E+0, 1.2982E+0, 1.1649E+0, 1.0919E+0,&
     & 9.8176E-1, 9.2580E-1, 8.9905E-1, 1.2556E+0, 1.3245E+0, 1.3406E+0,&
     & 1.3411E+0, 1.3239E+0, 1.2989E+0, 1.2927E+0, 1.2814E+0, 1.2694E+0,&
     & 1.2650E+0, 1.2619E+0, 1.2594E+0, 1.2408E+0, 1.2137E+0, 1.2040E+0,&
     & 1.1396E+0, 1.1088E+0, 1.0613E+0, 1.0289E+0, 1.0085E+0, 1.1281E+0,&
     & 1.1966E+0, 1.2154E+0, 1.2225E+0, 1.2132E+0, 1.2032E+0, 1.2010E+0,&
     & 1.1972E+0, 1.1935E+0, 1.1922E+0, 1.1913E+0, 1.1906E+0, 1.1859E+0,&
     & 1.1806E+0, 1.1792E+0, 1.1831E+0, 1.1987E+0, 1.2156E+0, 1.2038E+0,&
     & 1.1887E+0, 1.0731E+0, 1.1433E+0, 1.1645E+0, 1.1767E+0, 1.1823E+0,&
     & 1.1874E+0, 1.1887E+0, 1.1913E+0, 1.1943E+0, 1.1955E+0/           
      DATA X3101/ 1.1964E+0, 1.1971E+0, 1.2032E+0, 1.2147E+0, 1.2198E+0,&
     & 1.2778E+0, 1.3317E+0, 1.3967E+0, 1.3944E+0, 1.3782E+0, 1.0280E+0,&
     & 1.0961E+0, 1.1322E+0, 1.1881E+0, 1.2378E+0, 1.2810E+0, 1.2909E+0,&
     & 1.3090E+0, 1.3284E+0, 1.3357E+0, 1.3408E+0, 1.3450E+0, 1.3776E+0,&
     & 1.4309E+0, 1.4523E+0, 1.6545E+0, 1.8096E+0, 1.9601E+0, 1.9369E+0,&
     & 1.8899E+0, 9.9995E-1, 9.9997E-1, 9.9998E-1, 9.9999E-1, 9.9999E-1,&
     & 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1, 9.9999E-1,&
     & 9.9999E-1, 9.9999E-1, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0,&
     & 1.0000E+0, 1.0000E+0, 1.0000E+0, 9.9899E-1, 9.9947E-1, 9.9961E-1,&
     & 9.9973E-1, 9.9979E-1, 9.9983E-1, 9.9984E-1, 9.9985E-1, 9.9986E-1,&
     & 9.9987E-1, 9.9987E-1, 9.9987E-1, 9.9989E-1, 9.9991E-1, 9.9992E-1,&
     & 9.9997E-1, 1.0000E+0, 1.0000E+0, 1.0000E+0, 1.0000E+0, 9.8137E-1,&
     & 9.9042E-1, 9.9289E-1, 9.9509E-1, 9.9626E-1, 9.9698E-1, 9.9712E-1,&
     & 9.9735E-1, 9.9758E-1, 9.9765E-1, 9.9771E-1, 9.9775E-1, 9.9805E-1,&
     & 9.9847E-1, 9.9861E-1, 9.9954E-1, 9.9997E-1, 1.0003E+0, 1.0005E+0,&
     & 1.0006E+0, 9.0399E-1, 9.4672E-1, 9.6174E-1, 9.7445E-1, 9.8089E-1,&
     & 9.8470E-1, 9.8542E-1, 9.8663E-1, 9.8779E-1, 9.8819E-1/           
      DATA X3201/ 9.8847E-1, 9.8869E-1, 9.9024E-1, 9.9232E-1, 9.9303E-1,&
     & 9.9771E-1, 9.9988E-1, 1.0017E+0, 1.0024E+0, 1.0030E+0, 7.9365E-1,&
     & 8.7812E-1, 9.1067E-1, 9.4281E-1, 9.5815E-1, 9.6687E-1, 9.6850E-1,&
     & 9.7121E-1, 9.7378E-1, 9.7467E-1, 9.7528E-1, 9.7576E-1, 9.7914E-1,&
     & 9.8364E-1, 9.8517E-1, 9.9516E-1, 9.9980E-1, 1.0035E+0, 1.0048E+0,&
     & 1.0060E+0, 4.8488E-1, 6.8302E-1, 7.6304E-1, 8.4750E-1, 8.9392E-1,&
     & 9.1832E-1, 9.2272E-1, 9.2991E-1, 9.3663E-1, 9.3890E-1, 9.4047E-1,&
     & 9.4169E-1, 9.5025E-1, 9.6134E-1, 9.6505E-1, 9.8889E-1, 9.9986E-1,&
     & 1.0081E+0, 1.0105E+0, 1.0130E+0,-2.2221E-1, 2.4219E-1, 4.3268E-1,&
     & 6.3798E-1, 7.5526E-1, 8.2097E-1, 8.3212E-1, 8.4992E-1, 8.6608E-1,&
     & 8.7146E-1, 8.7514E-1, 8.7798E-1, 8.9754E-1, 9.2198E-1, 9.2996E-1,&
     & 9.7927E-1, 1.0011E+0, 1.0161E+0, 1.0200E+0, 1.0247E+0,-9.1748E-1,&
     &-1.9852E-1, 9.9380E-2, 4.2484E-1, 6.1519E-1, 7.2575E-1, 7.4519E-1,&
     & 7.7548E-1, 8.0224E-1, 8.1100E-1, 8.1695E-1, 8.2153E-1, 8.5249E-1,&
     & 8.8997E-1, 9.0193E-1, 9.7317E-1, 1.0033E+0, 1.0233E+0, 1.0285E+0,&
     & 1.0353E+0,-1.9063E+0,-7.7127E-1,-3.0516E-1, 1.9806E-1, 4.8636E-1,&
     & 6.4863E-1, 6.7629E-1, 7.1838E-1, 7.5466E-1, 7.6638E-1/           
      DATA X3301/ 7.7427E-1, 7.8034E-1, 8.2076E-1, 8.6851E-1, 8.8349E-1,&
     & 9.7018E-1, 1.0055E+0, 1.0286E+0, 1.0352E+0, 1.0435E+0,-2.1276E+0,&
     &-9.3918E-1,-4.4565E-1, 9.4500E-2, 4.1164E-1, 5.9690E-1, 6.2964E-1,&
     & 6.8087E-1, 7.2418E-1, 7.3801E-1, 7.4729E-1, 7.5440E-1, 8.0137E-1,&
     & 8.5592E-1, 8.7284E-1, 9.6893E-1, 1.0072E+0, 1.0321E+0, 1.0396E+0,&
     & 1.0489E+0,-3.9099E+0,-2.0213E+0,-1.2365E+0,-3.7584E-1, 1.3081E-1,&
     & 4.2790E-1, 4.8060E-1, 5.6328E-1, 6.3353E-1, 6.5500E-1, 6.6920E-1,&
     & 6.7995E-1, 7.4871E-1, 8.2428E-1, 8.4689E-1, 9.6812E-1, 1.0130E+0,&
     & 1.0427E+0, 1.0533E+0, 1.0651E+0,-6.2065E+0,-3.3984E+0,-2.2312E+0,&
     &-9.5166E-1,-1.9945E-1, 2.4097E-1, 3.1905E-1, 4.4142E-1, 5.4519E-1,&
     & 5.7686E-1, 5.9732E-1, 6.1258E-1, 7.0616E-1, 8.0260E-1, 8.3034E-1,&
     & 9.7102E-1, 1.0196E+0, 1.0531E+0, 1.0665E+0, 1.0795E+0,-1.0300E+1,&
     &-5.7834E+0,-3.9141E+0,-1.8782E+0,-6.9183E-1,-7.6294E-3, 1.1198E-1,&
     & 2.9752E-1, 4.5183E-1, 4.9794E-1, 5.2733E-1, 5.4872E-1, 6.7238E-1,&
     & 7.8986E-1, 8.2219E-1, 9.7700E-1, 1.0270E+0, 1.0632E+0, 1.0783E+0,&
     & 1.0911E+0,-2.2823E+1,-1.2850E+1,-8.7693E+0,-4.3879E+0,-1.9009E+0,&
     &-5.2179E-1,-2.9022E-1, 5.7934E-2, 3.2966E-1, 4.0498E-1/           
      DATA X3401/ 4.5061E-1, 4.8220E-1, 6.4749E-1, 7.8698E-1, 8.2327E-1,&
     & 9.8632E-1, 1.0355E+0, 1.0728E+0, 1.0879E+0, 1.0986E+0,-3.0690E+1,&
     &-1.7605E+1,-1.2215E+1,-6.3749E+0,-3.0060E+0,-1.0898E+0,-7.5972E-1,&
     &-2.5319E-1, 1.5914E-1, 2.7938E-1, 3.5483E-1, 4.0892E-1, 6.3934E-1,&
     & 7.9919E-1, 8.3770E-1, 9.9907E-1, 1.0445E+0, 1.0801E+0, 1.0921E+0,&
     & 1.0976E+0,-4.1662E+0,-2.3827E+0,-1.6106E+0,-7.2214E-1,-1.5660E-1,&
     & 2.1152E-1, 2.8287E-1, 4.0174E-1, 5.1385E-1, 5.5169E-1, 5.7759E-1,&
     & 5.9762E-1, 7.3224E-1, 8.7243E-1, 9.0191E-1, 1.0202E+0, 1.0517E+0,&
     & 1.0719E+0, 1.0654E+0, 1.0511E+0,-4.2678E+0,-2.4680E+0,-1.6889E+0,&
     &-7.9283E-1,-2.2262E-1, 1.4837E-1, 2.2025E-1, 3.3997E-1, 4.5284E-1,&
     & 4.9094E-1, 5.1699E-1, 5.3715E-1, 6.7252E-1, 8.1312E-1, 8.4249E-1,&
     & 9.5252E-1, 9.7067E-1, 9.3913E-1, 8.7216E-1, 8.0202E-1,-2.4858E+1,&
     &-1.4277E+1,-9.9135E+0,-5.1801E+0,-2.4437E+0,-8.8201E-1,-6.1207E-1,&
     &-1.9683E-1, 1.4292E-1, 2.4258E-1, 3.0535E-1, 3.5052E-1, 5.4849E-1,&
     & 6.8950E-1, 7.2332E-1, 8.5215E-1, 8.6830E-1, 8.0971E-1, 7.1290E-1,&
     & 6.1490E-1,-1.1269E+1,-6.4783E+0,-4.4847E+0,-2.2967E+0,-1.0060E+0,&
     &-2.4679E-1,-1.1175E-1, 1.0053E-1, 2.8158E-1, 3.3715E-1/           
      DATA X3501/ 3.7317E-1, 3.9979E-1, 5.3969E-1, 6.5738E-1, 6.8736E-1,&
     & 8.0584E-1, 8.1934E-1, 7.5574E-1, 6.5690E-1, 5.5823E-1,-8.2710E+0,&
     &-4.6465E+0,-3.1460E+0,-1.5110E+0,-5.5795E-1,-7.4921E-3, 8.8806E-2,&
     & 2.3829E-1, 3.6280E-1, 4.0005E-1, 4.2383E-1, 4.4114E-1, 5.4123E-1,&
     & 6.3477E-1, 6.5968E-1, 7.6102E-1, 7.7139E-1, 7.1006E-1, 6.2009E-1,&
     & 5.3289E-1,-4.8132E+0,-2.6355E+0,-1.7302E+0,-7.3825E-1,-1.5549E-1,&
     & 1.8559E-1, 2.4602E-1, 3.4066E-1, 4.2087E-1, 4.4533E-1, 4.6112E-1,&
     & 4.7289E-1, 5.4460E-1, 6.1622E-1, 6.3589E-1, 7.1741E-1, 7.2523E-1,&
     & 6.7494E-1, 6.0529E-1, 5.4102E-1,-2.5701E+0,-1.3323E+0,-8.1348E-1,&
     &-2.3895E-1, 1.0429E-1, 3.1015E-1, 3.4747E-1, 4.0687E-1, 4.5875E-1,&
     & 4.7506E-1, 4.8579E-1, 4.9388E-1, 5.4471E-1, 5.9757E-1, 6.1236E-1,&
     & 6.7455E-1, 6.8152E-1, 6.5159E-1, 6.1156E-1, 5.7660E-1,-1.6172E+0,&
     &-7.3167E-1,-3.6578E-1, 3.2156E-2, 2.6322E-1, 3.9597E-1, 4.1907E-1,&
     & 4.5478E-1, 4.8429E-1, 4.9354E-1, 4.9969E-1, 5.0437E-1, 5.3439E-1,&
     & 5.6652E-1, 5.7564E-1, 6.1591E-1, 6.2640E-1, 6.3910E-1, 6.4784E-1,&
     & 6.5358E-1,-1.3500E+0,-5.5659E-1,-2.3260E-1, 1.1462E-1, 3.1091E-1,&
     & 4.1907E-1, 4.3711E-1, 4.6408E-1, 4.8671E-1, 4.9385E-1/           
      DATA X3601/ 4.9862E-1, 5.0224E-1, 5.2562E-1, 5.5082E-1, 5.5802E-1,&
     & 5.9177E-1, 6.0591E-1, 6.4057E-1, 6.6992E-1, 6.9071E-1,-6.3834E-1,&
     &-1.5919E-1, 3.7384E-2, 2.4930E-1, 3.7034E-1, 4.3815E-1, 4.4966E-1,&
     & 4.6710E-1, 4.8191E-1, 4.8661E-1, 4.8976E-1, 4.9215E-1, 5.0768E-1,&
     & 5.2464E-1, 5.2960E-1, 5.5768E-1, 5.7991E-1, 6.4929E-1, 7.0666E-1,&
     & 7.4627E-1,-1.9334E-1, 9.6268E-2, 2.1283E-1, 3.3532E-1, 4.0208E-1,&
     & 4.3665E-1, 4.4202E-1, 4.5025E-1, 4.5732E-1, 4.5959E-1, 4.6112E-1,&
     & 4.6229E-1, 4.7004E-1, 4.7935E-1, 4.8247E-1, 5.1254E-1, 5.5255E-1,&
     & 6.7301E-1, 7.6338E-1, 8.2295E-1, 1.8273E-1, 2.7804E-1, 3.1551E-1,&
     & 3.5361E-1, 3.7304E-1, 3.8185E-1, 3.8346E-1, 3.8621E-1, 3.8903E-1,&
     & 3.9006E-1, 3.9081E-1, 3.9141E-1, 3.9623E-1, 4.0506E-1, 4.0906E-1,&
     & 4.6302E-1, 5.3160E-1, 7.0021E-1, 8.1136E-1, 8.8111E-1, 2.3775E-1,&
     & 2.6168E-1, 2.7170E-1, 2.8278E-1, 2.8941E-1, 2.9613E-1, 2.9788E-1,&
     & 3.0128E-1, 3.0524E-1, 3.0678E-1, 3.0792E-1, 3.0885E-1, 3.1655E-1,&
     & 3.3072E-1, 3.3691E-1, 4.0804E-1, 4.8255E-1, 6.4216E-1, 7.3971E-1,&
     & 7.9922E-1, 1.8767E-1, 1.9485E-1, 1.9875E-1, 2.0427E-1, 2.1176E-1,&
     & 2.2018E-1, 2.2232E-1, 2.2640E-1, 2.3099E-1, 2.3276E-1/           
      DATA X3701/ 2.3404E-1, 2.3507E-1, 2.4345E-1, 2.5801E-1, 2.6409E-1,&
     & 3.2782E-1, 3.8874E-1, 5.1170E-1, 5.8428E-1, 6.2793E-1, 2.2107E-2,&
     & 2.2097E-2, 2.2678E-2, 2.4371E-2, 2.6300E-2, 2.8106E-2, 2.8529E-2,&
     & 2.9305E-2, 3.0142E-2, 3.0454E-2, 3.0677E-2, 3.0857E-2, 3.2261E-2,&
     & 3.4550E-2, 3.5465E-2, 4.4229E-2, 5.1890E-2, 6.6439E-2, 7.4683E-2,&
     & 7.9550E-2, 1.3189E-4, 1.5715E-4, 1.7070E-4, 1.8951E-4, 2.0449E-4,&
     & 2.1658E-4, 2.1927E-4, 2.2411E-4, 2.2922E-4, 2.3110E-4, 2.3245E-4,&
     & 2.3352E-4, 2.4185E-4, 2.5526E-4, 2.6060E-4, 3.1342E-4, 3.6462E-4,&
     & 4.9613E-4, 6.0151E-4, 6.8055E-4, 1.3182E-4, 1.5711E-4, 1.7067E-4,&
     & 1.8949E-4, 2.0447E-4, 2.1657E-4, 2.1926E-4, 2.2410E-4, 2.2921E-4,&
     & 2.3109E-4, 2.3244E-4, 2.3351E-4, 2.4184E-4, 2.5525E-4, 2.6060E-4,&
     & 3.1343E-4, 3.6463E-4, 4.9613E-4, 6.0151E-4, 6.8055E-4, 1.3072E-4,&
     & 1.5644E-4, 1.7015E-4, 1.8912E-4, 2.0420E-4, 2.1635E-4, 2.1906E-4,&
     & 2.2392E-4, 2.2905E-4, 2.3095E-4, 2.3230E-4, 2.3338E-4, 2.4174E-4,&
     & 2.5520E-4, 2.6056E-4, 3.1354E-4, 3.6483E-4, 4.9652E-4, 6.0190E-4,&
     & 6.8094E-4, 1.2638E-4, 1.5385E-4, 1.6812E-4, 1.8769E-4, 2.0315E-4,&
     & 2.1556E-4, 2.1831E-4, 2.2327E-4, 2.2849E-4, 2.3042E-4/           
      DATA X3801/ 2.3179E-4, 2.3289E-4, 2.4138E-4, 2.5504E-4, 2.6047E-4,&
     & 3.1402E-4, 3.6571E-4, 4.9805E-4, 6.0343E-4, 6.8246E-4, 1.2162E-4,&
     & 1.5075E-4, 1.6572E-4, 1.8603E-4, 2.0195E-4, 2.1469E-4, 2.1751E-4,&
     & 2.2258E-4, 2.2792E-4, 2.2988E-4, 2.3128E-4, 2.3240E-4, 2.4107E-4,&
     & 2.5497E-4, 2.6051E-4, 3.1480E-4, 3.6698E-4, 5.0011E-4, 6.0549E-4,&
     & 6.8453E-4, 1.1313E-4, 1.4503E-4, 1.6124E-4, 1.8305E-4, 1.9998E-4,&
     & 2.1342E-4, 2.1638E-4, 2.2171E-4, 2.2730E-4, 2.2936E-4, 2.3082E-4,&
     & 2.3200E-4, 2.4104E-4, 2.5551E-4, 2.6125E-4, 3.1724E-4, 3.7055E-4,&
     & 5.0523E-4, 6.1061E-4, 6.8965E-4, 1.0422E-4, 1.3940E-4, 1.5715E-4,&
     & 1.8087E-4, 1.9917E-4, 2.1361E-4, 2.1679E-4, 2.2248E-4, 2.2845E-4,&
     & 2.3064E-4, 2.3220E-4, 2.3345E-4, 2.4306E-4, 2.5837E-4, 2.6443E-4,&
     & 3.2300E-4, 3.7802E-4, 5.1436E-4, 6.1974E-4, 6.9878E-4, 1.0044E-4,&
     & 1.3773E-4, 1.5638E-4, 1.8138E-4, 2.0061E-4, 2.1575E-4, 2.1908E-4,&
     & 2.2503E-4, 2.3128E-4, 2.3356E-4, 2.3519E-4, 2.3650E-4, 2.4652E-4,&
     & 2.6245E-4, 2.6874E-4, 3.2925E-4, 3.8551E-4, 5.2252E-4, 6.2790E-4,&
     & 7.0693E-4, 9.9123E-5, 1.3773E-4, 1.5703E-4, 1.8284E-4, 2.0268E-4,&
     & 2.1827E-4, 2.2170E-4, 2.2783E-4, 2.3424E-4, 2.3660E-4/           
      DATA X3901/ 2.3827E-4, 2.3961E-4, 2.4990E-4, 2.6624E-4, 2.7269E-4,&
     & 3.3446E-4, 3.9151E-4, 5.2867E-4, 6.3405E-4, 7.1308E-4, 9.9145E-5,&
     & 1.3832E-4, 1.5802E-4, 1.8424E-4, 2.0440E-4, 2.2026E-4, 2.2374E-4,&
     & 2.2997E-4, 2.3649E-4, 2.3888E-4, 2.4058E-4, 2.4194E-4, 2.5239E-4,&
     & 2.6897E-4, 2.7551E-4, 3.3803E-4, 3.9552E-4, 5.3266E-4, 6.3804E-4,&
     & 7.1708E-4, 1.0097E-4, 1.4216E-4, 1.6269E-4, 1.9005E-4, 2.1107E-4,&
     & 2.2760E-4, 2.3123E-4, 2.3771E-4, 2.4450E-4, 2.4699E-4, 2.4876E-4,&
     & 2.5018E-4, 2.6105E-4, 2.7827E-4, 2.8504E-4, 3.4951E-4, 4.0807E-4,&
     & 5.4477E-4, 6.5015E-4, 7.2919E-4, 1.0592E-4, 1.4788E-4, 1.6922E-4,&
     & 1.9759E-4, 2.1937E-4, 2.3636E-4, 2.4010E-4, 2.4680E-4, 2.5380E-4,&
     & 2.5637E-4, 2.5819E-4, 2.5965E-4, 2.7085E-4, 2.8858E-4, 2.9555E-4,&
     & 3.6152E-4, 4.2076E-4, 5.5672E-4, 6.6210E-4, 7.4114E-4, 1.1349E-4,&
     & 1.5700E-4, 1.7810E-4, 2.0683E-4, 2.2918E-4, 2.4663E-4, 2.5045E-4,&
     & 2.5729E-4, 2.6446E-4, 2.6709E-4, 2.6896E-4, 2.7045E-4, 2.8193E-4,&
     & 3.0006E-4, 3.0719E-4, 3.7434E-4, 4.3393E-4, 5.6904E-4, 6.7442E-4,&
     & 7.5346E-4, 1.2207E-4, 1.6654E-4, 1.8883E-4, 2.1845E-4, 2.4146E-4,&
     & 2.5930E-4, 2.6322E-4, 2.7021E-4, 2.7754E-4, 2.8022E-4/           
      DATA X4001/ 2.8213E-4, 2.8365E-4, 2.9536E-4, 3.1385E-4, 3.2112E-4,&
     & 3.8918E-4, 4.4878E-4, 5.8303E-4, 6.8841E-4, 7.6745E-4, 1.3657E-4,&
     & 1.8168E-4, 2.0440E-4, 2.3451E-4, 2.5765E-4, 2.7577E-4, 2.7974E-4,&
     & 2.8686E-4, 2.9429E-4, 2.9702E-4, 2.9896E-4, 3.0050E-4, 3.1240E-4,&
     & 3.3118E-4, 3.3855E-4, 4.0720E-4, 4.6630E-4, 5.9987E-4, 7.0526E-4,&
     & 7.8429E-4, 1.7316E-4, 2.2025E-4, 2.4373E-4, 2.7480E-4, 2.9848E-4,&
     & 3.1700E-4, 3.2105E-4, 3.2829E-4, 3.3584E-4, 3.3861E-4, 3.4057E-4,&
     & 3.4214E-4, 3.5418E-4, 3.7314E-4, 3.8056E-4, 4.4870E-4, 5.0475E-4,&
     & 6.3907E-4, 7.4445E-4, 8.2349E-4, 2.7817E-4, 3.2346E-4, 3.4589E-4,&
     & 3.7545E-4, 3.9784E-4, 4.1528E-4, 4.1909E-4, 4.2588E-4, 4.3295E-4,&
     & 4.3553E-4, 4.3737E-4, 4.3884E-4, 4.5006E-4, 4.6766E-4, 4.7453E-4,&
     & 5.3469E-4, 5.7683E-4, 7.2654E-4, 8.3192E-4, 9.1095E-4, 3.8773E-4,&
     & 4.1956E-4, 4.3613E-4, 4.5877E-4, 4.7666E-4, 4.9104E-4, 4.9423E-4,&
     & 5.0000E-4, 5.0608E-4, 5.0832E-4, 5.0992E-4, 5.1120E-4, 5.2113E-4,&
     & 5.3687E-4, 5.4297E-4, 5.9324E-4, 6.2054E-4, 7.9278E-4, 8.9816E-4,&
     & 9.7719E-4, 4.3315E-4, 4.6181E-4, 4.7686E-4, 4.9757E-4, 5.1411E-4,&
     & 5.2740E-4, 5.3036E-4, 5.3573E-4, 5.4139E-4, 5.4349E-4/           
      DATA X4101/ 5.4498E-4, 5.4618E-4, 5.5547E-4, 5.7019E-4, 5.7587E-4,&
     & 6.2057E-4, 6.3967E-4, 8.2546E-4, 9.3084E-4, 1.0099E-3, 4.8542E-4,&
     & 5.0831E-4, 5.2202E-4, 5.3865E-4, 5.5349E-4, 5.6542E-4, 5.6808E-4,&
     & 5.7291E-4, 5.7811E-4, 5.8004E-4, 5.8142E-4, 5.8253E-4, 5.9116E-4,&
     & 6.0479E-4, 6.1000E-4, 6.4852E-4, 6.5858E-4, 8.5977E-4, 9.6515E-4,&
     & 1.0442E-3, 5.4073E-4, 5.5772E-4, 5.6684E-4, 5.8174E-4, 5.9432E-4,&
     & 6.0474E-4, 6.0716E-4, 6.1158E-4, 6.1632E-4, 6.1809E-4, 6.1937E-4,&
     & 6.2039E-4, 6.2834E-4, 6.4084E-4, 6.4556E-4, 6.7733E-4, 6.7753E-4,&
     & 8.9574E-4, 1.0011E-3, 1.0802E-3, 5.8937E-4, 6.0415E-4, 6.1208E-4,&
     & 6.2513E-4, 6.3634E-4, 6.4574E-4, 6.4794E-4, 6.5196E-4, 6.5628E-4,&
     & 6.5790E-4, 6.5907E-4, 6.6000E-4, 6.6728E-4, 6.7861E-4, 6.8282E-4,&
     & 7.0730E-4, 6.9686E-4, 9.3339E-4, 1.0388E-3, 1.1178E-3, 6.8802E-4,&
     & 6.8616E-4, 6.8789E-4, 6.9327E-4, 7.0002E-4, 7.0701E-4, 7.0875E-4,&
     & 7.1206E-4, 7.1580E-4, 7.1722E-4, 7.1824E-4, 7.1906E-4, 7.2541E-4,&
     & 7.3507E-4, 7.3851E-4, 7.5190E-4, 7.2534E-4, 9.8894E-4, 1.0943E-3,&
     & 1.1734E-3, 7.3922E-4, 7.2628E-4, 7.2359E-4, 7.2448E-4, 7.2884E-4,&
     & 7.3466E-4, 7.3624E-4, 7.3934E-4, 7.4285E-4, 7.4418E-4/           
      DATA X4201/ 7.4514E-4, 7.4591E-4, 7.5188E-4, 7.6079E-4, 7.6390E-4,&
     & 7.7220E-4, 7.3832E-4, 1.0138E-3, 1.1192E-3, 1.1982E-3, 7.8940E-4,&
     & 7.7415E-4, 7.7030E-4, 7.6978E-4, 7.7309E-4, 7.7811E-4, 7.7952E-4,&
     & 7.8231E-4, 7.8550E-4, 7.8671E-4, 7.8758E-4, 7.8828E-4, 7.9365E-4,&
     & 8.0143E-4, 8.0400E-4, 8.0429E-4, 7.5898E-4, 1.0522E-3, 1.1576E-3,&
     & 1.2366E-3, 9.1153E-4, 8.7286E-4, 8.5988E-4, 8.5004E-4, 8.4864E-4,&
     & 8.5159E-4, 8.5273E-4, 8.5506E-4, 8.5774E-4, 8.5875E-4, 8.5948E-4,&
     & 8.6007E-4, 8.6446E-4, 8.7032E-4, 8.7199E-4, 8.5879E-4, 7.9475E-4,&
     & 1.1148E-3, 1.2202E-3, 1.2992E-3, 1.1419E-3, 1.0535E-3, 1.0219E-3,&
     & 9.9432E-4, 9.8519E-4, 9.8595E-4, 9.8661E-4, 9.8803E-4, 9.8970E-4,&
     & 9.9033E-4, 9.9077E-4, 9.9112E-4, 9.9358E-4, 9.9570E-4, 9.9565E-4,&
     & 9.5827E-4, 8.6312E-4, 1.2202E-3, 1.3256E-3, 1.4046E-3, 1.4662E-3,&
     & 1.2729E-3, 1.2059E-3, 1.1509E-3, 1.1371E-3, 1.1343E-3, 1.1342E-3,&
     & 1.1342E-3, 1.1343E-3, 1.1343E-3, 1.1343E-3, 1.1343E-3, 1.1339E-3,&
     & 1.1311E-3, 1.1288E-3, 1.0657E-3, 9.4230E-4, 1.3236E-3, 1.4290E-3,&
     & 1.5081E-3, 1.7712E-3, 1.4379E-3, 1.3355E-3, 1.2728E-3, 1.2537E-3,&
     & 1.2469E-3, 1.2458E-3, 1.2442E-3, 1.2425E-3, 1.2419E-3/           
      DATA X4301/ 1.2415E-3, 1.2411E-3, 1.2379E-3, 1.2303E-3, 1.2262E-3,&
     & 1.1443E-3, 1.0043E-3, 1.3948E-3, 1.5002E-3, 1.5793E-3, 2.2867E-3,&
     & 1.7008E-3, 1.5820E-3, 1.4985E-3, 1.4643E-3, 1.4459E-3, 1.4424E-3,&
     & 1.4364E-3, 1.4302E-3, 1.4279E-3, 1.4263E-3, 1.4250E-3, 1.4148E-3,&
     & 1.3965E-3, 1.3884E-3, 1.2749E-3, 1.1171E-3, 1.5106E-3, 1.6160E-3,&
     & 1.6950E-3, 2.6282E-4, 3.1986E-4, 3.5203E-4, 3.9864E-4, 4.3744E-4,&
     & 4.6982E-4, 4.7715E-4, 4.9048E-4, 5.0471E-4, 5.0999E-4, 5.1378E-4,&
     & 5.1682E-4, 5.4061E-4, 5.7984E-4, 5.9580E-4, 7.6273E-4, 9.3875E-4,&
     & 1.3800E-3, 1.6858E-3, 1.8569E-3, 2.6282E-4, 3.1986E-4, 3.5203E-4,&
     & 3.9864E-4, 4.3744E-4, 4.6982E-4, 4.7715E-4, 4.9048E-4, 5.0471E-4,&
     & 5.0999E-4, 5.1378E-4, 5.1682E-4, 5.4061E-4, 5.7984E-4, 5.9580E-4,&
     & 7.6273E-4, 9.3875E-4, 1.3800E-3, 1.6858E-3, 1.8569E-3, 2.6900E-4,&
     & 3.2262E-4, 3.5456E-4, 4.0118E-4, 4.4007E-4, 4.7255E-4, 4.7991E-4,&
     & 4.9327E-4, 5.0755E-4, 5.1286E-4, 5.1666E-4, 5.1971E-4, 5.4358E-4,&
     & 5.8294E-4, 5.9896E-4, 7.6644E-4, 9.4300E-4, 1.3856E-3, 1.6924E-3,&
     & 1.8642E-3, 3.1805E-4, 3.4726E-4, 3.7136E-4, 4.1415E-4, 4.5209E-4,&
     & 4.8435E-4, 4.9170E-4, 5.0508E-4, 5.1941E-4, 5.2473E-4/           
      DATA X4401/ 5.2855E-4, 5.3162E-4, 5.5565E-4, 5.9534E-4, 6.1152E-4,&
     & 7.8086E-4, 9.5946E-4, 1.4072E-3, 1.7179E-3, 1.8926E-3, 4.0390E-4,&
     & 4.0042E-4, 4.1106E-4, 4.3929E-4, 4.7270E-4, 5.0321E-4, 5.1031E-4,&
     & 5.2333E-4, 5.3738E-4, 5.4263E-4, 5.4640E-4, 5.4943E-4, 5.7329E-4,&
     & 6.1300E-4, 6.2925E-4, 8.0041E-4, 9.8154E-4, 1.4359E-3, 1.7519E-3,&
     & 1.9304E-3, 6.8938E-4, 5.8376E-4, 5.5250E-4, 5.3558E-4, 5.4321E-4,&
     & 5.6274E-4, 5.6811E-4, 5.7849E-4, 5.9032E-4, 5.9488E-4, 5.9819E-4,&
     & 6.0087E-4, 6.2257E-4, 6.6029E-4, 6.7612E-4, 8.4865E-4, 1.0349E-3,&
     & 1.5048E-3, 1.8332E-3, 2.0207E-3, 1.4200E-3, 1.0591E-3, 9.2181E-4,&
     & 7.8886E-4, 7.2835E-4, 7.0807E-4, 7.0699E-4, 7.0740E-4, 7.1059E-4,&
     & 7.1238E-4, 7.1384E-4, 7.1510E-4, 7.2763E-4, 7.5566E-4, 7.6887E-4,&
     & 9.3424E-4, 1.1264E-3, 1.6205E-3, 1.9695E-3, 2.1720E-3, 2.1584E-3,&
     & 1.5600E-3, 1.3207E-3, 1.0720E-3, 9.3917E-4, 8.7285E-4, 8.6301E-4,&
     & 8.4978E-4, 8.4106E-4, 8.3901E-4, 8.3788E-4, 8.3717E-4, 8.3676E-4,&
     & 8.5061E-4, 8.5981E-4, 1.0102E-3, 1.2045E-3, 1.7173E-3, 2.0832E-3,&
     & 2.2982E-3, 2.9910E-3, 2.0907E-3, 1.7264E-3, 1.3410E-3, 1.1282E-3,&
     & 1.0154E-3, 9.9734E-4, 9.7136E-4, 9.5148E-4, 9.4581E-4/           
      DATA X4501/ 9.4225E-4, 9.3968E-4, 9.2703E-4, 9.2732E-4, 9.3261E-4,&
     & 1.0672E-3, 1.2616E-3, 1.7869E-3, 2.1647E-3, 2.3887E-3,-5.3346E-3,&
     &-2.1988E-3,-9.8819E-4, 2.1126E-4, 7.8790E-4, 1.0152E-3, 1.0372E-3,&
     & 1.0505E-3, 1.0280E-3, 1.0197E-3, 9.5854E-4, 9.6158E-4, 9.8527E-4,&
     & 9.7918E-4, 9.8159E-4, 1.1041E-3, 1.2979E-3, 1.8307E-3, 2.2160E-3,&
     & 2.4455E-3,-3.6650E-2,-1.8937E-2,-1.1947E-2,-4.7983E-3,-1.1107E-3,&
     & 6.0596E-4, 8.3658E-4, 1.1135E-3, 1.2129E-3, 1.1996E-3, 1.1914E-3,&
     & 1.1854E-3, 1.1559E-3, 1.1450E-3, 1.1372E-3, 1.2154E-3, 1.4048E-3,&
     & 1.9577E-3, 2.3642E-3, 2.6098E-3, 1.0500E-3, 1.1101E-3, 1.1435E-3,&
     & 1.1916E-3, 1.2310E-3, 1.2632E-3, 1.2705E-3, 1.2839E-3, 1.2981E-3,&
     & 1.3034E-3, 1.3072E-3, 1.3102E-3, 1.3143E-3, 1.3192E-3, 1.2994E-3,&
     & 1.3244E-3, 1.5062E-3, 2.0754E-3, 2.5012E-3, 2.7616E-3, 1.2054E-3,&
     & 1.2674E-3, 1.3027E-3, 1.3514E-3, 1.3913E-3, 1.4238E-3, 1.4311E-3,&
     & 1.4446E-3, 1.4587E-3, 1.4640E-3, 1.4678E-3, 1.4709E-3, 1.4677E-3,&
     & 1.5241E-3, 1.5057E-3, 1.4363E-3, 1.6072E-3, 2.1903E-3, 2.6346E-3,&
     & 2.9092E-3, 1.3723E-3, 1.4343E-3, 1.4706E-3, 1.5192E-3, 1.5587E-3,&
     & 1.5911E-3, 1.5985E-3, 1.6119E-3, 1.6261E-3, 1.6314E-3/           
      DATA X4601/ 1.6352E-3, 1.6382E-3, 1.6220E-3, 1.7196E-3, 1.6812E-3,&
     & 1.5624E-3, 1.7180E-3, 2.3140E-3, 2.7778E-3, 3.0675E-3, 1.5582E-3,&
     & 1.6191E-3, 1.6527E-3, 1.7006E-3, 1.7400E-3, 1.7725E-3, 1.7798E-3,&
     & 1.7932E-3, 1.8074E-3, 1.8127E-3, 1.8165E-3, 1.8195E-3, 1.8433E-3,&
     & 1.9097E-3, 1.8557E-3, 1.8117E-3, 1.8470E-3, 2.4548E-3, 2.9403E-3,&
     & 3.2471E-3,-7.8784E-3,-3.8598E-3,-2.1772E-3,-3.1650E-4, 7.9526E-4,&
     & 1.4614E-3, 1.5819E-3, 1.7736E-3, 1.9408E-3, 1.9933E-3, 2.0278E-3,&
     & 2.0536E-3, 2.1993E-3, 2.2317E-3, 2.1746E-3, 2.1239E-3, 2.1319E-3,&
     & 2.7555E-3, 3.2853E-3, 3.6278E-3,-4.8755E-3,-1.9345E-3,-6.8969E-4,&
     & 7.0530E-4, 1.5572E-3, 2.0831E-3, 2.1808E-3, 2.3390E-3, 2.4815E-3,&
     & 2.5277E-3, 2.5585E-3, 2.5819E-3, 2.7257E-3, 2.8162E-3, 2.8035E-3,&
     & 2.6791E-3, 2.7134E-3, 3.3321E-3, 3.9404E-3, 4.3489E-3,-1.4271E-1,&
     &-7.8624E-2,-5.2669E-2,-2.5164E-2,-9.9291E-3,-1.8154E-3,-5.1199E-4,&
     & 1.3766E-3, 2.7314E-3, 3.0652E-3, 3.2492E-3, 3.3636E-3, 3.2652E-3,&
     & 3.3110E-3, 3.3294E-3, 3.0684E-3, 3.1200E-3, 3.7113E-3, 4.3666E-3,&
     & 4.8168E-3,-9.9880E-2,-5.4537E-2,-3.6166E-2,-1.6689E-2,-5.8935E-3,&
     &-1.3623E-4, 7.9008E-4, 2.1339E-3, 3.1010E-3, 3.3405E-3/           
      DATA X4701/ 3.4730E-3, 3.5560E-3, 3.5020E-3, 3.5363E-3, 3.5518E-3,&
     & 3.2647E-3, 3.3127E-3, 3.8853E-3, 4.5610E-3, 5.0298E-3,-2.8786E-1,&
     &-1.5540E-1,-1.0247E-1,-4.7430E-2,-1.8024E-2,-3.3562E-3,-1.1802E-3,&
     & 1.7434E-3, 3.4441E-3, 3.7120E-3, 3.7852E-3, 3.7728E-3, 3.7454E-3,&
     & 3.7726E-3, 3.7527E-3, 3.4777E-3, 3.5103E-3, 4.0602E-3, 4.7558E-3,&
     & 5.2431E-3,-1.0750E-1,-5.6309E-2,-3.5943E-2,-1.4882E-2,-3.7653E-3,&
     & 1.6531E-3, 2.4324E-3, 3.4459E-3, 3.9722E-3, 4.0255E-3, 4.0172E-3,&
     & 4.0123E-3, 4.0053E-3, 4.0441E-3, 4.0150E-3, 3.7105E-3, 3.7128E-3,&
     & 4.2362E-3, 4.9509E-3, 5.4565E-3, 7.5817E-3, 6.0606E-3, 5.4617E-3,&
     & 4.8437E-3, 4.5157E-3, 4.3525E-3, 4.3290E-3, 4.2979E-3, 4.2808E-3,&
     & 4.2787E-3, 4.2785E-3, 4.2790E-3, 4.2955E-3, 4.3359E-3, 4.3035E-3,&
     & 3.9667E-3, 3.9202E-3, 4.4131E-3, 5.1464E-3, 5.6702E-3, 6.2323E-3,&
     & 5.3526E-3, 5.0326E-3, 4.7436E-3, 4.6364E-3, 4.6271E-3, 4.6344E-3,&
     & 4.6560E-3, 4.6907E-3, 4.7052E-3, 4.7158E-3, 4.7245E-3, 4.7616E-3,&
     & 4.7971E-3, 4.7596E-3, 4.3715E-3, 4.2189E-3, 4.6625E-3, 5.4208E-3,&
     & 5.9696E-3, 5.3835E-3, 4.9112E-3, 4.7660E-3, 4.6787E-3, 4.6994E-3,&
     & 4.7732E-3, 4.7965E-3, 4.8449E-3, 4.9007E-3, 4.9221E-3/           
      DATA X4801/ 4.9377E-3, 4.9502E-3, 4.9906E-3, 5.0259E-3, 4.9858E-3,&
     & 4.5723E-3, 4.3498E-3, 4.7700E-3, 5.5386E-3, 6.0981E-3, 1.3723E-3,&
     & 2.9848E-3, 3.6535E-3, 4.3840E-3, 4.8113E-3, 5.0594E-3, 5.1030E-3,&
     & 5.1710E-3, 5.2483E-3, 5.2758E-3, 5.2949E-3, 5.2423E-3, 5.2661E-3,&
     & 5.3012E-3, 5.2581E-3, 4.8140E-3, 4.5495E-3, 4.9318E-3, 5.7156E-3,&
     & 6.2910E-3, 3.3885E-4, 2.8674E-3, 3.8586E-3, 4.8627E-3, 5.3700E-3,&
     & 5.5960E-3, 5.6242E-3, 5.6492E-3, 5.6634E-3, 5.6687E-3, 5.6725E-3,&
     & 5.6755E-3, 5.6993E-3, 5.7340E-3, 5.6861E-3, 5.1940E-3, 4.8681E-3,&
     & 5.1852E-3, 5.9915E-3, 6.5913E-3, 4.9285E-3, 5.4442E-3, 5.6867E-3,&
     & 5.9913E-3, 6.2097E-3, 6.3714E-3, 6.3787E-3, 6.3921E-3, 6.4063E-3,&
     & 6.4116E-3, 6.4154E-3, 6.4184E-3, 6.4422E-3, 6.4763E-3, 6.4202E-3,&
     & 5.8456E-3, 5.3883E-3, 5.5874E-3, 6.4266E-3, 7.0641E-3, 4.1187E-3,&
     & 5.9021E-3, 6.4889E-3, 6.9201E-3, 6.9589E-3, 6.9912E-3, 6.9986E-3,&
     & 7.0119E-3, 7.0261E-3, 7.0314E-3, 7.0352E-3, 7.0382E-3, 7.0620E-3,&
     & 7.0956E-3, 7.0326E-3, 6.3893E-3, 5.8818E-3, 5.9571E-3, 6.8238E-3,&
     & 7.4948E-3, 5.9975E-3, 6.7546E-3, 6.9950E-3, 7.1567E-3, 7.1955E-3,&
     & 7.2279E-3, 7.2352E-3, 7.2486E-3, 7.2628E-3, 7.2681E-3/           
      DATA X4901/ 7.2719E-3, 7.2749E-3, 7.2987E-3, 7.3321E-3, 7.2665E-3,&
     & 6.5969E-3, 6.2131E-3, 6.1996E-3, 7.0828E-3, 7.7752E-3, 6.9202E-3,&
     & 7.5922E-3, 7.3355E-3, 7.0190E-3, 7.0578E-3, 7.0902E-3, 7.0975E-3,&
     & 7.1109E-3, 7.1251E-3, 7.1304E-3, 7.1342E-3, 7.1372E-3, 7.1610E-3,&
     & 7.1945E-3, 7.1304E-3, 6.4761E-3, 6.7390E-3, 6.5759E-3, 7.4825E-3,&
     & 8.2073E-3, 4.2200E-1, 4.4000E-1, 4.7000E-1, 5.2000E-1, 5.7000E-1,&
     & 6.1000E-1, 6.4000E-1, 6.8000E-1, 7.1000E-1, 7.5000E-1, 7.8000E-1,&
     & 8.0000E-1, 8.3000E-1, 8.5000E-1, 8.8000E-1, 9.0000E-1, 9.2000E-1,&
     & 9.2500E-1, 9.3000E-1, 9.3500E-1, 9.4000E-1, 9.4300E-1, 9.4600E-1,&
     & 9.5000E-1, 9.5500E-1, 9.6000E-1, 9.6500E-1, 9.6800E-1, 9.7000E-1,&
     & 9.7500E-1, 9.8000E-1, 9.8800E-1, 9.9100E-1, 9.9300E-1, 9.9530E-1,&
     & 9.9630E-1, 9.9730E-1, 9.9830E-1, 9.9930E-1, 1.0000E+0, 2.7687E-5,&
     & 6.2066E-5, 2.0438E-4, 1.0566E-3, 3.9433E-3, 9.4812E-3, 1.6876E-2,&
     & 3.3314E-2, 5.2470E-2, 9.0382E-2, 1.3063E-1, 1.6430E-1, 2.2678E-1,&
     & 2.7753E-1, 3.6939E-1, 4.4251E-1, 5.2639E-1, 5.4920E-1, 5.7277E-1,&
     & 5.9714E-1, 6.2234E-1, 6.3787E-1, 6.5370E-1, 6.7531E-1, 7.0314E-1,&
     & 7.3190E-1, 7.6163E-1, 7.7995E-1, 7.9236E-1, 8.2414E-1/           
      DATA X5001/ 8.5698E-1, 9.1188E-1, 9.3324E-1, 9.4772E-1, 9.6462E-1,&
     & 9.7206E-1, 9.7954E-1, 9.8707E-1, 9.9465E-1, 1.0000E+0, 3.1539E+0,&
     & 3.1530E+0, 3.1399E+0, 3.0956E+0, 3.0324E+0, 2.9708E+0, 2.9185E+0,&
     & 2.8407E+0, 2.7761E+0, 2.6812E+0, 2.6024E+0, 2.5456E+0, 2.4527E+0,&
     & 2.3845E+0, 2.2702E+0, 2.1836E+0, 2.0859E+0, 2.0593E+0, 2.0316E+0,&
     & 2.0027E+0, 1.9725E+0, 1.9537E+0, 1.9343E+0, 1.9075E+0, 1.8721E+0,&
     & 1.8345E+0, 1.7939E+0, 1.7680E+0, 1.7499E+0, 1.7012E+0, 1.6463E+0,&
     & 1.5369E+0, 1.4836E+0, 1.4412E+0, 1.3806E+0, 1.3476E+0, 1.3075E+0,&
     & 1.2547E+0, 1.1697E+0, 1.0000E+0, 1.5309E-5, 3.2927E-5, 1.0161E-4,&
     & 4.7670E-4, 1.6366E-3, 3.7185E-3, 6.3841E-3, 1.2121E-2, 1.8681E-2,&
     & 3.1610E-2, 4.5503E-2, 5.7361E-2, 8.0141E-2, 9.9542E-2, 1.3722E-1,&
     & 1.7013E-1, 2.1206E-1, 2.2440E-1, 2.3766E-1, 2.5195E-1, 2.6742E-1,&
     & 2.7733E-1, 2.8777E-1, 3.0260E-1, 3.2282E-1, 3.4523E-1, 3.7035E-1,&
     & 3.8698E-1, 3.9884E-1, 4.3172E-1, 4.7060E-1, 5.5334E-1, 5.9592E-1,&
     & 6.3077E-1, 6.8170E-1, 7.0988E-1, 7.4434E-1, 7.8982E-1, 8.6089E-1,&
     & 1.0000E+0, 1.9839E+1, 2.0219E+1, 2.0818E+1, 2.1733E+1, 2.2567E+1,&
     & 2.3189E+1, 2.3632E+1, 2.4199E+1, 2.4609E+1, 2.5140E+1/           
      DATA X5101/ 2.5529E+1, 2.5785E+1, 2.6169E+1, 2.6425E+1, 2.6816E+1,&
     & 2.7084E+1, 2.7362E+1, 2.7433E+1, 2.7506E+1, 2.7580E+1, 2.7656E+1,&
     & 2.7702E+1, 2.7748E+1, 2.7812E+1, 2.7893E+1, 2.7977E+1, 2.8065E+1,&
     & 2.8120E+1, 2.8157E+1, 2.8255E+1, 2.8361E+1, 2.8559E+1, 2.8650E+1,&
     & 2.8721E+1, 2.8819E+1, 2.8871E+1, 2.8934E+1, 2.9016E+1, 2.9149E+1,&
     & 2.9233E+1, 3.9678E+1, 3.9038E+1, 3.8108E+1, 3.6859E+1, 3.5886E+1,&
     & 3.5249E+1, 3.4832E+1, 3.4337E+1, 3.4000E+1, 3.3580E+1, 3.3278E+1,&
     & 3.3079E+1, 3.2780E+1, 3.2577E+1, 3.2260E+1, 3.2034E+1, 3.1789E+1,&
     & 3.1723E+1, 3.1655E+1, 3.1585E+1, 3.1512E+1, 3.1466E+1, 3.1419E+1,&
     & 3.1355E+1, 3.1270E+1, 3.1179E+1, 3.1083E+1, 3.1021E+1, 3.0977E+1,&
     & 3.0862E+1, 3.0732E+1, 3.0476E+1, 3.0354E+1, 3.0258E+1, 3.0125E+1,&
     & 3.0054E+1, 2.9971E+1, 2.9865E+1, 2.9709E+1, 2.9233E+1, 8.3732E+0,&
     & 8.5371E+0, 8.8093E+0, 9.2620E+0, 9.7167E+0, 1.0083E+1, 1.0361E+1,&
     & 1.0737E+1, 1.1023E+1, 1.1414E+1, 1.1715E+1, 1.1920E+1, 1.2239E+1,&
     & 1.2459E+1, 1.2806E+1, 1.3053E+1, 1.3315E+1, 1.3383E+1, 1.3453E+1,&
     & 1.3525E+1, 1.3599E+1, 1.3644E+1, 1.3690E+1, 1.3753E+1, 1.3834E+1,&
     & 1.3918E+1, 1.4006E+1, 1.4061E+1, 1.4099E+1, 1.4199E+1/           
      DATA X5201/ 1.4307E+1, 1.4510E+1, 1.4604E+1, 1.4676E+1, 1.4776E+1,&
     & 1.4829E+1, 1.4893E+1, 1.4977E+1, 1.5112E+1, 1.5197E+1, 1.6746E+1,&
     & 1.6818E+1, 1.6937E+1, 1.7129E+1, 1.7309E+1, 1.7441E+1, 1.7530E+1,&
     & 1.7631E+1, 1.7691E+1, 1.7744E+1, 1.7760E+1, 1.7756E+1, 1.7727E+1,&
     & 1.7689E+1, 1.7598E+1, 1.7508E+1, 1.7388E+1, 1.7351E+1, 1.7312E+1,&
     & 1.7270E+1, 1.7224E+1, 1.7194E+1, 1.7163E+1, 1.7119E+1, 1.7059E+1,&
     & 1.6992E+1, 1.6919E+1, 1.6870E+1, 1.6835E+1, 1.6741E+1, 1.6631E+1,&
     & 1.6404E+1, 1.6292E+1, 1.6203E+1, 1.6076E+1, 1.6008E+1, 1.5927E+1,&
     & 1.5824E+1, 1.5671E+1, 1.5197E+1, 4.6151E-1, 6.4729E+2, 2.2089E+1,&
     & 3.1700E-1, 1.0000E-3, 2.0000E-3, 1.0000E-3, 1.0000E-3/           
                                                                        
!----------------------------------------------------------------------------

      NG = 20
      N1 = 20 
      N2 = 30 
      N3 = 8 
      NS = 40 
      DO 20 I=1,4 
        DO 10 J=1,20 
          G(J,I) = Z(J+(I-1)*20) 
   10   CONTINUE 
   20 CONTINUE

      DO 30 I=1,20 
        TT(I) = Z(I+80) 
   30 END DO

      DO 40 I=1,30 
               DD(I) = Z(I+100) 
   40 CONTINUE 

      KK=130
      DO 70 I=1,8 
        DO 60 J=1,30 
          DO 50 K=1,20 
            KK=KK+1 
            GG(K,J,I) = Z(KK) 
   50     CONTINUE 
   60   CONTINUE 
   70 CONTINUE

      DO 90 I=1,8 
        DO 80 J=1,40 
          SAT(J,I) = Z(J+(I-1)*40+4930) 
   80   CONTINUE 
   90 CONTINUE

      DO 100 I=1,8 
        C(I) = Z(I+5250) 
  100 CONTINUE 


      IGOTO = 4
      CALL FLUID(TEMP,PRES,DENS,PROPS,NP,ENTRY,VAPOR,ERROR,IGOTO) 

      RETURN                                                                        
      END Subroutine Steam

