C
C *** LAST REVISED ON 28-AUG-1987 07:57:13.06
C *** SOURCE FILE: [DL.GRAPHICS.LONGLIB]SYMS.FOR
C
C ***********************************************************************
C
C	MULTI-FONT CHARACTER PLOTTING ROUTINE FOR THE LONGLIB GRAPHICS LIBRARY
C
C	THIS ROUTINE IS FORTRAN-77 COMPATIBLE WITH THE FOLLOWING
C	EXCEPTIONS:
C		1. INTEGER*2 ARRAYS ARE USED TO SAVE SPACE.  THEY MAY
C		   BE REPLACED WITH INTEGER.
C
C	MACHINE DEPENDENT NOTES:
C		1. THE FUNCTION IBITS(I,J,K) RETURNS THE VALUE OF THE BITS
C		   IN I STARTING AT J FOR K BITS.
C		2. "PXPCGT" IS USED TO RETURN A SINGLE ASCII VALUE FROM A
C		    BYTE ARRAY.
C
C ***********************************************************************
C
	REAL FUNCTION SYMS(X,Y,S,T,A,NN,IS)
C
C	ROUTINE TO PLOT SEVERAL CHARACTER FONTS WITH SOME FANCY
C	OPTIONS. 
C
C	WRITTEN BY:	D. LONG  28 FEB 1985   JPL
C
C	X,Y   (R): string position
C	           If x=999 or y=999 then string is continued from
C	           lower right of previous SYMS call
C	S     (R): height of the string to be printed
C	T     (A): alpha array containing the text to be plotted (byte array)
C	A     (R): angle at which the string is to be plotted
C	N     (I): number of characters in string T
C		   note: string may terminated with an ASCII zero
C	IS    (I): centering flag
C			= -3 end coordinates returned in x,y starting
C			     with (x,y) as lower left corner of plotted string
C			     no plotting is done and last position not changed
C			= -2 end coordinates returned in x,y starting
C			     with (x,y) as lower left corner of plotted string
C			= -1 (x,y) lower left corner of plotted string
C			= 0  (x,y) center of plotted string
C			= 1  (x,y) lower right corner of plotted string
C
C SYMS plots an ASCII string (i.e. a byte array).  SYMS provides additional
C math and plotting symbols as well as several character fonts (including
C Greek characters).  SYMS has several additional enhancements to permit
C complicated equations to be plotted.  All but the 9th font have variable
C width characters.  Several fonts are designed to produce solid characters
C when the plotting scale is small.
C
C The ASCII character "|" (decimal 124) is used as a control character to
C change fonts or subscripting options.  The character following the
C "|" character is used according to the following table:
C
C		SYMS Options
C
C  ASCII Character       Decimal	Effect
C ________________ 	_________      ________
C
C     0-9		  48-57		Change to font (0-9)
C      W		   87		Move forward one space
C      X		   88		Move forward 1/2 space
C      Y		   89		Move backward one space
C      Z		   90		Move backward 1/2 space
C      [		   91		Reset to default values
C      \		   92		Begin subscripting
C      ]		   93		Back up last character
C      ^		   94		Begin superscripting
C      _		   95		Un-sub/super script
C      `		   96		Change scale (requires
C					another character-- "+"
C					indicates increase size by 2,
C					"-" indicates shrink by 1/2.
C      a		   97		Begin over printing
C      b		   98		Begin under printing
C
C The width of one space is moved when moving forward or backward.
C Back up returns the positioning to the start of the last character.
C Up to 6 back up commands can be issued.  Super/sub scripting can be
C done recursively.  Only one level is "popped off" by the
C un sub/super command.  Scale changes require an additional character
C (either a "+" or "-" to indicate the direction).  Over/under printing
C permit summation and integral limits to be added.  Fonts are described
C in the following Table:
C
C		Fonts Available in SYMS
C
C   Font		Characters		 Description
C  ______	       _____________		_____________
C
C    0 [default]	ASCII 0-31		Plotting Symbols
C 			ASCII 32-127		Simplex font--variable width
C    1			ASCII 32-127		Roman
C    2			ASCII 64-127		Greek Simplex
C    3			ASCII 32-127		Roman Italic
C    4			ASCII 32-127		Duplex bold
C    5			ASCII 64-127		Special math symbols
C    6			ASCII 32-127		Greek bold
C    7			ASCII 32-127		Simplex Italic
C    8			ASCII 32-127		Crude Simplex--fixed width
C   		
C For example, the following summation using greek characters, a
C math symbol, and a super scripted variable can be wrtten:
C
C  alph string = 'A = |6R a|^2|_|]|]|]|]|b|1|2n=1|]|]|]|_|a|5K'
C
C	       infinity    2
C	    A = SIGMA alpha
C	       zeta=1
C
C Note: VAX FORTRAN CHARACTER types
C can not be used directly since calling subroutines with CHARACTER types
C is done by DESCRIPTOR. Use BYTE or INTEGER arrays for s or use %REF()
C for character variables, i.e., call SYMS(0.,0.,.25,%REF(S),0.,10,-1).
C
C Original font data is an extensive adaptation of fonts developed by
C N.M. Wolcott at NBS. (See NBS special pub. 500-32).
C
      INTEGER T(1)			! INPUT STRING
C
      DATA NFNTS/9/
      INTEGER*2 IFNT(12584),IWID(880),IPNT(880)
      INTEGER*2 IFOFF(9),IFMIN(9),IFMAX(9)
      DATA IFMIN/  0, 32, 64, 32, 32, 64, 64, 32, 32/
      DATA IFMAX/127,127,127,127,127,127,127,127,127/
      DATA IFOFF/  1,129,225,289,385,481,545,609,705/
      INTEGER*2 IF001( 88),IF002( 88),IF003( 88),
     $ IF004( 88),IF005( 88),IF006( 88),IF007( 88),
     $ IF008( 88),IF009( 88),IF010( 88),IF011( 88),
     $ IF012( 88),IF013( 88),IF014( 88),IF015( 88),
     $ IF016( 88),IF017( 88),IF018( 88),IF019( 88),
     $ IF020( 88),IF021( 88),IF022( 88),IF023( 88),
     $ IF024( 88),IF025( 88),IF026( 88),IF027( 88),
     $ IF028( 88),IF029( 88),IF030( 88),IF031( 88),
     $ IF032( 88),IF033( 88),IF034( 88),IF035( 88)
      INTEGER*2 IF036( 88),IF037( 88),IF038( 88),
     $ IF039( 88),IF040( 88),IF041( 88),IF042( 88),
     $ IF043( 88),IF044( 88),IF045( 88),IF046( 88),
     $ IF047( 88),IF048( 88),IF049( 88),IF050( 88),
     $ IF051( 88),IF052( 88),IF053( 88),IF054( 88),
     $ IF055( 88),IF056( 88),IF057( 88),IF058( 88),
     $ IF059( 88),IF060( 88),IF061( 88),IF062( 88),
     $ IF063( 88),IF064( 88),IF065( 88),IF066( 88),
     $ IF067( 88),IF068( 88),IF069( 88),IF070( 88)
      INTEGER*2 IF071( 88),IF072( 88),IF073( 88),
     $ IF074( 88),IF075( 88),IF076( 88),IF077( 88),
     $ IF078( 88),IF079( 88),IF080( 88),IF081( 88),
     $ IF082( 88),IF083( 88),IF084( 88),IF085( 88),
     $ IF086( 88),IF087( 88),IF088( 88),IF089( 88),
     $ IF090( 88),IF091( 88),IF092( 88),IF093( 88),
     $ IF094( 88),IF095( 88),IF096( 88),IF097( 88),
     $ IF098( 88),IF099( 88),IF100( 88),IF101( 88),
     $ IF102( 88),IF103( 88),IF104( 88),IF105( 88)
      INTEGER*2 IF106( 88),IF107( 88),IF108( 88),
     $ IF109( 88),IF110( 88),IF111( 88),IF112( 88),
     $ IF113( 88),IF114( 88),IF115( 88),IF116( 88),
     $ IF117( 88),IF118( 88),IF119( 88),IF120( 88),
     $ IF121( 88),IF122( 88),IF123( 88),IF124( 88),
     $ IF125( 88),IF126( 88),IF127( 88),IF128( 88),
     $ IF129( 88),IF130( 88),IF131( 88),IF132( 88),
     $ IF133( 88),IF134( 88),IF135( 88),IF136( 88),
     $ IF137( 88),IF138( 88),IF139( 88),IF140( 88)
      INTEGER*2 IF141( 88),IF142( 88),IF143( 88)
      INTEGER*2 IWD001( 88),IWD002( 88),IWD003( 88),
     $ IWD004( 88),IWD005( 88),IWD006( 88),IWD007( 88),
     $ IWD008( 88),IWD009( 88),IWD010( 88)
      INTEGER*2 IPT001( 88),IPT002( 88),IPT003( 88),
     $ IPT004( 88),IPT005( 88),IPT006( 88),IPT007( 88),
     $ IPT008( 88),IPT009( 88),IPT010( 88)
      EQUIVALENCE (IFNT(    1),IF001(1)),(IFNT(   89),IF002(1)),
     $ (IFNT(  177),IF003(1)),(IFNT(  265),IF004(1)),
     $ (IFNT(  353),IF005(1)),(IFNT(  441),IF006(1)),
     $ (IFNT(  529),IF007(1)),(IFNT(  617),IF008(1)),
     $ (IFNT(  705),IF009(1)),(IFNT(  793),IF010(1)),
     $ (IFNT(  881),IF011(1)),(IFNT(  969),IF012(1)),
     $ (IFNT( 1057),IF013(1)),(IFNT( 1145),IF014(1)),
     $ (IFNT( 1233),IF015(1)),(IFNT( 1321),IF016(1)),
     $ (IFNT( 1409),IF017(1)),(IFNT( 1497),IF018(1))
      EQUIVALENCE (IFNT( 1585),IF019(1)),(IFNT( 1673),IF020(1)),
     $ (IFNT( 1761),IF021(1)),(IFNT( 1849),IF022(1)),
     $ (IFNT( 1937),IF023(1)),(IFNT( 2025),IF024(1)),
     $ (IFNT( 2113),IF025(1)),(IFNT( 2201),IF026(1)),
     $ (IFNT( 2289),IF027(1)),(IFNT( 2377),IF028(1)),
     $ (IFNT( 2465),IF029(1)),(IFNT( 2553),IF030(1)),
     $ (IFNT( 2641),IF031(1)),(IFNT( 2729),IF032(1)),
     $ (IFNT( 2817),IF033(1)),(IFNT( 2905),IF034(1)),
     $ (IFNT( 2993),IF035(1)),(IFNT( 3081),IF036(1))
      EQUIVALENCE (IFNT( 3169),IF037(1)),(IFNT( 3257),IF038(1)),
     $ (IFNT( 3345),IF039(1)),(IFNT( 3433),IF040(1)),
     $ (IFNT( 3521),IF041(1)),(IFNT( 3609),IF042(1)),
     $ (IFNT( 3697),IF043(1)),(IFNT( 3785),IF044(1)),
     $ (IFNT( 3873),IF045(1)),(IFNT( 3961),IF046(1)),
     $ (IFNT( 4049),IF047(1)),(IFNT( 4137),IF048(1)),
     $ (IFNT( 4225),IF049(1)),(IFNT( 4313),IF050(1)),
     $ (IFNT( 4401),IF051(1)),(IFNT( 4489),IF052(1)),
     $ (IFNT( 4577),IF053(1)),(IFNT( 4665),IF054(1))
      EQUIVALENCE (IFNT( 4753),IF055(1)),(IFNT( 4841),IF056(1)),
     $ (IFNT( 4929),IF057(1)),(IFNT( 5017),IF058(1)),
     $ (IFNT( 5105),IF059(1)),(IFNT( 5193),IF060(1)),
     $ (IFNT( 5281),IF061(1)),(IFNT( 5369),IF062(1)),
     $ (IFNT( 5457),IF063(1)),(IFNT( 5545),IF064(1)),
     $ (IFNT( 5633),IF065(1)),(IFNT( 5721),IF066(1)),
     $ (IFNT( 5809),IF067(1)),(IFNT( 5897),IF068(1)),
     $ (IFNT( 5985),IF069(1)),(IFNT( 6073),IF070(1)),
     $ (IFNT( 6161),IF071(1)),(IFNT( 6249),IF072(1))
      EQUIVALENCE (IFNT( 6337),IF073(1)),(IFNT( 6425),IF074(1)),
     $ (IFNT( 6513),IF075(1)),(IFNT( 6601),IF076(1)),
     $ (IFNT( 6689),IF077(1)),(IFNT( 6777),IF078(1)),
     $ (IFNT( 6865),IF079(1)),(IFNT( 6953),IF080(1)),
     $ (IFNT( 7041),IF081(1)),(IFNT( 7129),IF082(1)),
     $ (IFNT( 7217),IF083(1)),(IFNT( 7305),IF084(1)),
     $ (IFNT( 7393),IF085(1)),(IFNT( 7481),IF086(1)),
     $ (IFNT( 7569),IF087(1)),(IFNT( 7657),IF088(1)),
     $ (IFNT( 7745),IF089(1)),(IFNT( 7833),IF090(1))
      EQUIVALENCE (IFNT( 7921),IF091(1)),(IFNT( 8009),IF092(1)),
     $ (IFNT( 8097),IF093(1)),(IFNT( 8185),IF094(1)),
     $ (IFNT( 8273),IF095(1)),(IFNT( 8361),IF096(1)),
     $ (IFNT( 8449),IF097(1)),(IFNT( 8537),IF098(1)),
     $ (IFNT( 8625),IF099(1)),(IFNT( 8713),IF100(1)),
     $ (IFNT( 8801),IF101(1)),(IFNT( 8889),IF102(1)),
     $ (IFNT( 8977),IF103(1)),(IFNT( 9065),IF104(1)),
     $ (IFNT( 9153),IF105(1)),(IFNT( 9241),IF106(1)),
     $ (IFNT( 9329),IF107(1)),(IFNT( 9417),IF108(1))
      EQUIVALENCE (IFNT( 9505),IF109(1)),(IFNT( 9593),IF110(1)),
     $ (IFNT( 9681),IF111(1)),(IFNT( 9769),IF112(1)),
     $ (IFNT( 9857),IF113(1)),(IFNT( 9945),IF114(1)),
     $ (IFNT(10033),IF115(1)),(IFNT(10121),IF116(1)),
     $ (IFNT(10209),IF117(1)),(IFNT(10297),IF118(1)),
     $ (IFNT(10385),IF119(1)),(IFNT(10473),IF120(1)),
     $ (IFNT(10561),IF121(1)),(IFNT(10649),IF122(1)),
     $ (IFNT(10737),IF123(1)),(IFNT(10825),IF124(1)),
     $ (IFNT(10913),IF125(1)),(IFNT(11001),IF126(1))
      EQUIVALENCE (IFNT(11089),IF127(1)),(IFNT(11177),IF128(1)),
     $ (IFNT(11265),IF129(1)),(IFNT(11353),IF130(1)),
     $ (IFNT(11441),IF131(1)),(IFNT(11529),IF132(1)),
     $ (IFNT(11617),IF133(1)),(IFNT(11705),IF134(1)),
     $ (IFNT(11793),IF135(1)),(IFNT(11881),IF136(1)),
     $ (IFNT(11969),IF137(1)),(IFNT(12057),IF138(1)),
     $ (IFNT(12145),IF139(1)),(IFNT(12233),IF140(1)),
     $ (IFNT(12321),IF141(1)),(IFNT(12409),IF142(1)),
     $ (IFNT(12497),IF143(1))
      EQUIVALENCE (IWID(    1),IWD001(1)),(IWID(   89),IWD002(1)),
     $ (IWID(  177),IWD003(1)),(IWID(  265),IWD004(1)),
     $ (IWID(  353),IWD005(1)),(IWID(  441),IWD006(1)),
     $ (IWID(  529),IWD007(1)),(IWID(  617),IWD008(1)),
     $ (IWID(  705),IWD009(1)),(IWID(  793),IWD010(1))
      EQUIVALENCE (IPNT(    1),IPT001(1)),(IPNT(   89),IPT002(1)),
     $ (IPNT(  177),IPT003(1)),(IPNT(  265),IPT004(1)),
     $ (IPNT(  353),IPT005(1)),(IPNT(  441),IPT006(1)),
     $ (IPNT(  529),IPT007(1)),(IPNT(  617),IPT008(1)),
     $ (IPNT(  705),IPT009(1)),(IPNT(  793),IPT010(1))
      DATA IF001/ 28714, 21802, 21782, 19222, 19242, 20522, 12320,
     $  28704, 20522, 21034, 21796, 21788, 21014, 19990, 19228, 19236,
     $  20010, 12330, 28704, 20522, 21659, 19355, 12330, 28694, 20522,
     $  27424, 13599, 27801, 21415, 27815, 13209, 28714, 21792, 20502,
     $  19232, 20522, 12320, 28694, 20522, 21792, 19232, 12330, 27414,
     $  21802, 19242, 13590, 28704, 20522, 21669, 21659, 20502, 19355,
     $  19365, 12330, 27815, 20512, 20502, 28704, 13223, 29349, 21147,
     $  19867, 19877, 21157, 27434, 19877, 27414, 19867, 29974, 21147,
     $  28704, 13610, 27424, 21792, 28694, 20522, 27801, 21415, 29593,
     $  11431, 27434, 21802, 19222, 21782, 11050, 27668, 27688, 21544/
      DATA IF002/ 19480, 21528, 28192, 21024,  4128, 27668, 28704,
     $  21544, 29220, 20004, 19496, 28196, 19996, 19480, 28188, 21020,
     $  21528, 29212, 21028,  4128, 27180, 28704, 21536, 19496, 19480,
     $  21536,  4128, 27180, 27688, 21528, 21544, 19480,  4128, 27160,
     $  28704, 21528, 29736, 20512, 19488,  4128, 27160, 28704, 21528,
     $  21544, 19480, 19496, 20512,  4128, 28694, 12330, 28704, 20522,
     $  21659, 19355, 20522, 29861, 20502, 19365, 13477, 28705, 20384,
     $  20511, 20640, 12321, 28572, 20125, 19999, 20001, 20131, 20388,
     $  20644, 20899, 21025, 21023, 20893, 20636, 12188, 28437, 19862,
     $  19480, 19227, 19102, 19106, 19237, 19496, 19882, 20267, 20779/
      DATA IF003/ 21162, 21544, 21797, 21922, 21918, 21787, 21528,
     $  21142, 20757, 12053, 28426, 19595, 19085, 18703, 18322, 18069,
     $  17817, 17694, 17698, 17831, 18091, 18350, 18737, 19123, 19637,
     $  20278, 20790, 21429, 21939, 22321, 22702, 22955, 23207, 23330,
     $  23326, 23193, 22933, 22674, 22287, 21901, 21387, 20746, 12042,
     $  28572, 20125, 19999, 20001, 20131, 20388, 20644, 20899, 21025,
     $  21023, 20893, 20636, 20380, 28319, 20129, 20129, 28446, 20258,
     $  28573, 20387, 28701, 20515, 28829, 20643, 28958, 20770, 29087,
     $  12705, 28188, 20004, 21028, 21020, 19996, 28317, 20131, 28445,
     $  20259, 28573, 20387, 28701, 20515, 28829, 20643, 28957, 20771/
      DATA IF004/ 29085, 12707, 28698, 19875, 21155, 20506, 28322,
     $  20509, 20898, 28704, 20386, 20512, 12450, 30228, 30248, 20008,
     $  22040, 19992, 29728, 20512,  4640, 27668, 19500, 21548, 21524,
     $  19476, 21548, 27692, 21524,  6164, 30740,  4490,  4490, 26528,
     $  18206, 18322, 18462, 18336, 26526, 18328, 26509, 18188, 18315,
     $  18444, 10125, 25994, 26522, 18338, 27554, 19354,  4490, 27296,
     $  18180, 28064, 18948, 26389, 19989, 26255, 11663, 26916, 18695,
     $  27428, 19207, 28061, 19615, 19232, 18720, 18335, 18077, 18075,
     $  18201, 18328, 18583, 19349, 19604, 19731, 19857, 19854, 19596,
     $  19211, 18699, 18316,  9870, 28576, 18059, 26912, 18974, 18972/
      DATA IF005/ 18842, 18585, 18329, 18075, 18077, 18207, 18464,
     $  18720, 18975, 19358, 19742, 20127, 20384, 28050, 19601, 19471,
     $  19469, 19723, 19979, 20236, 20366, 20368, 20114, 11666, 25994,
     $  28050, 18826, 18314, 17806, 17810, 19354, 19358, 18850, 18334,
     $  18326, 19850,  4490, 25994, 26522, 18846, 18850,  4490, 27300,
     $  18850, 18591, 18331, 18198, 18194, 18317, 18569, 18822, 10884,
     $  26276, 18338, 18591, 18843, 18966, 18962, 18829, 18569, 18310,
     $   9860, 26906, 18702, 26263, 19345, 27543,  9873, 27549, 19339,
     $  26388, 12308, 26636, 18315, 18188, 18317, 18444, 18442, 18312,
     $   9991, 26388, 12308, 26509, 18188, 18315, 18444, 10125, 28452/
      DATA IF006/  9732, 27040, 18463, 18204, 18071, 18068, 18191,
     $  18444, 18827, 19083, 19468, 19727, 19860, 19863, 19740, 19487,
     $  19104, 10656, 26652, 18717, 19104, 10891, 26395, 18204, 18334,
     $  18463, 18720, 19232, 19487, 19614, 19740, 19738, 19608, 19349,
     $  18059, 11659, 26528, 19744, 18968, 19352, 19607, 19734, 19859,
     $  19857, 19726, 19468, 19083, 18699, 18316, 18189,  9871, 27552,
     $  18066, 19986, 27552, 11147, 27808, 18336, 18199, 18328, 18713,
     $  19097, 19480, 19734, 19859, 19857, 19726, 19468, 19083, 18699,
     $  18316, 18189,  9871, 27933, 19615, 19232, 18976, 18591, 18332,
     $  18199, 18194, 18318, 18572, 18955, 19083, 19468, 19726, 19857/
      DATA IF007/ 19858, 19733, 19479, 19096, 18968, 18583, 18325,
     $  10002, 28064, 18571, 26272, 11680, 26912, 18335, 18205, 18203,
     $  18329, 18584, 19095, 19478, 19732, 19858, 19855, 19725, 19596,
     $  19211, 18699, 18316, 18189, 18063, 18066, 18196, 18454, 18839,
     $  19352, 19609, 19739, 19741, 19615, 19232, 10528, 27929, 19606,
     $  19348, 18963, 18835, 18452, 18198, 18073, 18074, 18205, 18463,
     $  18848, 18976, 19359, 19613, 19737, 19732, 19599, 19340, 18955,
     $  18699, 18316,  9998, 26521, 18200, 18327, 18456, 18329, 26509,
     $  18188, 18315, 18444, 10125, 26521, 18200, 18327, 18456, 18329,
     $  26507, 18188, 18317, 18444, 18442, 18312,  9991, 28445, 18196/
      DATA IF008/ 12043, 26391, 20503, 26385, 12305, 26397, 20244,
     $   9995, 25994, 27018, 18826, 27026, 19866, 19870, 19362, 18338,
     $  17822,  4490, 25994, 27530, 18314, 17806, 17822, 18338, 19362,
     $  19870, 19858, 18834, 18838, 19870,  4490, 27040, 17803, 27040,
     $  19851, 26386, 11282, 26400, 18187, 26400, 19360, 19743, 19870,
     $  19996, 19994, 19864, 19735, 19350, 26390, 19350, 19733, 19860,
     $  19986, 19983, 19853, 19724, 19339,  9995, 28187, 19869, 19615,
     $  19360, 18848, 18591, 18333, 18203, 18072, 18067, 18192, 18318,
     $  18572, 18827, 19339, 19596, 19854, 11792, 26400, 18187, 26400,
     $  19104, 19487, 19741, 19867, 19992, 19987, 19856, 19726, 19468/
      DATA IF009/ 19083,  9995, 26400, 18187, 26400, 19872, 26390,
     $  19222, 26379, 11659, 26400, 18187, 26400, 19872, 26390, 11030,
     $  28187, 19869, 19615, 19360, 18848, 18591, 18333, 18203, 18072,
     $  18067, 18192, 18318, 18572, 18827, 19339, 19596, 19854, 19984,
     $  19987, 27539, 11795, 26400, 18187, 28192, 19979, 26390, 11798,
     $  26400,  9995, 27424, 19216, 19085, 18956, 18699, 18443, 18188,
     $  18061, 17936,  9746, 26400, 18187, 28192, 18194, 27031, 11787,
     $  26400, 18187, 26379, 11531, 26400, 18187, 26400, 19211, 28448,
     $  19211, 28448, 12043, 26400, 18187, 26400, 19979, 28192, 11787,
     $  27040, 18591, 18333, 18203, 18072, 18067, 18192, 18318, 18572/
      DATA IF010/ 18827, 19339, 19596, 19854, 19984, 20115, 20120,
     $  19995, 19869, 19615, 19360, 10656, 26400, 18187, 26400, 19360,
     $  19743, 19870, 19996, 19993, 19863, 19734, 19349, 10005, 27040,
     $  18591, 18333, 18203, 18072, 18067, 18192, 18318, 18572, 18827,
     $  19339, 19596, 19854, 19984, 20115, 20120, 19995, 19869, 19615,
     $  19360, 18848, 27407, 11785, 26400, 18187, 26400, 19360, 19743,
     $  19870, 19996, 19994, 19864, 19735, 19350, 18198, 27286, 11787,
     $  28061, 19615, 19232, 18720, 18335, 18077, 18075, 18201, 18328,
     $  18583, 19349, 19604, 19731, 19857, 19854, 19596, 19211, 18699,
     $  18316,  9870, 26912, 18699, 26016, 11424, 26400, 18193, 18318/
      DATA IF011/ 18572, 18955, 19211, 19596, 19854, 19985, 11808,
     $  26016, 18827, 28064, 10635, 26144, 18571, 27424, 18571, 27424,
     $  19851, 28704, 11659, 26272, 19851, 28064,  9867, 26016, 18838,
     $  18827, 28064, 10646, 28064, 18059, 26272, 19872, 26251, 11659,
     $  25994, 27042, 17826, 17802, 18826,  3466, 25994, 28042, 17826,
     $   4490, 25994, 18826, 18850, 17826,  3466, 25994, 26006, 18846,
     $  19862,  2462, 27038, 25996, 19852,  2444, 25994, 26018, 19350,
     $   4490, 27801, 19595, 27798, 19352, 19097, 18713, 18456, 18198,
     $  18067, 18065, 18190, 18444, 18699, 19083, 19340, 11406, 26400,
     $  18187, 26390, 18456, 18713, 19097, 19352, 19606, 19731, 19729/
      DATA IF012/ 19598, 19340, 19083, 18699, 18444,  9998, 27798,
     $  19352, 19097, 18713, 18456, 18198, 18067, 18065, 18190, 18444,
     $  18699, 19083, 19340, 11406, 27808, 19595, 27798, 19352, 19097,
     $  18713, 18456, 18198, 18067, 18065, 18190, 18444, 18699, 19083,
     $  19340, 11406, 26259, 19603, 19605, 19479, 19352, 19097, 18713,
     $  18456, 18198, 18067, 18065, 18190, 18444, 18699, 19083, 19340,
     $  11406, 27168, 18720, 18463, 18332, 18315, 26137, 10649, 27801,
     $  19593, 19462, 19333, 19076, 18692, 18437, 27798, 19352, 19097,
     $  18713, 18456, 18198, 18067, 18065, 18190, 18444, 18699, 19083,
     $  19340, 11406, 26400, 18187, 26389, 18584, 18841, 19225, 19480/
      DATA IF013/ 19605, 11403, 26272, 18207, 18336, 18209, 18080,
     $  26393,  9995, 26528, 18463, 18592, 18465, 18336, 26649, 18440,
     $  18309, 18052,  9604, 26400, 18187, 27673, 18191, 26899, 11403,
     $  26400,  9995, 26393, 18187, 26389, 18584, 18841, 19225, 19480,
     $  19605, 19595, 27797, 19992, 20249, 20633, 20888, 21013, 12811,
     $  26393, 18187, 26389, 18584, 18841, 19225, 19480, 19605, 11403,
     $  26905, 18456, 18198, 18067, 18065, 18190, 18444, 18699, 19083,
     $  19340, 19598, 19729, 19731, 19606, 19352, 19097, 10521, 26393,
     $  18180, 26390, 18456, 18713, 19097, 19352, 19606, 19731, 19729,
     $  19598, 19340, 19083, 18699, 18444,  9998, 27801, 19588, 27798/
      DATA IF014/ 19352, 19097, 18713, 18456, 18198, 18067, 18065,
     $  18190, 18444, 18699, 19083, 19340, 11406, 26393, 18187, 26387,
     $  18326, 18584, 18841, 11033, 27670, 19352, 18969, 18585, 18200,
     $  18070, 18196, 18451, 19090, 19345, 19471, 19470, 19340, 18955,
     $  18571, 18188,  9870, 26528, 18319, 18444, 18699, 18955, 26137,
     $  10649, 26393, 18191, 18316, 18571, 18955, 19212, 19599, 27801,
     $  11403, 26137, 18699, 27673, 10507, 26265, 18571, 27289, 18571,
     $  27289, 19595, 28313, 11403, 26265, 19467, 27673,  9867, 26137,
     $  18699, 27673, 18699, 18439, 18181, 17924,  9604, 27673, 18059,
     $  26265, 19481, 26251, 11275, 25994, 27018, 18318, 18322, 17814/
      DATA IF015/ 18330, 18334, 18850,  3978, 26404,  9988, 25994,
     $  26506, 18830, 18834, 19350, 18842, 18846, 18338,  3978, 25994,
     $  26002, 18326, 19350, 19866,  4490, 25994, 17826, 19874, 19850,
     $  17802, 19874, 26018, 19850,  4490,  4490, 26528, 18206, 18322,
     $  18462, 18336, 26526, 18328, 26509, 18188, 18315, 18444, 10125,
     $  25994, 26522, 18338, 27554, 19354,  4490, 27296, 18180, 28064,
     $  18948, 26389, 19989, 26255, 11663, 26916, 18695, 27428, 19207,
     $  27933, 19612, 19739, 19868, 19869, 19615, 19232, 18720, 18335,
     $  18077, 18075, 18201, 18328, 18583, 19349, 19604, 19858, 26267,
     $  18329, 18584, 19350, 19605, 19732, 19858, 19854, 19596, 19211/
      DATA IF016/ 18699, 18316, 18062, 18063, 18192, 18319,  9998,
     $  28576, 18059, 26912, 18974, 18972, 18842, 18585, 18329, 18075,
     $  18077, 18207, 18464, 18720, 18975, 19358, 19742, 20127, 20384,
     $  28050, 19601, 19471, 19469, 19723, 19979, 20236, 20366, 20368,
     $  20114, 11666, 28568, 20247, 20374, 20503, 20504, 20377, 20249,
     $  20120, 19990, 19729, 19470, 19212, 18955, 18571, 18188, 18062,
     $  18065, 18195, 18967, 19225, 19355, 19357, 19231, 18976, 18719,
     $  18589, 18587, 18712, 18965, 19598, 19852, 20235, 20363, 20492,
     $  20493, 26763, 18316, 18190, 18193, 18323, 18581, 26779, 18713,
     $  19726, 19980, 12043, 25994, 26522, 18846, 18850,  4490, 27300/
      DATA IF017/ 18850, 18591, 18331, 18198, 18194, 18317, 18569,
     $  18822, 19076, 27042, 18590, 18459, 18326, 18322, 18445, 18570,
     $  10630, 26276, 18338, 18591, 18843, 18966, 18962, 18829, 18569,
     $  18310, 18052, 26530, 18590, 18715, 18838, 18834, 18701, 18570,
     $  10118, 26912, 18708, 26269, 19351, 27549,  9879, 27549, 19339,
     $  26388, 12308, 26507, 18188, 18317, 18444, 18442, 18312,  9991,
     $  26388, 12308, 26509, 18188, 18315, 18444, 10125, 28452,  9732,
     $  27040, 18463, 18204, 18071, 18068, 18191, 18444, 18827, 19083,
     $  19468, 19727, 19860, 19863, 19740, 19487, 19104, 18848, 27040,
     $  18591, 18462, 18332, 18199, 18196, 18319, 18445, 18572, 18827/
      DATA IF018/ 27275, 19340, 19469, 19599, 19732, 19735, 19612,
     $  19486, 19359, 10912, 26652, 18717, 19104, 19083, 27167, 18955,
     $  26635, 11403, 26396, 18331, 18202, 18075, 18076, 18206, 18335,
     $  18720, 19232, 19615, 19742, 19868, 19866, 19736, 19350, 18708,
     $  18451, 18193, 18062, 18059, 27424, 19487, 19614, 19740, 19738,
     $  19608, 19222, 18708, 26253, 18190, 18446, 19084, 19468, 19725,
     $  19854, 26638, 19083, 19595, 19724, 19854, 11664, 26396, 18331,
     $  18202, 18075, 18076, 18206, 18335, 18720, 19232, 19615, 19741,
     $  19738, 19608, 19223, 18839, 27424, 19487, 19613, 19610, 19480,
     $  19223, 27415, 19478, 19732, 19858, 19855, 19725, 19596, 19211/
      DATA IF019/ 18699, 18316, 18189, 18063, 18064, 18193, 18320,
     $  18191, 27797, 19730, 19727, 19597, 19468, 11019, 27422, 19211,
     $  27552, 19339, 27552, 17937, 19985, 27019, 11531, 26528, 18070,
     $  26262, 18328, 18713, 19097, 19480, 19734, 19859, 19857, 19726,
     $  19468, 19083, 18699, 18316, 18189, 18063, 18064, 18193, 18320,
     $  18191, 27289, 19352, 19606, 19731, 19729, 19598, 19340, 19083,
     $  26528, 19616, 26527, 18975, 11424, 27805, 19484, 19611, 19740,
     $  19741, 19615, 19360, 18976, 18591, 18333, 18203, 18071, 18065,
     $  18190, 18444, 18827, 19083, 19468, 19726, 19857, 19858, 19733,
     $  19479, 19096, 18968, 18583, 18325, 18194, 27168, 18719, 18461/
      DATA IF020/ 18331, 18199, 18193, 18318, 18572, 18827, 27275,
     $  19340, 19598, 19729, 19730, 19605, 19351, 10904, 26272, 18074,
     $  26268, 18206, 18464, 18720, 19357, 19613, 19742, 19872, 26398,
     $  18463, 18719, 19357, 28064, 19869, 19738, 19221, 19091, 18960,
     $  18955, 27930, 19093, 18963, 18832, 10635, 26912, 18335, 18205,
     $  18202, 18328, 18711, 19223, 19608, 19738, 19741, 19615, 19232,
     $  18720, 26912, 18463, 18333, 18330, 18456, 18711, 27415, 19480,
     $  19610, 19613, 19487, 19232, 26903, 18326, 18197, 18067, 18063,
     $  18189, 18316, 18699, 19211, 19596, 19725, 19855, 19859, 19733,
     $  19606, 19223, 26903, 18454, 18325, 18195, 18191, 18317, 18444/
      DATA IF021/ 18699, 27403, 19468, 19597, 19727, 19731, 19605,
     $  19478, 11031, 27929, 19606, 19348, 18963, 18835, 18452, 18198,
     $  18073, 18074, 18205, 18463, 18848, 19104, 19487, 19741, 19866,
     $  19860, 19728, 19598, 19340, 18955, 18571, 18316, 18190, 18191,
     $  18320, 18447, 18318, 27027, 18580, 18326, 18201, 18202, 18333,
     $  18591, 18848, 27296, 19359, 19613, 19738, 19732, 19600, 19470,
     $  19212, 10763, 26521, 18200, 18327, 18456, 18329, 26509, 18188,
     $  18315, 18444, 10125, 26521, 18200, 18327, 18456, 18329, 26507,
     $  18188, 18317, 18444, 18442, 18312,  9991, 28445, 18196, 12043,
     $  26391, 20503, 26385, 12305, 26397, 20244,  9995, 26396, 18331/
      DATA IF022/ 18202, 18075, 18076, 18206, 18335, 18592, 18976,
     $  19359, 19486, 19612, 19610, 19480, 19351, 18837, 18834, 27168,
     $  19231, 19358, 19484, 19482, 19352, 19094, 27021, 18700, 18827,
     $  18956, 10637, 28184, 19866, 19611, 19227, 18970, 18841, 18710,
     $  18707, 18833, 19088, 19472, 19729, 19859, 27419, 18969, 18838,
     $  18835, 18961, 19088, 28187, 19859, 19857, 20112, 20368, 20626,
     $  20757, 20759, 20634, 20508, 20254, 19999, 19616, 19232, 18847,
     $  18590, 18332, 18202, 18071, 18068, 18193, 18319, 18573, 18828,
     $  19211, 19595, 19980, 20237, 20366, 28315, 19987, 19985, 11920,
     $  27168, 18059, 27168, 19851, 27165, 19723, 26513, 19473, 25995/
      DATA IF023/ 18571, 27531, 11915, 26528, 18315, 26656, 18443,
     $  26144, 19488, 19871, 19998, 20124, 20122, 19992, 19863, 19478,
     $  27680, 19743, 19870, 19996, 19994, 19864, 19735, 19478, 26646,
     $  19478, 19861, 19988, 20114, 20111, 19981, 19852, 19467, 17931,
     $  27670, 19733, 19860, 19986, 19983, 19853, 19724, 11275, 28061,
     $  19994, 20000, 19869, 19615, 19232, 18976, 18591, 18333, 18203,
     $  18072, 18067, 18192, 18318, 18572, 18955, 19211, 19596, 19854,
     $  19984, 27168, 18719, 18461, 18331, 18200, 18195, 18320, 18446,
     $  18700, 10763, 26528, 18315, 26656, 18443, 26144, 19232, 19615,
     $  19869, 19995, 20120, 20115, 19984, 19854, 19596, 19211, 17931/
      DATA IF024/ 27424, 19487, 19741, 19867, 19992, 19987, 19856,
     $  19726, 19468, 11019, 26528, 18315, 26656, 18443, 27418, 19218,
     $  26144, 20000, 19994, 19872, 26646, 19222, 26123, 19979, 19985,
     $  11659, 26528, 18315, 26656, 18443, 27418, 19218, 26144, 20000,
     $  19994, 19872, 26646, 19222, 26123, 10635, 28061, 19994, 20000,
     $  19869, 19615, 19232, 18976, 18591, 18333, 18203, 18072, 18067,
     $  18192, 18318, 18572, 18955, 19211, 19596, 19854, 27168, 18719,
     $  18461, 18331, 18200, 18195, 18320, 18446, 18700, 18955, 28051,
     $  19851, 28179, 19979, 27667, 12179, 26528, 18315, 26656, 18443,
     $  28192, 19979, 28320, 20107, 26144, 18848, 27808, 20512, 26646/
      DATA IF025/ 19990, 26123, 18827, 27787, 12299, 26528, 18315,
     $  26656, 18443, 26144, 18848, 26123, 10635, 27168, 18959, 18828,
     $  18571, 18315, 18060, 17934, 17936, 18065, 18192, 18063, 27040,
     $  18831, 18700, 18571, 26656, 11168, 26528, 18315, 26656, 18443,
     $  28320, 18451, 27287, 20107, 27159, 19979, 26144, 18848, 27808,
     $  20384, 26123, 18827, 27787, 12171, 26528, 18315, 26656, 18443,
     $  26144, 18848, 26123, 19851, 19857, 11531, 26528, 18315, 26656,
     $  19214, 26528, 19211, 28320, 19211, 28320, 20107, 28448, 20235,
     $  26144, 18464, 28320, 20640, 26123, 18699, 27915, 12427, 26528,
     $  18315, 26656, 19981, 26654, 19979, 28192, 19979, 26144, 18464/
      DATA IF026/ 27808, 20384, 26123, 10507, 27168, 18591, 18333,
     $  18203, 18071, 18068, 18192, 18318, 18572, 18955, 19211, 19596,
     $  19854, 19984, 20116, 20119, 19995, 19869, 19615, 19232, 18976,
     $  27168, 18719, 18461, 18331, 18199, 18196, 18320, 18446, 18700,
     $  18955, 27403, 19468, 19726, 19856, 19988, 19991, 19867, 19741,
     $  19487, 11040, 26528, 18315, 26656, 18443, 26144, 19488, 19871,
     $  19998, 20124, 20121, 19991, 19862, 19477, 18453, 27680, 19743,
     $  19870, 19996, 19993, 19863, 19734, 19477, 26123, 10635, 27168,
     $  18591, 18333, 18203, 18071, 18068, 18192, 18318, 18572, 18955,
     $  19211, 19596, 19854, 19984, 20116, 20119, 19995, 19869, 19615/
      DATA IF027/ 19232, 18976, 27168, 18719, 18461, 18331, 18199,
     $  18196, 18320, 18446, 18700, 18955, 27403, 19468, 19726, 19856,
     $  19988, 19991, 19867, 19741, 19487, 19232, 26765, 18574, 18704,
     $  18961, 19089, 19344, 19470, 19591, 19718, 19974, 20104, 20105,
     $  27662, 19594, 19720, 19847, 19975, 11912, 26528, 18315, 26656,
     $  18443, 26144, 19488, 19871, 19998, 20124, 20122, 19992, 19863,
     $  19478, 18454, 27680, 19743, 19870, 19996, 19994, 19864, 19735,
     $  19478, 26123, 18827, 27286, 19349, 19476, 19853, 19980, 20108,
     $  20237, 27541, 19475, 19724, 19851, 20107, 20237, 12046, 27933,
     $  19872, 19866, 19741, 19487, 19104, 18720, 18335, 18077, 18075/
      DATA IF028/ 18201, 18328, 18583, 19349, 19604, 19858, 26267,
     $  18329, 18584, 19350, 19605, 19732, 19858, 19854, 19596, 19211,
     $  18827, 18444, 18190, 18065, 18059,  9998, 27040, 18827, 27168,
     $  18955, 26272, 17946, 17952, 19872, 19866, 19744, 26635, 11147,
     $  26528, 18321, 18446, 18700, 19083, 19339, 19724, 19982, 20113,
     $  20128, 26656, 18449, 18574, 18828, 19083, 26144, 18848, 27936,
     $  12320, 26272, 18955, 26400, 18958, 28064, 18955, 26016, 18592,
     $  27552, 11936, 26400, 18699, 26528, 18704, 27424, 18699, 27424,
     $  19723, 27552, 19728, 28448, 19723, 26016, 18720, 28064, 12448,
     $  26272, 19723, 26400, 19851, 28064, 18059, 26016, 18592, 27552/
      DATA IF029/ 20128, 25995, 18571, 27531, 11915, 26272, 18965,
     $  18955, 26400, 19093, 19083, 28192, 19093, 26016, 18592, 27680,
     $  20256, 26763, 11275, 27936, 18059, 28064, 18187, 26400, 18074,
     $  18080, 19872, 26251, 19851, 19857, 11531, 26404, 18180, 26532,
     $  18308, 26404, 19108, 26372, 10884, 25994, 28042, 17826,  4490,
     $  27044, 18820, 27172, 18948, 26276, 18980, 26244, 10756, 25994,
     $  26006, 18846, 19862, 27038, 18830,  4490, 25994, 27022, 17814,
     $  18846, 26006, 19862,  4490, 25994, 26018, 19350,  4490, 26519,
     $  18326, 18198, 18199, 18328, 18585, 19097, 19352, 19479, 19605,
     $  19598, 19724, 19851, 27671, 19470, 19596, 19851, 19979, 27669/
      DATA IF030/ 19348, 18579, 18194, 18064, 18062, 18188, 18571,
     $  18955, 19212, 19470, 26771, 18322, 18192, 18190, 18316, 10379,
     $  26528, 18315, 26656, 18443, 26646, 18712, 18969, 19225, 19608,
     $  19862, 19987, 19985, 19854, 19596, 19211, 18955, 18700, 18446,
     $  27417, 19480, 19734, 19859, 19857, 19726, 19468, 19211, 26144,
     $  10272, 27798, 19477, 19604, 19733, 19734, 19480, 19225, 18841,
     $  18456, 18198, 18067, 18065, 18190, 18444, 18827, 19083, 19468,
     $  19726, 27033, 18584, 18326, 18195, 18193, 18318, 18572, 10635,
     $  27808, 19595, 27936, 19723, 27798, 19352, 19097, 18841, 18456,
     $  18198, 18067, 18065, 18190, 18444, 18827, 19083, 19340, 19598/
      DATA IF031/ 27033, 18584, 18326, 18195, 18193, 18318, 18572,
     $  18827, 27424, 19744, 27787, 11915, 26387, 19731, 19733, 19607,
     $  19480, 19225, 18841, 18456, 18198, 18067, 18065, 18190, 18444,
     $  18827, 19083, 19468, 19726, 27795, 19606, 19480, 27033, 18584,
     $  18326, 18195, 18193, 18318, 18572, 10635, 27167, 18846, 18973,
     $  19102, 19103, 18976, 18720, 18463, 18333, 18315, 26912, 18591,
     $  18461, 18443, 26137, 18969, 26123, 10635, 26905, 18456, 18327,
     $  18197, 18195, 18321, 18448, 18703, 18959, 19216, 19345, 19475,
     $  19477, 19351, 19224, 18969, 18713, 26648, 18326, 18322, 18448,
     $  27408, 19346, 19350, 19224, 27543, 19480, 19737, 19736, 19480/
      DATA IF032/ 26513, 18192, 18062, 18061, 18187, 18570, 19210,
     $  19593, 19720, 26253, 18188, 18571, 19211, 19594, 19720, 19719,
     $  19589, 19204, 18436, 18053, 17927, 17928, 18058, 10251, 26528,
     $  18315, 26656, 18443, 26646, 18712, 19097, 19353, 19736, 19862,
     $  19851, 27545, 19608, 19734, 19723, 26144, 18464, 26123, 18827,
     $  27531, 12043, 26528, 18207, 18334, 18463, 18336, 26521, 18315,
     $  26649, 18443, 26137, 18457, 26123, 10635, 26656, 18335, 18462,
     $  18591, 18464, 26777, 18567, 18437, 18180, 17924, 17797, 17798,
     $  17927, 18054, 17925, 26649, 18439, 18309, 18180, 26265, 10393,
     $  26528, 18315, 26656, 18443, 27929, 18447, 27283, 19851, 27155/
      DATA IF033/ 19723, 26144, 18464, 27545, 20121, 26123, 18827,
     $  27531, 11915, 26528, 18315, 26656, 18443, 26144, 18464, 26123,
     $  10635, 26521, 18315, 26649, 18443, 26646, 18712, 19097, 19353,
     $  19736, 19862, 19851, 27545, 19608, 19734, 19723, 28054, 20120,
     $  20505, 20761, 21144, 21270, 21259, 28953, 21016, 21142, 21131,
     $  26137, 18457, 26123, 18827, 27531, 20235, 28939, 13451, 26521,
     $  18315, 26649, 18443, 26646, 18712, 19097, 19353, 19736, 19862,
     $  19851, 27545, 19608, 19734, 19723, 26137, 18457, 26123, 18827,
     $  27531, 12043, 27033, 18456, 18198, 18067, 18065, 18190, 18444,
     $  18827, 19083, 19468, 19726, 19857, 19859, 19734, 19480, 19097/
      DATA IF034/ 18841, 27033, 18584, 18326, 18195, 18193, 18318,
     $  18572, 18827, 27275, 19340, 19598, 19729, 19731, 19606, 19352,
     $  10905, 26521, 18308, 26649, 18436, 26646, 18712, 18969, 19225,
     $  19608, 19862, 19987, 19985, 19854, 19596, 19211, 18955, 18700,
     $  18446, 27417, 19480, 19734, 19859, 19857, 19726, 19468, 19211,
     $  26137, 18457, 26116, 10628, 27801, 19588, 27929, 19716, 27798,
     $  19352, 19097, 18841, 18456, 18198, 18067, 18065, 18190, 18444,
     $  18827, 19083, 19340, 19598, 27033, 18584, 18326, 18195, 18193,
     $  18318, 18572, 18827, 27396, 11908, 26521, 18315, 26649, 18443,
     $  26643, 18582, 18840, 19097, 19481, 19608, 19607, 19478, 19351/
      DATA IF035/ 19480, 26137, 18457, 26123, 10635, 27543, 19481,
     $  19477, 19351, 19224, 18969, 18457, 18200, 18071, 18069, 18196,
     $  18451, 19089, 19344, 19471, 26262, 18197, 18452, 19090, 19345,
     $  19472, 19469, 19340, 19083, 18571, 18316, 18189, 18063, 18059,
     $   9997, 26528, 18319, 18444, 18699, 18955, 19212, 19342, 26656,
     $  18447, 18572, 18699, 26137, 10777, 26521, 18318, 18444, 18827,
     $  19083, 19468, 19726, 26649, 18446, 18572, 18827, 27929, 19723,
     $  28057, 19851, 26137, 18457, 27545, 19865, 27915, 12043, 26265,
     $  18827, 26393, 18829, 27801, 18827, 26009, 18585, 27289, 11673,
     $  26393, 18699, 26521, 18702, 27417, 18699, 27417, 19723, 27545/
      DATA IF036/ 19726, 28441, 19723, 26009, 18713, 28057, 12441,
     $  26393, 19595, 26521, 19723, 27929, 18187, 26137, 18713, 27417,
     $  19993, 26123, 18699, 27403, 11787, 26393, 18955, 26521, 18957,
     $  27929, 18955, 18695, 18437, 18180, 18052, 17925, 18054, 18181,
     $  26137, 18713, 27417, 11801, 27673, 18059, 27801, 18187, 26393,
     $  18069, 18073, 19609, 26251, 19595, 19599, 11275, 27044, 18595,
     $  18466, 18336, 18334, 18460, 18587, 18713, 18711, 18453, 26787,
     $  18465, 18463, 18589, 18716, 18842, 18840, 18710, 18196, 18706,
     $  18832, 18830, 18700, 18571, 18441, 18439, 18565, 26643, 18705,
     $  18703, 18573, 18444, 18314, 18312, 18438, 18565, 10628, 26404/
      DATA IF037/  9988, 26532, 18595, 18722, 18848, 18846, 18716,
     $  18587, 18457, 18455, 18709, 26787, 18721, 18719, 18589, 18460,
     $  18330, 18328, 18454, 18964, 18450, 18320, 18318, 18444, 18571,
     $  18697, 18695, 18565, 26899, 18449, 18447, 18573, 18700, 18826,
     $  18824, 18694, 18565, 10116, 26257, 18067, 18198, 18455, 18711,
     $  18966, 19475, 19730, 19986, 20243, 20373, 26259, 18197, 18454,
     $  18710, 18965, 19474, 19729, 19985, 20242, 20373, 12183, 25994,
     $  17826, 19874, 19850, 17802, 19874, 26018, 19850,  4490, 28184,
     $  19866, 19611, 19227, 18970, 18841, 18710, 18707, 18833, 19088,
     $  19472, 19729, 19859, 27419, 18969, 18838, 18835, 18961, 19088/
      DATA IF038/ 28187, 19859, 19857, 20112, 20368, 20626, 20757,
     $  20759, 20634, 20508, 20254, 19999, 19616, 19232, 18847, 18590,
     $  18332, 18202, 18071, 18068, 18193, 18319, 18573, 18828, 19211,
     $  19595, 19980, 20237, 20366, 28315, 19987, 19985, 11920, 27040,
     $  17803, 27040, 19851, 26386, 11282, 26400, 18187, 26400, 19360,
     $  19743, 19870, 19996, 19994, 19864, 19735, 19350, 26390, 19350,
     $  19733, 19860, 19986, 19983, 19853, 19724, 19339, 10001, 26400,
     $  18187, 26400, 11552, 27040, 17803, 27040, 19851, 25995, 11659,
     $  26400, 18187, 26400, 19872, 26390, 19222, 26379, 11659, 28064,
     $  18059, 26272, 19872, 26251, 11659, 26400, 18187, 28192, 19979/
      DATA IF039/ 26390, 11798, 27040, 18591, 18333, 18203, 18072,
     $  18067, 18192, 18318, 18572, 18827, 19339, 19596, 19854, 19984,
     $  20115, 20120, 19995, 19869, 19615, 19360, 18848, 26902, 11286,
     $  26400,  9995, 26400, 18187, 28192, 18194, 27031, 11787, 27040,
     $  17803, 27040, 11659, 26400, 18187, 26400, 19211, 28448, 19211,
     $  28448, 12043, 26400, 18187, 26400, 19979, 28192, 11787, 26144,
     $  19744, 26646, 19222, 26123, 11531, 27040, 18591, 18333, 18203,
     $  18072, 18067, 18192, 18318, 18572, 18827, 19339, 19596, 19854,
     $  19984, 20115, 20120, 19995, 19869, 19615, 19360, 10656, 26400,
     $  18187, 28192, 19979, 26400, 11808, 26400, 18187, 26400, 19360/
      DATA IF040/ 19743, 19870, 19996, 19993, 19863, 19734, 19349,
     $  10005, 26144, 18838, 17931, 26144, 19744, 26123, 11531, 26912,
     $  18699, 26016, 11424, 26139, 17949, 18079, 18208, 18464, 18591,
     $  18717, 18841, 18827, 27931, 19741, 19615, 19488, 19232, 19103,
     $  18973, 10649, 27168, 18955, 26907, 18330, 18201, 18071, 18068,
     $  18194, 18321, 18704, 19216, 19601, 19730, 19860, 19863, 19737,
     $  19610, 19227, 10523, 26272, 19851, 26251, 11680, 27296, 19083,
     $  26138, 18074, 18201, 18325, 18451, 18578, 18961, 19217, 19602,
     $  19731, 19861, 19993, 20122, 12058, 26251, 18571, 18194, 18070,
     $  18074, 18205, 18463, 18848, 19104, 19487, 19741, 19866, 19862/
      DATA IF041/ 19730, 19339, 11659, 25994, 17826, 19874, 19850,
     $  17802, 19874, 26018, 19850,  4490, 25994, 17826, 19874, 19850,
     $  17802, 19874, 26018, 19850,  4490, 26404, 18180, 26532, 18308,
     $  26404, 19108, 26372, 10884, 25994, 28042, 17826,  4490, 27044,
     $  18820, 27172, 18948, 26276, 18980, 26244, 10756, 25994, 26006,
     $  18846, 19862, 27038, 18830,  4490, 25994, 27022, 17814, 18846,
     $  26006, 19862,  4490, 25994, 26018, 19350,  4490, 27033, 18584,
     $  18326, 18196, 18065, 18062, 18188, 18443, 18699, 18956, 19343,
     $  19602, 19862, 19993, 27033, 19097, 19224, 19350, 19598, 19724,
     $  19851, 11787, 27424, 18975, 18717, 18457, 18326, 18194, 18060/
      DATA IF042/ 17924, 27424, 19488, 19742, 19739, 19609, 19480,
     $  19223, 18839, 27031, 19094, 19348, 19474, 19471, 19341, 19212,
     $  18955, 18699, 18444, 18317, 10000, 26006, 18072, 18329, 18457,
     $  18712, 18839, 18964, 18960, 18827, 28057, 19734, 19604, 18827,
     $  18567, 10244, 27289, 18713, 18456, 18198, 18067, 18064, 18189,
     $  18316, 18571, 18827, 19084, 19342, 19473, 19476, 19351, 19097,
     $  18843, 18717, 18719, 18848, 19104, 19359, 11421, 27543, 19224,
     $  18969, 18585, 18328, 18326, 18452, 18835, 27027, 18322, 18064,
     $  18062, 18188, 18443, 18827, 19084, 11150, 27168, 18719, 18590,
     $  18589, 18716, 19099, 19483, 27675, 18969, 18583, 18196, 18065/
      DATA IF043/ 18063, 18189, 18443, 18825, 18951, 18949, 18820,
     $  18564, 10246, 26005, 17943, 18201, 18457, 18584, 18582, 18450,
     $  18187, 26642, 18710, 18968, 19225, 19481, 19735, 19732, 19599,
     $  11012, 26005, 17943, 18201, 18457, 18584, 18582, 18449, 18446,
     $  18572, 18699, 18955, 19212, 19471, 19601, 19732, 19865, 19868,
     $  19743, 19488, 19232, 19102, 19100, 19225, 19478, 19732, 11922,
     $  26649, 18194, 18062, 18060, 18187, 18443, 18701, 10639, 26649,
     $  17931, 27928, 19609, 19481, 19224, 18708, 18451, 18323, 26515,
     $  18578, 18705, 18956, 19083, 19211, 11148, 26016, 18080, 18335,
     $  18462, 19467, 26905,  9739, 26777, 17796, 26645, 18320, 18317/
      DATA IF044/ 18571, 18827, 19084, 19342, 19602, 28057, 19602,
     $  19470, 19468, 19595, 19851, 20109, 12047, 26265, 18457, 18323,
     $  18190, 18059, 27929, 19606, 19476, 19217, 18830, 18444,  9867,
     $  27168, 18719, 18590, 18589, 18716, 19099, 19483, 27291, 18714,
     $  18457, 18327, 18325, 18579, 18962, 19218, 27154, 18449, 18192,
     $  18062, 18060, 18314, 18824, 18951, 18949, 18692, 10244, 26905,
     $  18456, 18198, 18067, 18064, 18189, 18316, 18571, 18827, 19084,
     $  19342, 19473, 19476, 19351, 19224, 18969, 10521, 27033, 18315,
     $  27673, 19603, 19726, 19851, 26134, 18200, 18585, 12057, 26387,
     $  18192, 18317, 18444, 18699, 18955, 19212, 19470, 19601, 19604/
      DATA IF045/ 19479, 19352, 19097, 18841, 18584, 18326, 18195,
     $   9476, 28185, 18713, 18456, 18198, 18067, 18064, 18189, 18316,
     $  18571, 18827, 19084, 19342, 19473, 19476, 19351, 19224, 10777,
     $  27289, 18699, 26134, 18200, 18585, 11801, 26005, 17943, 18201,
     $  18457, 18584, 18582, 18320, 18317, 18571, 18827, 19212, 19470,
     $  19730, 19862, 11673, 26904, 18455, 18197, 18066, 18063, 18189,
     $  18316, 18571, 18955, 19340, 19726, 19985, 20116, 20119, 19865,
     $  19609, 19351, 19091, 18830, 10244, 26137, 18201, 18455, 19206,
     $  19460, 19716, 28057, 19735, 19476, 18185, 17926,  9604, 27936,
     $  18692, 26005, 17943, 18201, 18457, 18584, 18582, 18449, 18446/
      DATA IF046/ 18572, 18827, 19083, 19468, 19726, 19985, 20246,
     $  12185, 26905, 18456, 18197, 18066, 18063, 18188, 18315, 18571,
     $  18828, 19087, 27411, 19087, 19212, 19339, 19595, 19852, 20111,
     $  20242, 20245, 20120, 11801, 25994, 17826, 19874, 19850, 17802,
     $  19874, 26018, 19850,  4490, 25994, 17826, 19874, 19850, 17802,
     $  19874, 26018, 19850,  4490, 27044, 18595, 18466, 18336, 18334,
     $  18460, 18587, 18713, 18711, 18453, 26787, 18465, 18463, 18589,
     $  18716, 18842, 18840, 18710, 18196, 18706, 18832, 18830, 18700,
     $  18571, 18441, 18439, 18565, 26643, 18705, 18703, 18573, 18444,
     $  18314, 18312, 18438, 18565, 10628, 26404,  9988, 26532, 18595/
      DATA IF047/ 18722, 18848, 18846, 18716, 18587, 18457, 18455,
     $  18709, 26787, 18721, 18719, 18589, 18460, 18330, 18328, 18454,
     $  18964, 18450, 18320, 18318, 18444, 18571, 18697, 18695, 18565,
     $  26899, 18449, 18447, 18573, 18700, 18826, 18824, 18694, 18565,
     $  10116, 26257, 18067, 18198, 18455, 18711, 18966, 19475, 19730,
     $  19986, 20243, 20373, 26259, 18197, 18454, 18710, 18965, 19474,
     $  19729, 19985, 20242, 20373, 12183, 25994, 17826, 19874, 19850,
     $  17802, 19874, 26018, 19850,  4490,  4490, 26912, 18591, 18323,
     $  26911, 18323, 26912, 18847, 18323, 26253, 17932, 18059, 18188,
     $   9869, 25994, 26522, 18338, 27554, 19354,  4490, 27296, 18180/
      DATA IF048/ 28064, 18948, 26389, 19989, 26255, 11663, 27428,
     $  18183, 28068, 18823, 28188, 19867, 19994, 20123, 20124, 19998,
     $  19871, 19488, 18976, 18591, 18333, 18331, 18457, 18584, 19476,
     $  19730, 26523, 18585, 19477, 19604, 19730, 19727, 19597, 19468,
     $  19083, 18571, 18188, 18061, 17935, 17936, 18065, 18192,  9871,
     $  28576, 18059, 26912, 18974, 18972, 18842, 18585, 18329, 18075,
     $  18077, 18207, 18464, 18720, 18975, 19358, 19742, 20127, 20384,
     $  28050, 19601, 19471, 19469, 19723, 19979, 20236, 20366, 20368,
     $  20114, 11666, 28568, 20247, 20374, 20503, 20504, 20377, 20249,
     $  20120, 19990, 19729, 19470, 19212, 18955, 18571, 18188, 18062/
      DATA IF049/ 18065, 18195, 18967, 19225, 19355, 19357, 19231,
     $  18976, 18719, 18589, 18587, 18712, 18965, 19598, 19852, 20235,
     $  20363, 20492, 20493, 26763, 18316, 18190, 18193, 18323, 18581,
     $  26779, 18713, 19726, 19980, 12043, 25994, 26522, 18846, 18850,
     $   4490, 27812, 19105, 18718, 18459, 18199, 18066, 18062, 18185,
     $  18310, 18436, 27297, 18717, 18457, 18326, 18193, 18188, 18311,
     $  10244, 27044, 18978, 19103, 19226, 19222, 19089, 18829, 18570,
     $  18183, 17668, 27044, 18977, 19100, 19095, 18962, 18831, 18571,
     $   9991, 27168, 18964, 26525, 19607, 27805, 10135, 27549, 19339,
     $  26388, 12308, 26251, 17932, 18061, 18188, 18187, 18057,  9607/
      DATA IF050/ 26388, 12308, 26253, 17932, 18059, 18188,  9869,
     $  28964,  9220, 27424, 18847, 18589, 18330, 18199, 18067, 18064,
     $  18189, 18316, 18571, 18827, 19212, 19470, 19729, 19860, 19992,
     $  19995, 19870, 19743, 19488, 19232, 27424, 18975, 18717, 18458,
     $  18327, 18195, 18192, 18317, 18571, 27019, 19084, 19342, 19601,
     $  19732, 19864, 19867, 19742, 11296, 27420, 18571, 27680, 18699,
     $  27680, 19101, 18715, 18458, 27549, 18843, 10266, 26780, 18715,
     $  18586, 18459, 18460, 18590, 18719, 19104, 19488, 19871, 19997,
     $  19995, 19865, 19607, 19221, 18707, 18321, 18063, 17803, 27680,
     $  19743, 19869, 19867, 19737, 19479, 18707, 26125, 18062, 18318/
      DATA IF051/ 18956, 19340, 19597, 19727, 26510, 18955, 19339,
     $  19596, 11535, 26780, 18715, 18586, 18459, 18460, 18590, 18719,
     $  19104, 19488, 19871, 19997, 19995, 19865, 19479, 19094, 27680,
     $  19743, 19869, 19867, 19737, 19479, 27030, 19094, 19477, 19604,
     $  19730, 19727, 19597, 19468, 19083, 18571, 18188, 18061, 17935,
     $  17936, 18065, 18192, 18063, 27286, 19349, 19476, 19602, 19599,
     $  19469, 19340, 10891, 27935, 18955, 28064, 19083, 28064, 17937,
     $  11793, 27040, 18198, 27040, 20128, 27039, 19487, 20128, 26390,
     $  18327, 18712, 19096, 19479, 19606, 19732, 19729, 19598, 19340,
     $  18955, 18571, 18188, 18061, 17935, 17936, 18065, 18192, 18063/
      DATA IF052/ 27288, 19351, 19478, 19604, 19601, 19470, 19212,
     $  10763, 28061, 19740, 19867, 19996, 19997, 19871, 19616, 19232,
     $  18847, 18589, 18330, 18199, 18067, 18063, 18189, 18316, 18571,
     $  18955, 19340, 19598, 19728, 19731, 19605, 19478, 19223, 18839,
     $  18582, 18324, 18194, 27424, 18975, 18717, 18458, 18327, 18195,
     $  18190, 18316, 27147, 19212, 19470, 19600, 19604, 11286, 26656,
     $  18202, 28320, 19997, 19738, 19092, 18833, 18703, 18571, 27930,
     $  18964, 18705, 18575, 18443, 26525, 18720, 18976, 19613, 26654,
     $  18719, 18975, 19613, 19869, 19998, 11936, 27296, 18719, 18590,
     $  18460, 18457, 18583, 18838, 19222, 19735, 19864, 19994, 19997/
      DATA IF053/ 19871, 19488, 19104, 27296, 18847, 18718, 18588,
     $  18585, 18711, 18838, 27414, 19607, 19736, 19866, 19869, 19743,
     $  19488, 27030, 18325, 18067, 17937, 17934, 18060, 18443, 18955,
     $  19468, 19597, 19727, 19730, 19604, 19477, 19222, 27030, 18453,
     $  18195, 18065, 18062, 18188, 18443, 27147, 19340, 19469, 19599,
     $  19603, 11285, 28057, 19735, 19477, 19220, 18836, 18581, 18454,
     $  18328, 18331, 18461, 18719, 19104, 19488, 19743, 19870, 19996,
     $  19992, 19860, 19729, 19470, 19212, 18827, 18443, 18188, 18062,
     $  18063, 18192, 18319, 18190, 26773, 18455, 18459, 18589, 18847,
     $  19104, 27935, 19869, 19864, 19732, 19601, 19342, 19084, 10635/
      DATA IF054/ 26649, 18328, 18455, 18584, 18457, 26253, 17932,
     $  18059,  9996, 26649, 18328, 18455, 18584, 18457, 26251, 17932,
     $  18061, 18188, 18187, 18057,  9607, 28445, 18196, 12043, 26391,
     $  20503, 26385, 12305, 26397, 20244,  9995, 26780, 18715, 18586,
     $  18459, 18460, 18590, 18719, 19104, 19616, 19999, 20125, 20123,
     $  19993, 19864, 19094, 18837, 18835, 18962, 19218, 27808, 19871,
     $  19997, 19995, 19865, 19736, 19479, 26893, 18572, 18699, 18828,
     $  10509, 28184, 19866, 19611, 19227, 18970, 18841, 18710, 18707,
     $  18833, 19088, 19472, 19729, 19859, 27419, 18969, 18838, 18835,
     $  18961, 19088, 28187, 19859, 19857, 20112, 20368, 20626, 20757/
      DATA IF055/ 20759, 20634, 20508, 20254, 19999, 19616, 19232,
     $  18847, 18590, 18332, 18202, 18071, 18068, 18193, 18319, 18573,
     $  18828, 19211, 19595, 19980, 20237, 20366, 28315, 19987, 19985,
     $  11920, 27552, 17675, 27552, 19467, 27422, 19339, 26385, 19345,
     $  25611, 18187, 27147, 11531, 27040, 18059, 27168, 18187, 26656,
     $  19872, 20255, 20381, 20379, 20248, 20119, 19734, 28064, 20127,
     $  20253, 20251, 20120, 19991, 19734, 26774, 19734, 19989, 20115,
     $  20113, 19982, 19724, 19211, 17675, 27926, 19861, 19987, 19985,
     $  19854, 19596, 11019, 28190, 20126, 20256, 20122, 20124, 19998,
     $  19871, 19616, 19232, 18847, 18589, 18330, 18199, 18067, 18064/
      DATA IF056/ 18189, 18316, 18699, 19083, 19340, 19598, 19728,
     $  27424, 18975, 18717, 18458, 18327, 18195, 18192, 18317, 18444,
     $  10507, 27040, 18059, 27168, 18187, 26656, 19616, 19999, 20126,
     $  20251, 20247, 20115, 19855, 19597, 19340, 18827, 17675, 27808,
     $  19871, 19998, 20123, 20119, 19987, 19727, 19469, 19212, 10635,
     $  27040, 18059, 27168, 18187, 27674, 19218, 26656, 20384, 20250,
     $  20256, 26774, 19350, 25867, 19595, 19856, 11275, 27040, 18059,
     $  27168, 18187, 27674, 19218, 26656, 20384, 20250, 20256, 26774,
     $  19350, 25867, 10379, 28190, 20126, 20256, 20122, 20124, 19998,
     $  19871, 19616, 19232, 18847, 18589, 18330, 18199, 18067, 18064/
      DATA IF057/ 18189, 18316, 18699, 18955, 19340, 19598, 19858,
     $  27424, 18975, 18717, 18458, 18327, 18195, 18192, 18317, 18444,
     $  18699, 27147, 19212, 19470, 19730, 27538, 12050, 27040, 18059,
     $  27168, 18187, 28704, 19723, 28832, 19851, 26656, 19360, 28320,
     $  21024, 26774, 20118, 25867, 18571, 27531, 12043, 27040, 18059,
     $  27168, 18187, 26656, 19360, 25867, 10379, 27808, 18959, 18829,
     $  18700, 18443, 18187, 17932, 17806, 17808, 17937, 18064, 17935,
     $  27680, 18831, 18701, 18443, 27296, 11808, 27040, 18059, 27168,
     $  18187, 28832, 18451, 27543, 19851, 27415, 19723, 26656, 19360,
     $  28320, 20896, 25867, 18571, 27531, 11915, 27040, 18059, 27168/
      DATA IF058/ 18187, 26656, 19360, 25867, 19595, 19857, 11275,
     $  27040, 18059, 27040, 18955, 27168, 19085, 28832, 18955, 28832,
     $  19851, 28960, 19979, 26656, 18976, 28832, 21152, 25867, 18443,
     $  27659, 12171, 27040, 18059, 27040, 19726, 27037, 19723, 28704,
     $  19723, 26656, 18848, 28320, 20896, 25867, 10251, 27424, 18847,
     $  18589, 18330, 18199, 18067, 18064, 18189, 18316, 18571, 18955,
     $  19340, 19598, 19857, 19988, 20120, 20123, 19998, 19871, 19616,
     $  19232, 27424, 18975, 18717, 18458, 18327, 18195, 18192, 18317,
     $  18571, 27147, 19212, 19470, 19729, 19860, 19992, 19995, 19870,
     $  11424, 27040, 18059, 27168, 18187, 26656, 20000, 20383, 20509/
      DATA IF059/ 20507, 20376, 20118, 19605, 18581, 28192, 20255,
     $  20381, 20379, 20248, 19990, 19605, 25867, 10379, 27424, 18847,
     $  18589, 18330, 18199, 18067, 18064, 18189, 18316, 18571, 18955,
     $  19340, 19598, 19857, 19988, 20120, 20123, 19998, 19871, 19616,
     $  19232, 27424, 18975, 18717, 18458, 18327, 18195, 18192, 18317,
     $  18571, 27147, 19212, 19470, 19729, 19860, 19992, 19995, 19870,
     $  19616, 26509, 18318, 18448, 18705, 18833, 19088, 19214, 19207,
     $  19334, 19590, 19720, 19721, 27406, 19336, 19463, 19591, 11528,
     $  27040, 18059, 27168, 18187, 26656, 19872, 20255, 20381, 20379,
     $  20248, 20119, 19734, 18582, 28064, 20127, 20253, 20251, 20120/
      DATA IF060/ 19991, 19734, 27414, 19477, 19604, 19724, 19851,
     $  20107, 20237, 20238, 27796, 19853, 19980, 20108, 20237, 25867,
     $  10379, 28318, 20254, 20384, 20250, 20252, 20126, 19999, 19616,
     $  19104, 18719, 18461, 18459, 18585, 18712, 19604, 19858, 26651,
     $  18713, 19605, 19732, 19858, 19855, 19725, 19596, 19211, 18699,
     $  18316, 18189, 18063, 18065, 17931, 18061,  9997, 27552, 18571,
     $  27680, 18699, 26784, 18202, 18464, 20384, 20250, 20256, 26379,
     $  10891, 26912, 18325, 18193, 18190, 18316, 18699, 19211, 19596,
     $  19854, 19985, 20512, 27040, 18453, 18321, 18318, 18444, 18699,
     $  26528, 19232, 28320, 12704, 26656, 18571, 26784, 18701, 28448/
      DATA IF061/ 18571, 26400, 18976, 27936, 12320, 26912, 18443,
     $  27040, 18573, 27936, 18443, 27936, 19467, 28064, 19597, 28960,
     $  19467, 26528, 19232, 28576, 12960, 26784, 19467, 26912, 19595,
     $  28576, 17803, 26528, 19104, 28064, 20640, 25739, 18315, 27275,
     $  11659, 26656, 18966, 18571, 26784, 19094, 18699, 28576, 19094,
     $  26400, 18976, 28064, 20640, 26379, 10891, 28448, 17803, 28576,
     $  17931, 26912, 18330, 18592, 20384, 25995, 19595, 19857, 11275,
     $  26404, 18180, 26532, 18308, 26404, 19108, 26372, 10884, 25994,
     $  28042, 17826,  4490, 27044, 18820, 27172, 18948, 26276, 18980,
     $  26244, 10756, 25994, 26006, 18846, 19862, 27038, 18830,  4490/
      DATA IF062/ 25994, 27022, 17814, 18846, 26006, 19862,  4490,
     $  25994, 26018, 19350,  4490, 27929, 19474, 19342, 19340, 19467,
     $  19851, 20109, 20239, 28057, 19602, 19470, 19468, 19595, 27666,
     $  19477, 19352, 19097, 18841, 18456, 18197, 18066, 18063, 18189,
     $  18316, 18571, 18827, 19084, 19343, 19474, 27033, 18584, 18325,
     $  18194, 18190, 10124, 26912, 18195, 18192, 18317, 18444, 27040,
     $  18323, 26515, 18454, 18712, 18969, 19225, 19480, 19607, 19733,
     $  19730, 19599, 19340, 18955, 18699, 18444, 18319, 18323, 27672,
     $  19606, 19602, 19471, 19212, 18955, 26528, 10656, 27670, 19477,
     $  19605, 19606, 19480, 19225, 18841, 18456, 18197, 18066, 18063/
      DATA IF063/ 18189, 18316, 18571, 18827, 19212, 19471, 27033,
     $  18584, 18325, 18194, 18190, 10124, 28192, 19474, 19342, 19340,
     $  19467, 19851, 20109, 20239, 28320, 19602, 19470, 19468, 19595,
     $  27666, 19477, 19352, 19097, 18841, 18456, 18197, 18066, 18063,
     $  18189, 18316, 18571, 18827, 19084, 19343, 19474, 27033, 18584,
     $  18325, 18194, 18190, 18316, 27808, 11936, 26384, 18705, 19090,
     $  19476, 19606, 19480, 19225, 18841, 18456, 18197, 18066, 18063,
     $  18189, 18316, 18571, 18827, 19212, 19470, 27033, 18584, 18325,
     $  18194, 18190, 10124, 27807, 19486, 19613, 19742, 19743, 19616,
     $  19360, 19103, 18974, 18844, 18713, 18315, 18183, 18053, 27552/
      DATA IF064/ 19102, 18972, 18840, 18575, 18443, 18312, 18182,
     $  18053, 17796, 17540, 17413, 17414, 17543, 17670, 17541, 26393,
     $  11289, 28057, 19339, 19208, 18949, 18564, 18180, 17925, 17798,
     $  17799, 17928, 18055, 17926, 27929, 19211, 19080, 18821, 18564,
     $  27666, 19477, 19352, 19097, 18841, 18456, 18197, 18066, 18063,
     $  18189, 18316, 18571, 18827, 19084, 19343, 19474, 27033, 18584,
     $  18325, 18194, 18190, 10124, 26912, 17931, 27040, 18059, 26514,
     $  18582, 18840, 19097, 19353, 19608, 19735, 19733, 19471, 19468,
     $  19595, 27545, 19607, 19605, 19343, 19340, 19467, 19851, 20109,
     $  20239, 26528, 10656, 27040, 18719, 18846, 18975, 18848, 26005/
      DATA IF065/ 17943, 18201, 18585, 18712, 18709, 18447, 18444,
     $  18571, 26649, 18584, 18581, 18319, 18316, 18443, 18827, 19085,
     $  11023, 27168, 18847, 18974, 19103, 18976, 26133, 18071, 18329,
     $  18713, 18840, 18837, 18443, 18312, 18182, 18053, 17796, 17540,
     $  17413, 17414, 17543, 17670, 17541, 26777, 18712, 18709, 18315,
     $  18184, 18054,  9604, 26912, 17931, 27040, 18059, 27928, 19607,
     $  19734, 19863, 19864, 19737, 19609, 19352, 18836, 18579, 18323,
     $  26771, 18834, 19084, 19211, 26771, 18706, 18956, 19083, 19339,
     $  19596, 19855, 26528, 10656, 26912, 18194, 18062, 18060, 18187,
     $  18571, 18829, 18959, 27040, 18322, 18190, 18188, 18315, 26528/
      DATA IF066/ 10656, 26005, 17943, 18201, 18585, 18712, 18710,
     $  18578, 18315, 26649, 18584, 18582, 18450, 18187, 26770, 18838,
     $  19096, 19353, 19609, 19864, 19991, 19989, 19595, 27801, 19863,
     $  19861, 19467, 28050, 20118, 20376, 20633, 20889, 21144, 21271,
     $  21269, 21007, 21004, 21131, 29081, 21143, 21141, 20879, 20876,
     $  21003, 21387, 21645, 13583, 26005, 17943, 18201, 18585, 18712,
     $  18710, 18578, 18315, 26649, 18584, 18582, 18450, 18187, 26770,
     $  18838, 19096, 19353, 19609, 19864, 19991, 19989, 19727, 19724,
     $  19851, 27801, 19863, 19861, 19599, 19596, 19723, 20107, 20365,
     $  12303, 27033, 18456, 18197, 18066, 18063, 18189, 18316, 18571/
      DATA IF067/ 18827, 19212, 19471, 19602, 19605, 19479, 19352,
     $  19097, 18841, 27033, 18584, 18325, 18194, 18190, 18316, 27019,
     $  19084, 19343, 19474, 19478, 11160, 26005, 17943, 18201, 18585,
     $  18712, 18710, 18578, 18052, 26649, 18584, 18582, 18450, 17924,
     $  26770, 18709, 18968, 19225, 19481, 19736, 19863, 19989, 19986,
     $  19855, 19596, 19211, 18955, 18700, 18575, 18578, 27928, 19862,
     $  19858, 19727, 19468, 19211, 25732, 10244, 27929, 18948, 28057,
     $  19076, 27666, 19477, 19352, 19097, 18841, 18456, 18197, 18066,
     $  18063, 18189, 18316, 18571, 18827, 19084, 19343, 19474, 27033,
     $  18584, 18325, 18194, 18190, 18316, 26756, 11268, 26005, 17943/
      DATA IF068/ 18201, 18585, 18712, 18710, 18578, 18315, 26649,
     $  18584, 18582, 18450, 18187, 26770, 18838, 19096, 19353, 19609,
     $  19736, 19735, 19606, 19479, 11416, 27671, 19478, 19606, 19607,
     $  19480, 19097, 18713, 18328, 18199, 18197, 18324, 19216, 19343,
     $  26390, 18325, 19217, 19344, 19341, 19212, 18827, 18443, 18060,
     $  17933, 17934, 18062,  9869, 27040, 18322, 18190, 18188, 18315,
     $  18699, 18957, 19087, 27168, 18450, 18318, 18316, 18443, 26265,
     $  11033, 26005, 17943, 18201, 18585, 18712, 18709, 18447, 18445,
     $  18699, 26649, 18584, 18581, 18319, 18317, 18444, 18699, 18955,
     $  19212, 19470, 19730, 28185, 19730, 19598, 19596, 19723, 20107/
      DATA IF069/ 20365, 20495, 28313, 19858, 19726, 19724, 11659,
     $  26005, 17943, 18201, 18585, 18712, 18709, 18447, 18445, 18699,
     $  26649, 18584, 18581, 18319, 18317, 18444, 18699, 18827, 19212,
     $  19470, 19729, 19861, 19865, 19737, 11671, 26005, 17943, 18201,
     $  18585, 18712, 18709, 18447, 18445, 18699, 26649, 18584, 18581,
     $  18319, 18317, 18444, 18699, 18955, 19212, 19470, 19600, 28057,
     $  19600, 19597, 19724, 19979, 20235, 20492, 20750, 20880, 21012,
     $  21017, 20889, 21015, 28185, 19728, 19725, 11787, 26261, 18328,
     $  18585, 18969, 19095, 19092, 27033, 18967, 18964, 18832, 18702,
     $  18444, 18187, 18059, 17932, 17933, 18062, 18189, 18060, 27024/
      DATA IF070/ 18829, 18955, 19339, 19596, 19855, 28056, 19735,
     $  19862, 19991, 19992, 19865, 19737, 19480, 19222, 19092, 18960,
     $  18957, 10891, 26005, 17943, 18201, 18585, 18712, 18709, 18447,
     $  18445, 18699, 26649, 18584, 18581, 18319, 18317, 18444, 18699,
     $  18955, 19212, 19470, 19730, 28313, 19595, 19464, 19205, 18820,
     $  18436, 18181, 18054, 18055, 18184, 18311, 18182, 28185, 19467,
     $  19336, 19077, 10628, 28057, 19735, 19477, 18447, 18189, 18059,
     $  26389, 18327, 18585, 18969, 19479, 26519, 18584, 18968, 19479,
     $  19735, 26381, 18445, 18956, 19340, 19597, 26637, 18955, 19339,
     $  19597, 11535, 27044, 18595, 18466, 18336, 18334, 18460, 18587/
      DATA IF071/ 18713, 18711, 18453, 26787, 18465, 18463, 18589,
     $  18716, 18842, 18840, 18710, 18196, 18706, 18832, 18830, 18700,
     $  18571, 18441, 18439, 18565, 26643, 18705, 18703, 18573, 18444,
     $  18314, 18312, 18438, 18565, 10628, 26404,  9988, 26532, 18595,
     $  18722, 18848, 18846, 18716, 18587, 18457, 18455, 18709, 26787,
     $  18721, 18719, 18589, 18460, 18330, 18328, 18454, 18964, 18450,
     $  18320, 18318, 18444, 18571, 18697, 18695, 18565, 26899, 18449,
     $  18447, 18573, 18700, 18826, 18824, 18694, 18565, 10116, 26257,
     $  18067, 18198, 18455, 18711, 18966, 19475, 19730, 19986, 20243,
     $  20373, 26259, 18197, 18454, 18710, 18965, 19474, 19729, 19985/
      DATA IF072/ 20242, 20373, 12183, 25994, 17826, 19874, 19850,
     $  17802, 19874, 26018, 19850,  4490,  4490, 26528, 18206, 18322,
     $  18462, 18336, 26526, 18328, 26509, 18188, 18315, 18444, 10125,
     $  25994, 26522, 18338, 27554, 19354,  4490, 27296, 18180, 28064,
     $  18948, 26389, 19989, 26255, 11663, 27044, 18823, 18951, 27044,
     $  18980, 18951, 27677, 19741, 19487, 19104, 18720, 18335, 18077,
     $  18075, 18201, 18328, 19348, 19475, 19601, 19599, 19469, 19084,
     $  18700, 18445, 18318, 27677, 19358, 19103, 18719, 18334, 18205,
     $  18203, 18329, 19349, 19603, 19729, 19727, 19597, 19468, 19083,
     $  18699, 18316, 18062, 18318, 27790, 11020, 28576, 18059, 26912/
      DATA IF073/ 18974, 18972, 18842, 18585, 18329, 18075, 18077,
     $  18207, 18464, 18720, 18975, 19358, 19742, 20127, 20384, 28050,
     $  19601, 19471, 19469, 19723, 19979, 20236, 20366, 20368, 20114,
     $  11666, 28568, 20247, 20374, 20503, 20504, 20377, 20249, 20120,
     $  19990, 19729, 19470, 19212, 18955, 18571, 18188, 18062, 18065,
     $  18195, 18967, 19225, 19355, 19357, 19231, 18976, 18719, 18589,
     $  18587, 18712, 18965, 19598, 19852, 20235, 20363, 20492, 20493,
     $  26763, 18316, 18190, 18193, 18323, 18581, 26779, 18713, 19726,
     $  19980, 12043, 25994, 26522, 18846, 18850,  4490, 27172, 18722,
     $  18463, 18203, 18070, 18066, 18189, 18441, 18694, 18948, 19076/
      DATA IF074/ 27172, 19108, 18850, 18591, 18331, 18198, 18194,
     $  18317, 18569, 18822, 10884, 26276, 18338, 18591, 18843, 18966,
     $  18962, 18829, 18569, 18310, 18052, 18180, 26276, 18212, 18466,
     $  18719, 18971, 19094, 19090, 18957, 18697, 18438,  9988, 26912,
     $  18591, 18837, 18708, 26912, 18708, 26912, 18847, 18581, 18708,
     $  26269, 18205, 19223, 19351, 26269, 19351, 26269, 18076, 19352,
     $  19351, 27549, 19229, 18199, 18071, 27549, 18071, 27549, 19356,
     $  18072,  9879, 27421, 19212, 19340, 27421, 19357, 19340, 26389,
     $  20373, 20372, 26389, 18196, 12180, 26764, 18443, 18315, 18188,
     $  18189, 18318, 18446, 18573, 18570, 18440, 18183, 26509, 18316/
      DATA IF075/ 18444, 18445, 18317, 26635, 18570, 26764, 10248,
     $  26389, 20373, 20372, 26389, 18196, 12180, 26510, 18189, 18188,
     $  18315, 18443, 18572, 18573, 18446, 18318, 26509, 18316, 18444,
     $  18445, 10125, 28452, 17924, 18052, 28452, 20388,  9860, 27040,
     $  18463, 18204, 18071, 18068, 18191, 18444, 18827, 19083, 19468,
     $  19727, 19860, 19863, 19740, 19487, 19104, 18848, 26783, 18332,
     $  18199, 18196, 18319, 18572, 26637, 18828, 19084, 19469, 27532,
     $  19599, 19732, 19735, 19612, 19359, 27678, 19103, 18847, 10270,
     $  26652, 18717, 19104, 19083, 26652, 18459, 18716, 18974, 18955,
     $  10891, 26395, 18204, 18334, 18463, 18720, 19232, 19487, 19614/
      DATA IF076/ 19740, 19738, 19608, 19349, 18187, 26395, 18331,
     $  18332, 18462, 18719, 19231, 19486, 19612, 19610, 19480, 19221,
     $  18059, 26380, 19852, 19851, 26251, 11659, 26528, 19744, 18839,
     $  26528, 18335, 19615, 27808, 18711, 27032, 19096, 19479, 19733,
     $  19858, 19857, 19726, 19468, 19083, 18699, 18316, 18189, 18063,
     $  18191, 26903, 19095, 19478, 19731, 27415, 19605, 19730, 19729,
     $  19598, 19212, 27920, 19469, 19084, 18700, 18317, 18191, 26764,
     $   9998, 27549, 19339, 19467, 27680, 19467, 27680, 18064, 19984,
     $  27549, 18192, 26385, 19985, 11792, 26528, 18199, 26655, 18328,
     $  26528, 19616, 19615, 26655, 19615, 26520, 18713, 19097, 19480/
      DATA IF077/ 19734, 19859, 19857, 19726, 19468, 19083, 18699,
     $  18316, 18189, 18063, 18191, 26391, 18327, 18584, 19096, 19479,
     $  19732, 27416, 19606, 19731, 19729, 19598, 19212, 27920, 19469,
     $  19084, 18700, 18317, 18191, 26764,  9998, 27679, 19613, 19741,
     $  19615, 19232, 18976, 18591, 18332, 18199, 18194, 18318, 18572,
     $  18955, 19083, 19468, 19726, 19857, 19858, 19733, 19479, 19096,
     $  18968, 18583, 18325, 27806, 19231, 18975, 18590, 26911, 18460,
     $  18327, 18322, 18446, 18828, 26512, 18573, 18956, 19084, 19469,
     $  19728, 27404, 19598, 19729, 19730, 19605, 19223, 27923, 19478,
     $  19095, 18967, 18582, 18323, 27031, 18453, 10130, 26272, 19872/
      DATA IF078/ 18571, 26272, 18079, 19743, 27936, 18443, 10379,
     $  26912, 18335, 18205, 18203, 18329, 18456, 18711, 19222, 19477,
     $  19604, 19730, 19727, 19597, 19212, 18700, 18317, 18191, 18194,
     $  18324, 18453, 18710, 19223, 19480, 19609, 19739, 19741, 19615,
     $  19232, 18720, 26655, 18333, 18331, 18457, 18712, 19223, 19478,
     $  19732, 19858, 19855, 19725, 19596, 19211, 18699, 18316, 18189,
     $  18063, 18066, 18196, 18454, 18711, 19224, 19481, 19611, 19613,
     $  19487, 27806, 19231, 18719, 18334, 26382, 18572, 27532, 11534,
     $  27798, 19348, 18963, 18835, 18452, 18198, 18073, 18074, 18205,
     $  18463, 18848, 18976, 19359, 19613, 19737, 19732, 19599, 19340/
      DATA IF079/ 18955, 18699, 18316, 18190, 18318, 18444, 27801,
     $  19478, 19092, 27800, 19349, 18964, 18836, 18453, 18200, 26900,
     $  18326, 18201, 18202, 18333, 18719, 26395, 18462, 18847, 18975,
     $  19358, 19611, 10911, 26521, 18200, 18327, 18456, 18329, 26509,
     $  18188, 18315, 18444, 10125, 26521, 18200, 18327, 18456, 18329,
     $  26507, 18188, 18317, 18444, 18442, 18312,  9991, 28445, 18196,
     $  12043, 26393, 20377, 20376, 26393, 18200, 20376, 26385, 20369,
     $  20368, 26385, 18192, 12176, 26397, 20244,  9995, 26396, 18331,
     $  18202, 18075, 18076, 18206, 18335, 18592, 18976, 19359, 19486,
     $  19612, 19610, 19480, 19351, 18837, 18834, 27168, 19231, 19358/
      DATA IF080/ 19484, 19482, 19352, 19094, 27021, 18700, 18827,
     $  18956, 10637, 28184, 19866, 19611, 19227, 18970, 18841, 18710,
     $  18707, 18833, 19088, 19472, 19729, 19859, 27419, 18969, 18838,
     $  18835, 18961, 19088, 28187, 19859, 19857, 20112, 20368, 20626,
     $  20757, 20759, 20634, 20508, 20254, 19999, 19616, 19232, 18847,
     $  18590, 18332, 18202, 18071, 18068, 18193, 18319, 18573, 18828,
     $  19211, 19595, 19980, 20237, 20366, 28315, 19987, 19985, 11920,
     $  27168, 17931, 27165, 18059, 17931, 27165, 19851, 19979, 27168,
     $  19979, 26513, 19601, 26384, 11536, 26400, 18187, 26527, 18316,
     $  26400, 19232, 19615, 19742, 19868, 19865, 19735, 19606, 19221/
      DATA IF081/ 26527, 19231, 19614, 19740, 19737, 19607, 19222,
     $  26518, 19222, 19605, 19732, 19858, 19855, 19725, 19596, 19211,
     $  18187, 26517, 19221, 19604, 19730, 19727, 19597, 19212, 10124,
     $  28187, 19869, 19615, 19360, 18848, 18591, 18333, 18203, 18072,
     $  18067, 18192, 18318, 18572, 18827, 19339, 19596, 19854, 19984,
     $  28187, 19867, 19741, 19614, 19359, 18847, 18590, 18331, 18200,
     $  18195, 18320, 18573, 18828, 19340, 19597, 19726, 19856, 11792,
     $  26400, 18187, 26527, 18316, 26400, 19104, 19487, 19741, 19867,
     $  19992, 19987, 19856, 19726, 19468, 19083, 18187, 26527, 19103,
     $  19486, 19613, 19739, 19864, 19859, 19728, 19598, 19469, 19084/
      DATA IF082/ 10124, 26400, 18187, 26527, 18316, 26400, 19744,
     $  26527, 19743, 19744, 26518, 19094, 19093, 26517, 19093, 26508,
     $  19724, 19723, 26379, 11531, 26400, 18187, 26527, 18315, 18187,
     $  26400, 19744, 26527, 19743, 19744, 26518, 19094, 19093, 26517,
     $  10901, 28187, 19869, 19615, 19360, 18848, 18591, 18333, 18203,
     $  18072, 18067, 18192, 18318, 18572, 18827, 19339, 19596, 19854,
     $  19984, 19988, 19348, 28187, 19867, 19741, 19614, 19359, 18847,
     $  18590, 18461, 18331, 18200, 18195, 18320, 18446, 18573, 18828,
     $  19340, 19597, 19726, 19856, 19859, 19347, 11156, 26400, 18187,
     $  26400, 18336, 18315, 18187, 28192, 19872, 19851, 19979, 28192/
      DATA IF083/ 19979, 26518, 19862, 26517, 11669, 26400, 18187,
     $  18315, 26400, 18336, 10123, 27424, 19216, 19085, 18828, 18572,
     $  18317, 18192, 18064, 27424, 19360, 19344, 19213, 19084, 18827,
     $  18571, 18316, 18189,  9872, 26400, 18187, 18315, 26400, 18336,
     $  18315, 28192, 19872, 18324, 28192, 18323, 26903, 19851, 19979,
     $  27031, 11787, 26400, 18187, 26400, 18336, 18316, 26508, 19724,
     $  19723, 26379, 11531, 26400, 18187, 26523, 18315, 18187, 26523,
     $  19211, 26400, 19214, 28448, 19214, 28315, 19211, 28315, 20107,
     $  20235, 28448, 12043, 26400, 18187, 26525, 18315, 18187, 26525,
     $  19979, 26400, 19854, 28064, 19854, 28064, 20000, 11787, 27040/
      DATA IF084/ 18591, 18333, 18203, 18072, 18067, 18192, 18318,
     $  18572, 18827, 19339, 19596, 19854, 19984, 20115, 20120, 19995,
     $  19869, 19615, 19360, 18848, 27167, 18590, 18331, 18200, 18195,
     $  18320, 18573, 18956, 19212, 19597, 19856, 19987, 19992, 19867,
     $  19614, 19231, 10783, 26400, 18187, 26527, 18315, 18187, 26400,
     $  19360, 19615, 19742, 19868, 19865, 19735, 19606, 19349, 18325,
     $  26527, 19359, 19614, 19740, 19737, 19607, 19350, 10134, 27040,
     $  18591, 18333, 18203, 18072, 18067, 18192, 18318, 18572, 18827,
     $  19339, 19596, 19854, 19984, 20115, 20120, 19995, 19869, 19615,
     $  19360, 18848, 27167, 18590, 18331, 18200, 18195, 18320, 18573/
      DATA IF085/ 18956, 19212, 19597, 19856, 19987, 19992, 19867,
     $  19614, 19231, 18975, 27406, 19849, 19977, 27406, 19342, 11785,
     $  26400, 18187, 26527, 18315, 18187, 26400, 19232, 19615, 19742,
     $  19868, 19865, 19735, 19606, 19221, 18325, 26527, 19231, 19614,
     $  19740, 19737, 19607, 19222, 18326, 27157, 19723, 19851, 27285,
     $  11659, 28061, 19615, 19232, 18720, 18335, 18077, 18075, 18201,
     $  18328, 18583, 19221, 19476, 19603, 19729, 19726, 19597, 19212,
     $  18700, 18445, 18318, 18062, 28061, 19613, 19486, 19231, 18719,
     $  18334, 18205, 18203, 18329, 18584, 19222, 19477, 19731, 19857,
     $  19854, 19596, 19211, 18699, 18316,  9870, 26911, 18699, 27039/
      DATA IF086/ 18827, 18699, 26144, 19616, 19615, 26144, 17951,
     $  11423, 26400, 18193, 18318, 18572, 18955, 19211, 19596, 19854,
     $  19985, 20000, 26400, 18336, 18321, 18446, 18573, 18956, 19212,
     $  19597, 19726, 19857, 19872, 11808, 26144, 18955, 26144, 18080,
     $  18958, 28192, 19872, 18958, 28192, 10763, 26144, 18699, 26144,
     $  18080, 18702, 27552, 18702, 27549, 18699, 27549, 19979, 27552,
     $  19982, 28960, 20640, 19982, 28960, 11787, 26272, 19723, 19851,
     $  26272, 18208, 19851, 28064, 19744, 18059, 28064, 18187,  9867,
     $  26144, 18838, 18827, 18955, 26144, 18080, 18966, 28064, 19744,
     $  18838, 28064, 18966, 10763, 27936, 18059, 28064, 18187, 26272/
      DATA IF087/ 19872, 26272, 18079, 19743, 26380, 19852, 19851,
     $  26251, 11659, 26404, 18180, 26532, 18308, 26404, 19108, 26372,
     $  10884, 25994, 28042, 17826,  4490, 27044, 18820, 27172, 18948,
     $  26276, 18980, 26244, 10756, 25994, 26006, 18846, 19862, 27038,
     $  18830,  4490, 25994, 27022, 17814, 18846, 26006, 19862,  4490,
     $  25994, 26018, 19350,  4490, 27801, 19595, 19723, 27801, 19737,
     $  19723, 27798, 19352, 19097, 18713, 18456, 18198, 18067, 18065,
     $  18190, 18444, 18699, 19083, 19340, 19598, 27798, 19096, 18712,
     $  18455, 18326, 18195, 18193, 18318, 18445, 18700, 19084, 11406,
     $  26400, 18187, 18315, 26400, 18336, 18315, 26518, 18584, 18841/
      DATA IF088/ 19225, 19480, 19734, 19859, 19857, 19726, 19468,
     $  19211, 18827, 18572, 18318, 26518, 18840, 19224, 19479, 19606,
     $  19731, 19729, 19598, 19469, 19212, 18828, 10126, 27798, 19352,
     $  19097, 18713, 18456, 18198, 18067, 18065, 18190, 18444, 18699,
     $  19083, 19340, 19598, 27798, 19477, 19351, 19096, 18712, 18455,
     $  18326, 18195, 18193, 18318, 18445, 18700, 19084, 19341, 19471,
     $  11406, 27808, 19595, 19723, 27808, 19744, 19723, 27798, 19352,
     $  19097, 18713, 18456, 18198, 18067, 18065, 18190, 18444, 18699,
     $  19083, 19340, 19598, 27798, 19096, 18712, 18455, 18326, 18195,
     $  18193, 18318, 18445, 18700, 19084, 11406, 26386, 19602, 19605/
      DATA IF089/ 19479, 19352, 19097, 18713, 18456, 18198, 18067,
     $  18065, 18190, 18444, 18699, 19083, 19340, 19598, 26387, 19475,
     $  19477, 19351, 19096, 18712, 18455, 18326, 18195, 18193, 18318,
     $  18445, 18700, 19084, 19341, 19471, 11406, 27296, 18848, 18591,
     $  18460, 18443, 18571, 27296, 19103, 18847, 18590, 26911, 18588,
     $  18571, 26265, 18969, 18968, 26265, 18072, 10776, 27929, 19609,
     $  19594, 19463, 19334, 19077, 18821, 18566, 18439, 18183, 27929,
     $  19722, 19591, 19333, 19076, 18692, 18437, 18183, 27798, 19352,
     $  19097, 18713, 18456, 18198, 18067, 18065, 18190, 18444, 18699,
     $  19083, 19340, 19598, 27798, 19096, 18712, 18455, 18326, 18195/
      DATA IF090/ 18193, 18318, 18445, 18700, 19084, 11406, 26400,
     $  18187, 18315, 26400, 18336, 18315, 26517, 18712, 18969, 19353,
     $  19608, 19733, 19723, 26517, 18711, 18968, 19224, 19479, 19605,
     $  19595, 11531, 26400, 18079, 18078, 18205, 18333, 18462, 18463,
     $  18336, 18208, 26399, 18206, 18334, 18335, 18207, 26393, 18187,
     $  18315, 26393, 18329, 10123, 26400, 18079, 18078, 18205, 18333,
     $  18462, 18463, 18336, 18208, 26399, 18206, 18334, 18335, 18207,
     $  26393, 18180, 18308, 26393, 18329, 10116, 26400, 18187, 18315,
     $  26400, 18336, 18315, 27929, 19609, 18319, 27929, 18318, 26898,
     $  19467, 19723, 27027, 11531, 26400, 18187, 18315, 26400, 18336/
      DATA IF091/ 10123, 26393, 18187, 18315, 26393, 18329, 18315,
     $  26517, 18712, 18969, 19353, 19608, 19733, 19723, 26517, 18711,
     $  18968, 19224, 19479, 19605, 19595, 19723, 27925, 20120, 20377,
     $  20761, 21016, 21141, 21131, 27925, 20119, 20376, 20632, 20887,
     $  21013, 21003, 12939, 26393, 18187, 18315, 26393, 18329, 18315,
     $  26517, 18712, 18969, 19353, 19608, 19733, 19723, 26517, 18711,
     $  18968, 19224, 19479, 19605, 19595, 11531, 26905, 18456, 18198,
     $  18067, 18065, 18190, 18444, 18699, 19083, 19340, 19598, 19729,
     $  19731, 19606, 19352, 19097, 18713, 26904, 18455, 18326, 18195,
     $  18193, 18318, 18445, 18700, 19084, 19341, 19470, 19601, 19603/
      DATA IF092/ 19478, 19351, 19096, 10520, 26393, 18180, 18308,
     $  26393, 18329, 18308, 26518, 18584, 18841, 19225, 19480, 19734,
     $  19859, 19857, 19726, 19468, 19211, 18827, 18572, 18318, 26518,
     $  18840, 19224, 19479, 19606, 19731, 19729, 19598, 19469, 19212,
     $  18828, 10126, 27801, 19588, 19716, 27801, 19737, 19716, 27798,
     $  19352, 19097, 18713, 18456, 18198, 18067, 18065, 18190, 18444,
     $  18699, 19083, 19340, 19598, 27798, 19096, 18712, 18455, 18326,
     $  18195, 18193, 18318, 18445, 18700, 19084, 11406, 26393, 18187,
     $  18315, 26393, 18329, 18315, 26515, 18454, 18712, 18969, 19353,
     $  26515, 18453, 18711, 18968, 19352, 11161, 27670, 19352, 18969/
      DATA IF093/ 18585, 18200, 18070, 18196, 18451, 19089, 19344,
     $  27409, 19343, 19342, 19212, 27533, 18956, 18572, 18189, 26508,
     $  18190, 18062, 27670, 19350, 19224, 27543, 18968, 18584, 18199,
     $  26520, 18198, 18324, 26389, 18452, 19090, 19345, 19471, 19470,
     $  19340, 18955, 18571, 18188,  9870, 26528, 18315, 18443, 26528,
     $  18464, 18443, 26137, 18841, 18840, 26137, 17944, 10648, 26393,
     $  18191, 18316, 18571, 18955, 19212, 19599, 26393, 18329, 18319,
     $  18445, 18700, 18956, 19213, 19599, 27801, 19595, 19723, 27801,
     $  19737, 11531, 26137, 18699, 26137, 18073, 18701, 27673, 19353,
     $  18701, 27673, 10507, 26265, 18699, 26265, 18201, 18702, 27417/
      DATA IF094/ 18702, 27414, 18699, 27414, 19723, 27417, 19726,
     $  28569, 20249, 19726, 28569, 11531, 26265, 19467, 19595, 26265,
     $  18201, 19595, 27801, 19481, 18059, 27801, 18187,  9867, 26137,
     $  18699, 26137, 18073, 18701, 27673, 19353, 18701, 18180, 27673,
     $  18699, 18308,  9988, 27544, 18059, 27801, 18316, 26265, 19609,
     $  26265, 18072, 19352, 26508, 19596, 19595, 26251, 11403, 27044,
     $  18595, 18466, 18336, 18334, 18460, 18587, 18713, 18711, 18453,
     $  26787, 18465, 18463, 18589, 18716, 18842, 18840, 18710, 18196,
     $  18706, 18832, 18830, 18700, 18571, 18441, 18439, 18565, 26643,
     $  18705, 18703, 18573, 18444, 18314, 18312, 18438, 18565, 10628/
      DATA IF095/ 26404,  9988, 26532, 18595, 18722, 18848, 18846,
     $  18716, 18587, 18457, 18455, 18709, 26787, 18721, 18719, 18589,
     $  18460, 18330, 18328, 18454, 18964, 18450, 18320, 18318, 18444,
     $  18571, 18697, 18695, 18565, 26899, 18449, 18447, 18573, 18700,
     $  18826, 18824, 18694, 18565, 10116, 26257, 18067, 18198, 18455,
     $  18711, 18966, 19475, 19730, 19986, 20243, 20373, 26259, 18197,
     $  18454, 18710, 18965, 19474, 19729, 19985, 20242, 20373, 12183,
     $  25994, 17826, 19874, 19850, 17802, 19874, 26018, 19850,  4490,
     $  25994, 25998, 19870, 26526, 17822, 17826, 18338, 18334, 28042,
     $  19338, 19342, 19854, 19850,  4490, 28445, 18196, 12043, 26397/
      DATA IF096/ 20244,  9995, 27796, 19479, 19352, 19097, 18841,
     $  18456, 18197, 18066, 18063, 18189, 18316, 18571, 18827, 19212,
     $  19470, 19601, 19734, 19739, 19614, 19487, 19232, 18848, 18591,
     $  18461, 18461, 18589, 18590, 27033, 18584, 18325, 18194, 18190,
     $  18316, 27019, 19084, 19342, 19473, 19606, 19611, 19486, 11040,
     $  26144, 18955, 26272, 18957, 28192, 18955, 26144, 20000, 26271,
     $  11679, 27672, 19225, 18841, 18456, 18198, 18067, 18064, 18189,
     $  18316, 18699, 19083, 19340, 27033, 18584, 18326, 18190, 18192,
     $  18317, 18444, 18699, 26386, 11026, 28448, 18201, 20242, 26384,
     $  20240, 26379, 12043, 26400, 20249, 18194, 26384, 20240, 26379/
      DATA IF097/ 12043, 28559, 20111, 19856, 19602, 19222, 19095,
     $  18840, 18584, 18327, 18197, 18195, 18321, 18576, 18832, 19089,
     $  19218, 19606, 19864, 20121, 12185, 28579, 20258, 20385, 20514,
     $  20515, 20388, 20132, 19875, 19617, 19487, 19356, 19224, 18956,
     $  18824, 18694, 27938, 19616, 19484, 19216, 19084, 18953, 18823,
     $  18565, 18308, 18052, 17925, 17926, 18055, 18182,  9861, 28579,
     $  20258, 20385, 20514, 20515, 20388, 20132, 19875, 19617, 19487,
     $  19356, 19224, 18956, 18824, 18694, 27938, 19616, 19484, 19216,
     $  19084, 18953, 18823, 18565, 18308, 18052, 17925, 17926, 18055,
     $  18182, 18053, 27291, 18714, 18456, 18325, 18323, 18448, 18702/
      DATA IF098/ 19085, 19341, 19726, 19984, 20115, 20117, 19992,
     $  19738, 19355, 10907, 28691, 20369, 20112, 19856, 19601, 19474,
     $  19094, 18967, 18712, 18456, 18199, 18069, 18067, 18193, 18448,
     $  18704, 18961, 19090, 19478, 19607, 19864, 20120, 20375, 20501,
     $  12307, 27420, 19211, 26388, 20244, 26379, 12043, 27420, 19211,
     $  26396, 20252, 26388, 12052, 26395, 19981, 28187,  9997, 27549,
     $  19228, 19355, 19484, 19357, 26388, 20500, 27533, 19212, 19339,
     $  19468, 11149, 26788, 18564, 26916, 18692, 29220, 20996, 29348,
     $  21124, 26276, 21668, 26244, 19204, 28676, 13444, 26517, 18196,
     $  18323, 18452, 10133, 26265, 18585, 19341, 26649, 19339, 28708/
      DATA IF099/ 11147, 26532, 19606, 18180, 26632, 19478, 26276,
     $  19477, 26276, 21028, 21277, 20900, 26501, 20997, 26372, 20996,
     $  21259, 12676, 27296, 18719, 18460, 18330, 18199, 18066, 18062,
     $  18188, 18443, 18699, 19084, 19343, 19473, 19604, 19737, 19741,
     $  19615, 19360, 19104, 27296, 18847, 18588, 18458, 18327, 18194,
     $  18190, 18316, 18443, 26891, 18956, 19215, 19345, 19476, 19609,
     $  19613, 19487, 19360, 26518, 11286, 25994, 28058, 19854, 19338,
     $  18314, 17806, 17818,  1442, 26026, 28042, 19862, 19354, 18330,
     $  17814, 17802,  1410, 25986, 26014, 19870, 17806, 19854, 26518,
     $  19350,  2454, 26521, 18200, 18070, 18068, 18193, 18701, 18827/
      DATA IF100/ 26260, 18194, 18702, 18827, 18825, 18694, 18436,
     $  18308, 18181, 18055, 18058, 18190, 18450, 18709, 19096, 19353,
     $  19609, 19992, 20118, 20114, 19982, 19724, 19467, 19339, 19212,
     $  19214, 19343, 19470, 19341, 27801, 19864, 19990, 19986, 19854,
     $  11532, 27030, 26010, 19866, 26002, 19858, 26510, 19358,  2454,
     $  27030, 27030, 18846, 26522, 19354, 26514, 19346,  2454, 26404,
     $  18180, 26532, 18308, 26404, 19108, 26372, 10884, 25994, 28042,
     $  17826,  4490, 27044, 18820, 27172, 18948, 26276, 18980, 26244,
     $  10756, 25994, 26006, 18846, 19862, 27038, 18830,  4490, 25994,
     $  27022, 17814, 18846, 26006, 19862,  4490, 25994, 26018, 19350/
      DATA IF101/  4490, 25994, 28058, 18330, 17814, 17806, 18314,
     $  19850,  4490, 29066, 26010, 19354, 19862, 19854, 19338, 17802,
     $    394, 25994, 27022, 18846, 28058, 17810, 26010, 19858,  4490,
     $  27293, 18972, 19099, 19228, 19229, 19103, 18848, 18592, 18335,
     $  18205, 18203, 18329, 18583, 19220, 26521, 18966, 19220, 19346,
     $  19344, 19214, 18956, 26648, 18198, 18068, 18066, 18192, 18446,
     $  19083, 26384, 18829, 19083, 19209, 19207, 19077, 18820, 18564,
     $  18309, 18183, 18184, 18313, 18440, 10119, 26912, 18590, 18716,
     $  18846, 18720, 26912, 18692, 26901, 18578, 18692, 18834, 18709,
     $  26137, 18200, 18457, 18202, 17945, 26137, 19481, 27161, 19224/
      DATA IF102/ 19481, 19226, 10777, 29066, 20898, 18850, 27542,
     $  20886, 29066, 18826,  1418, 25994, 27018, 18842, 28058, 19850,
     $   1442, 25994, 26006, 19338, 20886,  1442, 25994, 25998, 19354,
     $  20878,  1442, 25994, 19850, 27530, 19854, 19346, 17810, 27538,
     $  19862, 19354, 17818,  1442, 28568, 20247, 20374, 20503, 20504,
     $  20377, 20249, 20120, 19990, 19729, 19470, 19212, 18955, 18571,
     $  18188, 18062, 18065, 18195, 18967, 19225, 19355, 19357, 19231,
     $  18976, 18719, 18589, 18587, 18712, 18965, 19598, 19852, 20235,
     $  20363, 20492, 20493, 26763, 18316, 18190, 18193, 18323, 18581,
     $  26779, 18713, 19726, 19980, 12043, 25994, 25998, 19342, 19858/
      DATA IF103/ 19350, 18326, 17818, 18334, 19870, 27042, 18826,
     $   4490, 27022, 17827, 27022, 19875, 26396, 11292, 25994, 27042,
     $  17826, 17802, 18826,  3466, 25994, 18826, 18850, 17826,  3466,
     $  26257, 18067, 18198, 18455, 18711, 18966, 19475, 19730, 19986,
     $  20243, 20373, 26259, 18197, 18454, 18710, 18965, 19474, 19729,
     $  19985, 20242, 20373, 12183, 27172, 18068, 10756, 26404, 19092,
     $   9988, 26404,  9988, 26269, 18203, 19727, 19853, 19851, 26394,
     $  19726, 26269, 18075, 18201, 19725, 19851, 26902, 18194, 18064,
     $  18062, 18188, 18059, 26256, 18316, 26386, 18192, 18318, 18316,
     $  18059, 27283, 19736, 27677, 19482, 19608, 19864, 19866, 19611/
      DATA IF104/ 19485, 27677, 19610, 11672, 26656, 18207, 18077,
     $  18075, 18201, 18456, 18712, 18969, 19099, 19101, 18975, 18720,
     $  10272, 25994, 26506, 18338, 27554, 19338, 26010, 19866, 28050,
     $  17810,  4490, 27680, 18692, 27808, 18564, 27161, 18456, 18198,
     $  18067, 18064, 18190, 18444, 18827, 19211, 19724, 19982, 20113,
     $  20116, 19990, 19736, 19353, 18969, 27161, 18584, 18326, 18195,
     $  18192, 18318, 18572, 18827, 27403, 19596, 19854, 19985, 19988,
     $  19862, 19608, 11161, 26912, 18590, 18716, 18846, 18720, 26912,
     $  18706, 26902, 18580, 18832, 18702, 18576, 18836, 18710, 26898,
     $  18692, 26888, 18566, 18692, 18822, 18696, 26137, 18200, 18457/
      DATA IF105/ 18202, 17945, 26137, 19481, 27161, 19224, 19481,
     $  19226, 18969, 26123, 18186, 18443, 18188, 17931, 26123, 19467,
     $  27147, 19210, 19467, 19212, 10763, 25994, 27022, 17814, 18846,
     $  26006, 19862,  4490, 25994, 26006, 18846, 19862, 27038, 18830,
     $   4490, 28170, 27150, 19990, 18974, 28182, 17942,   522, 25994,
     $  26514, 19338, 20370, 27530, 19354,  1442, 26018, 26006, 19862,
     $  26014, 19870, 25998, 19854,  2454, 26257, 18067, 18198, 18455,
     $  18711, 18966, 19475, 19730, 19986, 20243, 20373, 26259, 18197,
     $  18454, 18710, 18965, 19474, 19729, 19985, 20242, 20373, 12183,
     $  25994, 17826, 19874, 19850, 17802, 19874, 26018, 19850,  4490/
      DATA IF106/ 28184, 19866, 19611, 19227, 18970, 18841, 18710,
     $  18707, 18833, 19088, 19472, 19729, 19859, 27419, 18969, 18838,
     $  18835, 18961, 19088, 28187, 19859, 19857, 20112, 20368, 20626,
     $  20757, 20759, 20634, 20508, 20254, 19999, 19616, 19232, 18847,
     $  18590, 18332, 18202, 18071, 18068, 18193, 18319, 18573, 18828,
     $  19211, 19595, 19980, 20237, 20366, 28315, 19987, 19985, 11920,
     $  27168, 18059, 27168, 19851, 27165, 19723, 26513, 19473, 25995,
     $  18571, 27531, 11915, 26528, 18315, 26656, 18443, 26144, 19488,
     $  19871, 19998, 20124, 20122, 19992, 19863, 19478, 27680, 19743,
     $  19870, 19996, 19994, 19864, 19735, 19478, 26646, 19478, 19861/
      DATA IF107/ 19988, 20114, 20111, 19981, 19852, 19467, 17931,
     $  27670, 19733, 19860, 19986, 19983, 19853, 19724, 11275, 26528,
     $  18315, 26656, 18443, 26144, 19872, 19866, 19744, 26123, 10635,
     $  27168, 17931, 27168, 19979, 27165, 19851, 26252, 19852, 26123,
     $  11787, 26528, 18315, 26656, 18443, 27418, 19218, 26144, 20000,
     $  19994, 19872, 26646, 19222, 26123, 19979, 19985, 11659, 27936,
     $  18059, 28064, 18187, 26400, 18074, 18080, 19872, 26251, 19851,
     $  19857, 11531, 26528, 18315, 26656, 18443, 28192, 19979, 28320,
     $  20107, 26144, 18848, 27808, 20512, 26646, 19990, 26123, 18827,
     $  27787, 12299, 27168, 18591, 18333, 18203, 18071, 18068, 18192/
      DATA IF108/ 18318, 18572, 18955, 19211, 19596, 19854, 19984,
     $  20116, 20119, 19995, 19869, 19615, 19232, 18976, 27168, 18719,
     $  18461, 18331, 18199, 18196, 18320, 18446, 18700, 18955, 27403,
     $  19468, 19726, 19856, 19988, 19991, 19867, 19741, 19487, 19232,
     $  26905, 18706, 27673, 19474, 26902, 19478, 26901, 11285, 26528,
     $  18315, 26656, 18443, 26144, 18848, 26123, 10635, 26528, 18315,
     $  26656, 18443, 28320, 18451, 27287, 20107, 27159, 19979, 26144,
     $  18848, 27808, 20384, 26123, 18827, 27787, 12171, 27168, 18059,
     $  27168, 19851, 27165, 19723, 25995, 18571, 27531, 11915, 26528,
     $  18315, 26656, 19214, 26528, 19211, 28320, 19211, 28320, 20107/
      DATA IF109/ 28448, 20235, 26144, 18464, 28320, 20640, 26123,
     $  18699, 27915, 12427, 26528, 18315, 26656, 19981, 26654, 19979,
     $  28192, 19979, 26144, 18464, 27808, 20384, 26123, 10507, 26401,
     $  18076, 28321, 19996, 26904, 18579, 27800, 19475, 26383, 18058,
     $  28303, 19978, 26399, 19999, 26398, 19998, 26902, 19478, 26901,
     $  19477, 26381, 19981, 26380, 11788, 27168, 18591, 18333, 18203,
     $  18071, 18068, 18192, 18318, 18572, 18955, 19211, 19596, 19854,
     $  19984, 20116, 20119, 19995, 19869, 19615, 19232, 18976, 27168,
     $  18719, 18461, 18331, 18199, 18196, 18320, 18446, 18700, 18955,
     $  27403, 19468, 19726, 19856, 19988, 19991, 19867, 19741, 19487/
      DATA IF110/ 11040, 26528, 18315, 26656, 18443, 28192, 19979,
     $  28320, 20107, 26144, 20512, 26123, 18827, 27787, 12299, 26528,
     $  18315, 26656, 18443, 26144, 19488, 19871, 19998, 20124, 20121,
     $  19991, 19862, 19477, 18453, 27680, 19743, 19870, 19996, 19993,
     $  19863, 19734, 19477, 26123, 10635, 26272, 18966, 17931, 26144,
     $  18838, 26144, 19872, 19994, 19744, 26252, 19724, 26123, 19851,
     $  19985, 11531, 27040, 18827, 27168, 18955, 26272, 17946, 17952,
     $  19872, 19866, 19744, 26635, 11147, 26139, 17949, 18079, 18208,
     $  18464, 18591, 18717, 18841, 18827, 26141, 18207, 18463, 18717,
     $  28059, 19869, 19743, 19616, 19360, 19231, 19101, 18969, 18955/
      DATA IF111/ 28061, 19615, 19359, 19101, 26635, 11147, 27168,
     $  18955, 27296, 19083, 26907, 18330, 18201, 18071, 18068, 18194,
     $  18321, 18704, 19344, 19729, 19858, 19988, 19991, 19865, 19738,
     $  19355, 18715, 26907, 18458, 18329, 18199, 18196, 18322, 18449,
     $  18704, 27536, 19601, 19730, 19860, 19863, 19737, 19610, 19355,
     $  26784, 19488, 26763, 11275, 26272, 19723, 26400, 19851, 28064,
     $  18059, 26016, 18592, 27552, 20128, 25995, 18571, 27531, 11915,
     $  27296, 19083, 27424, 19211, 26137, 18074, 18329, 18453, 18579,
     $  18706, 18961, 26266, 18201, 18325, 18451, 18578, 18961, 19345,
     $  19730, 19859, 19989, 20121, 20250, 27537, 19602, 19731, 19861/
      DATA IF112/ 19993, 20250, 20377, 26912, 19616, 26891, 11403,
     $  26254, 18187, 18699, 18447, 18195, 18070, 18074, 18205, 18463,
     $  18848, 19360, 19743, 19997, 20122, 20118, 19987, 19727, 19467,
     $  19979, 20110, 26639, 18322, 18198, 18202, 18333, 18591, 18848,
     $  27552, 19615, 19869, 19994, 19990, 19858, 19727, 26380, 18572,
     $  27788, 11788, 25994, 17826, 19874, 19850, 17802, 19874, 26018,
     $  19850,  4490, 25994, 17826, 19874, 19850, 17802, 19874, 26018,
     $  19850,  4490, 26404, 18180, 26532, 18308, 26404, 19108, 26372,
     $  10884, 25994, 28042, 17826,  4490, 27044, 18820, 27172, 18948,
     $  26276, 18980, 26244, 10756, 25994, 26006, 18846, 19862, 27038/
      DATA IF113/ 18830,  4490, 25994, 27022, 17814, 18846, 26006,
     $  19862,  4490, 25994, 26018, 19350,  4490, 27161, 18584, 18326,
     $  18196, 18065, 18062, 18188, 18571, 18827, 19084, 19471, 19730,
     $  19990, 20121, 27161, 18712, 18454, 18324, 18193, 18190, 18316,
     $  18571, 27161, 19225, 19480, 19606, 19854, 19980, 20107, 27417,
     $  19352, 19478, 19726, 19852, 20107, 12043, 27552, 18975, 18717,
     $  18457, 18326, 18194, 18060, 17924, 27552, 19103, 18845, 18585,
     $  18454, 18322, 18188, 18052, 27552, 19616, 19871, 19998, 19995,
     $  19865, 19736, 19351, 18839, 27808, 19870, 19867, 19737, 19608,
     $  19351, 27031, 19350, 19604, 19730, 19727, 19597, 19468, 19083/
      DATA IF114/ 18827, 18572, 18445, 18320, 27031, 19222, 19476,
     $  19602, 19599, 19469, 19340, 10891, 26006, 18072, 18329, 18585,
     $  18840, 18967, 19092, 19088, 18956, 18564, 26135, 18200, 18712,
     $  18967, 28185, 19862, 19732, 19085, 18696, 18436, 28057, 19734,
     $  19604, 10893, 27544, 19097, 18841, 18456, 18197, 18066, 18063,
     $  18189, 18316, 18571, 18827, 19212, 19471, 19602, 19605, 19479,
     $  18972, 18846, 18848, 18975, 19233, 19488, 19742, 27033, 18584,
     $  18325, 18194, 18190, 18316, 27019, 19084, 19343, 19474, 19478,
     $  19352, 19099, 18973, 18975, 19104, 19360, 11550, 27798, 19352,
     $  19097, 18585, 18328, 18326, 18580, 18963, 26777, 18456, 18454/
      DATA IF115/ 18708, 18963, 27155, 18322, 18064, 18062, 18188,
     $  18571, 18955, 19212, 19470, 27155, 18450, 18192, 18190, 18316,
     $  10379, 27296, 18847, 18718, 18717, 18844, 19227, 19867, 19868,
     $  19483, 18969, 18583, 18196, 18065, 18063, 18189, 18571, 18953,
     $  19079, 19077, 18948, 18692, 18565, 27418, 18711, 18324, 18193,
     $  18191, 18317, 10379, 26005, 17943, 18201, 18585, 18712, 18710,
     $  18578, 18315, 26649, 18584, 18582, 18450, 18187, 26770, 18838,
     $  19096, 19353, 19609, 19864, 19991, 19988, 19855, 19460, 27801,
     $  19863, 19860, 19727, 11140, 26005, 17943, 18201, 18585, 18712,
     $  18710, 18577, 18574, 18700, 18827, 26649, 18584, 18582, 18449/
      DATA IF116/ 18446, 18572, 18827, 19083, 19340, 19598, 19857,
     $  19988, 20121, 20125, 19999, 19744, 19488, 19230, 19228, 19353,
     $  19606, 19860, 20242, 27532, 19599, 19729, 19860, 19993, 19997,
     $  19871, 11552, 26649, 18194, 18062, 18060, 18187, 18571, 18829,
     $  18959, 26777, 18322, 18190, 18188, 10123, 26649, 17931, 26777,
     $  18059, 27929, 19864, 19992, 19865, 19609, 19352, 18836, 18579,
     $  18323, 26771, 18834, 19084, 19211, 26771, 18706, 18956, 19083,
     $  19339, 19596, 11663, 26272, 18336, 18591, 18718, 18844, 19598,
     $  19724, 19851, 26528, 18590, 18716, 19470, 19596, 19851, 19979,
     $  27161, 17931, 27161,  9867, 26777, 17796, 26905, 17924, 26774/
      DATA IF117/ 18448, 18445, 18699, 18955, 19212, 19470, 19729,
     $  28185, 19598, 19596, 19723, 20107, 20365, 20495, 28313, 19726,
     $  19724, 11659, 26649, 18187, 26777, 18451, 18318, 18187, 28057,
     $  19733, 19473, 28185, 19862, 19732, 19473, 19215, 18829, 18572,
     $  18187, 26265, 10393, 27296, 18847, 18718, 18717, 18844, 19227,
     $  19611, 27419, 18714, 18457, 18327, 18325, 18579, 18962, 19346,
     $  27419, 18842, 18585, 18455, 18453, 18707, 18962, 27154, 18449,
     $  18192, 18062, 18060, 18314, 18952, 19079, 19077, 18820, 18564,
     $  27154, 18577, 18320, 18190, 18188, 18442, 10760, 27033, 18456,
     $  18197, 18066, 18063, 18189, 18316, 18571, 18827, 19212, 19471/
      DATA IF118/ 19602, 19605, 19479, 19352, 19097, 18841, 27033,
     $  18584, 18325, 18194, 18190, 18316, 27019, 19084, 19343, 19474,
     $  19478, 11160, 27032, 18315, 27032, 18443, 27800, 19595, 27800,
     $  19723, 26134, 18200, 18585, 20249, 26134, 18199, 18584, 12056,
     $  26384, 18317, 18444, 18699, 18955, 19340, 19599, 19730, 19733,
     $  19607, 19480, 19225, 18969, 18584, 18325, 18194, 17668, 27147,
     $  19212, 19471, 19602, 19606, 19480, 27161, 18712, 18453, 18322,
     $   9604, 28313, 18841, 18456, 18197, 18066, 18063, 18189, 18316,
     $  18571, 18827, 19212, 19471, 19602, 19605, 19479, 19352, 19097,
     $  27033, 18584, 18325, 18194, 18190, 18316, 27019, 19084, 19343/
      DATA IF119/ 19474, 19478, 19352, 27544, 11928, 27288, 18699,
     $  27288, 18827, 26134, 18200, 18585, 19993, 26134, 18199, 18584,
     $  11800, 26005, 17943, 18201, 18585, 18712, 18710, 18448, 18445,
     $  18699, 26649, 18584, 18582, 18320, 18317, 18444, 18699, 18827,
     $  19212, 19470, 19729, 19860, 19863, 19737, 19608, 19735, 19860,
     $  27921, 11671, 26904, 18455, 18197, 18066, 18063, 18189, 18316,
     $  18571, 18955, 19340, 19726, 19985, 20116, 20119, 19865, 19609,
     $  19351, 19091, 18830, 18436, 26255, 18317, 18572, 18956, 19341,
     $  19727, 19985, 28311, 19864, 19608, 19350, 19091, 18829, 10372,
     $  26137, 18201, 18456, 18582, 19207, 19333, 19460, 26393, 18328/
      DATA IF120/ 18454, 19079, 19205, 19460, 19716, 28057, 19735,
     $  19476, 18185, 17926,  9604, 27808, 18820, 27936, 18692, 26005,
     $  17943, 18201, 18585, 18712, 18710, 18577, 18574, 18828, 19212,
     $  19469, 19856, 20115, 26649, 18584, 18582, 18449, 18446, 18572,
     $  18827, 19211, 19468, 19726, 19985, 20115, 12185, 26389, 18455,
     $  18840, 18713, 18456, 18197, 18066, 18063, 18188, 18315, 18571,
     $  18828, 19087, 19218, 26255, 18189, 18316, 18572, 18829, 19087,
     $  27282, 19087, 19212, 19339, 19595, 19852, 20111, 20242, 20245,
     $  20120, 19993, 19864, 20119, 20245, 27279, 19213, 19340, 19596,
     $  19853, 11919, 25994, 17826, 19874, 19850, 17802, 19874, 26018/
      DATA IF121/ 19850,  4490, 25994, 17826, 19874, 19850, 17802,
     $  19874, 26018, 19850,  4490, 27044, 18595, 18466, 18336, 18334,
     $  18460, 18587, 18713, 18711, 18453, 26787, 18465, 18463, 18589,
     $  18716, 18842, 18840, 18710, 18196, 18706, 18832, 18830, 18700,
     $  18571, 18441, 18439, 18565, 26643, 18705, 18703, 18573, 18444,
     $  18314, 18312, 18438, 18565, 10628, 26404,  9988, 26532, 18595,
     $  18722, 18848, 18846, 18716, 18587, 18457, 18455, 18709, 26787,
     $  18721, 18719, 18589, 18460, 18330, 18328, 18454, 18964, 18450,
     $  18320, 18318, 18444, 18571, 18697, 18695, 18565, 26899, 18449,
     $  18447, 18573, 18700, 18826, 18824, 18694, 18565, 10116, 26257/
      DATA IF122/ 18067, 18198, 18455, 18711, 18966, 19475, 19730,
     $  19986, 20243, 20373, 26259, 18197, 18454, 18710, 18965, 19474,
     $  19729, 19985, 20242, 20373, 12183, 25994, 17826, 19874, 19850,
     $  17802, 19874, 26018, 19850,  4490,  4234, 27168, 18718, 18322,
     $  18974, 18976, 27038, 18584, 26381, 17932, 18059, 18188,  9997,
     $  25738, 26906, 19106, 28322, 19738,  4234, 27936, 17668, 28704,
     $  18436, 26517, 20117, 26127, 11535, 27812, 18311, 28324, 18823,
     $  28573, 20255, 19872, 19360, 18975, 18589, 18459, 18585, 18584,
     $  18839, 19477, 19732, 19859, 19857, 19726, 19340, 18955, 18443,
     $  18060,  9742, 29216, 17803, 27552, 19486, 19484, 19226, 18969/
      DATA IF123/ 18713, 18459, 18589, 18847, 19104, 19360, 19615,
     $  19870, 20254, 20767, 21024, 28050, 19601, 19343, 19341, 19467,
     $  19723, 19980, 20238, 20368, 20114, 11666, 25738, 28050, 18570,
     $  18058, 17678, 17810, 19738, 19870, 19618, 18846, 18582, 19594,
     $   4234, 25738, 26906, 19358, 19618,  4234, 28196, 19618, 19231,
     $  18715, 18454, 18194, 18189, 18185, 18310, 10372, 27172, 19106,
     $  19231, 19227, 19222, 18962, 18701, 18185, 17798,  9348, 27290,
     $  18574, 26519, 19345, 27799,  9873, 28061, 19083, 26516, 12436,
     $  26380, 18059, 17932, 18189, 18188, 18186, 17928,  9607, 26516,
     $  12436, 26381, 17932, 18059, 18188,  9997, 29348,  9220, 27680/
      DATA IF124/ 19103, 18716, 18327, 18196, 18063, 18188, 18571,
     $  18827, 19212, 19599, 19988, 20119, 20252, 20127, 19744, 11296,
     $  27164, 19229, 19744, 10635, 26779, 18716, 18846, 19103, 19360,
     $  19872, 20127, 20126, 20252, 20122, 19864, 19477, 17803, 11403,
     $  27168, 20384, 19224, 19608, 19863, 19990, 19987, 19857, 19598,
     $  19212, 18827, 18443, 18060, 18061,  9743, 28192, 18066, 19986,
     $  28192, 10891, 28448, 18976, 18455, 18584, 19097, 19481, 19736,
     $  19990, 19987, 19857, 19598, 19212, 18827, 18443, 18060, 18061,
     $   9743, 28445, 20255, 19872, 19616, 19231, 18844, 18455, 18194,
     $  18190, 18316, 18699, 18827, 19212, 19598, 19857, 19858, 19861/
      DATA IF125/ 19735, 19352, 19224, 18839, 18453, 10002, 28704,
     $  18315, 26912, 12320, 27552, 18975, 18717, 18587, 18713, 18840,
     $  19351, 19734, 19860, 19858, 19727, 19597, 19340, 18955, 18443,
     $  18060, 18061, 17935, 18066, 18324, 18710, 19095, 19608, 19993,
     $  20123, 20253, 20255, 19872, 11168, 28313, 19862, 19476, 19091,
     $  18963, 18580, 18454, 18457, 18458, 18717, 19103, 19488, 19616,
     $  19999, 20125, 20121, 19860, 19471, 19084, 18699, 18443, 18060,
     $   9870, 26905, 18456, 18583, 18712, 18713, 26381, 17932, 18059,
     $  18188,  9997, 26905, 18456, 18583, 18712, 18713, 26251, 17932,
     $  18189, 18188, 18186, 17928,  9607, 28957, 18324, 11787, 26647/
      DATA IF126/ 20759, 26385, 12305, 26909, 20372,  9739, 26908,
     $  18715, 18586, 18459, 18588, 18718, 18975, 19232, 19616, 19999,
     $  19998, 20124, 19994, 19736, 19607, 18965, 18834, 27808, 19871,
     $  19870, 19996, 19866, 19608, 19350, 26893, 18444, 18571, 18700,
     $  10509, 28440, 20250, 19995, 19611, 19354, 19225, 18966, 18835,
     $  18833, 19088, 19472, 19729, 19987, 27803, 19353, 19094, 18963,
     $  18961, 19088, 28571, 19987, 19857, 20112, 20368, 20626, 20885,
     $  21015, 21018, 21020, 20766, 20639, 20256, 19872, 19487, 19102,
     $  18844, 18586, 18327, 18196, 18193, 18191, 18445, 18572, 18955,
     $  19339, 19724, 20109, 20238, 28699, 20115, 19985, 11920, 27680/
      DATA IF127/ 17547, 27680, 19595, 26386, 11282, 27040, 17931,
     $  27040, 20000, 20383, 20382, 20508, 20378, 20120, 19991, 19606,
     $  26646, 19606, 19861, 19988, 19986, 19855, 19725, 19468, 19083,
     $   9739, 28571, 20381, 20255, 20000, 19488, 19231, 18845, 18587,
     $  18328, 18195, 18192, 18190, 18316, 18571, 19083, 19340, 19726,
     $  11792, 27040, 17931, 27040, 19744, 20127, 20253, 20251, 20248,
     $  20115, 19856, 19598, 19212, 18827,  9739, 27040, 17931, 27040,
     $  20512, 26646, 19478, 26123, 11403, 27040, 17931, 27040, 20512,
     $  26646, 11286, 28571, 20381, 20255, 20000, 19488, 19231, 18845,
     $  18587, 18328, 18195, 18192, 18190, 18316, 18571, 19083, 19340/
      DATA IF128/ 19726, 19984, 20115, 27667, 11923, 27040, 17931,
     $  28832, 19723, 26646, 12054, 27040,  9739, 28064, 19216, 18957,
     $  18700, 18443, 18187, 17932, 17933, 17936,  9746, 27040, 17931,
     $  28832, 18194, 27287, 11531, 27040, 17931, 26123, 11275, 27040,
     $  17931, 27040, 18955, 29088, 18955, 29088, 11787, 27040, 17931,
     $  27040, 19723, 28832, 11531, 27680, 19231, 18845, 18587, 18328,
     $  18195, 18192, 18190, 18316, 18571, 19083, 19340, 19726, 19984,
     $  20243, 20376, 20379, 20381, 20255, 20000, 11296, 27040, 17931,
     $  27040, 20000, 20383, 20382, 20508, 20377, 20119, 19990, 19477,
     $  10133, 27680, 19231, 18845, 18587, 18328, 18195, 18192, 18190/
      DATA IF129/ 18316, 18571, 19083, 19340, 19726, 19984, 20243,
     $  20376, 20379, 20381, 20255, 20000, 19488, 27279, 11401, 27040,
     $  17931, 27040, 20000, 20383, 20382, 20508, 20378, 20120, 19991,
     $  19606, 18454, 27542, 11531, 28573, 20255, 19872, 19360, 18975,
     $  18589, 18459, 18585, 18584, 18839, 19477, 19732, 19859, 19857,
     $  19726, 19340, 18955, 18443, 18060,  9742, 27552, 18443, 26656,
     $  12064, 27040, 18193, 18190, 18316, 18699, 18955, 19340, 19726,
     $  19985, 12448, 26656, 18571, 28704, 10379, 26784, 18315, 28064,
     $  18315, 28064, 19595, 29344, 11403, 26912, 19595, 28704,  9611,
     $  26656, 19094, 18571, 28704, 10902, 28704, 17803, 26912, 20512/
      DATA IF130/ 25995, 11403, 27300, 17668, 27428, 17796, 27300,
     $  20004, 25860, 10372, 25738, 27786, 18594,  4234, 27940, 18308,
     $  28068, 18436, 27172, 19876, 25732, 10244, 25738, 26262, 19358,
     $  20118, 27550, 18702,  4234, 25738, 26894, 18070, 19358, 26262,
     $  20118,  4234, 25738, 26786, 19606,  4234, 28185, 19339, 28054,
     $  19608, 19481, 19097, 18712, 18454, 18195, 18065, 18062, 18188,
     $  18443, 18827, 19084, 11278, 27040, 17931, 26646, 18712, 19097,
     $  19481, 19608, 19862, 19859, 19729, 19470, 19084, 18827, 18443,
     $  18188,  9870, 28054, 19608, 19481, 19097, 18712, 18454, 18195,
     $  18065, 18062, 18188, 18443, 18827, 19084, 11278, 28448, 19339/
      DATA IF131/ 28054, 19608, 19481, 19097, 18712, 18454, 18195,
     $  18065, 18062, 18188, 18443, 18827, 19084, 11278, 26387, 19731,
     $  19733, 19735, 19608, 19481, 19097, 18712, 18454, 18195, 18065,
     $  18062, 18188, 18443, 18827, 19084, 11278, 27808, 19360, 19103,
     $  18844, 18059, 26521, 11033, 28185, 19209, 18950, 18821, 18564,
     $  18180, 17925, 28054, 19608, 19481, 19097, 18712, 18454, 18195,
     $  18065, 18062, 18188, 18443, 18827, 19084, 11278, 27040, 17931,
     $  26517, 18840, 19225, 19609, 19736, 19733, 11147, 26912, 18847,
     $  18976, 18977, 18720, 26777,  9739, 27168, 19103, 19232, 19233,
     $  18976, 27033, 18056, 17797, 17540,  9092, 27040, 17931, 28057/
      DATA IF132/ 18063, 27027, 11147, 27040,  9739, 26777, 17931,
     $  26517, 18840, 19225, 19609, 19736, 19733, 19339, 27925, 20248,
     $  20633, 21017, 21144, 21141, 12555, 26777, 17931, 26517, 18840,
     $  19225, 19609, 19736, 19733, 11147, 27289, 18712, 18454, 18195,
     $  18065, 18062, 18188, 18443, 18827, 19084, 19470, 19729, 19859,
     $  19862, 19608, 19481, 10905, 26777, 17668, 26646, 18712, 19097,
     $  19481, 19608, 19862, 19859, 19729, 19470, 19084, 18827, 18443,
     $  18188,  9870, 28185, 19076, 28054, 19608, 19481, 19097, 18712,
     $  18454, 18195, 18065, 18062, 18188, 18443, 18827, 19084, 11278,
     $  26777, 17931, 26515, 18582, 18840, 19225, 11417, 27926, 19608/
      DATA IF133/ 19353, 18969, 18456, 18326, 18324, 18579, 19090,
     $  19345, 19343, 19342, 19084, 18699, 18315, 17932,  9742, 27168,
     $  18191, 18188, 18443, 18699, 26521, 11033, 26777, 18063, 18060,
     $  18315, 18699, 18956, 19471, 28185, 11147, 26521, 18443, 28057,
     $  10251, 26649, 18315, 27673, 18315, 27673, 19339, 28697, 11147,
     $  26649, 19211, 28057,  9611, 26521, 18443, 28057, 18443, 18055,
     $  17669, 17412,  9092, 28057, 17803, 26649, 19865, 25995, 11019,
     $  27940, 19363, 19234, 18976, 18846, 18972, 18971, 19097, 18967,
     $  18581, 27555, 19233, 19103, 19101, 19228, 19226, 19096, 18966,
     $  18324, 18706, 18832, 18702, 18444, 18315, 18057, 18055, 18053/
      DATA IF134/ 26771, 18705, 18575, 18445, 18188, 18058, 17928,
     $  17926, 18053, 10116, 27300,  9476, 27428, 19363, 19490, 19488,
     $  19358, 19228, 18971, 18841, 18711, 18837, 27555, 19489, 19359,
     $  19101, 18972, 18714, 18584, 18710, 19092, 18450, 18320, 18190,
     $  18188, 18315, 18313, 18311, 18053, 27027, 18449, 18319, 18445,
     $  18444, 18570, 18440, 18182, 18053,  9604, 26257, 18195, 18454,
     $  18711, 18967, 19222, 19603, 19730, 19986, 20371, 20501, 26387,
     $  18325, 18710, 18966, 19093, 19474, 19729, 19985, 20242, 20501,
     $  12439, 25738, 18594, 20642, 19594, 17546, 20642, 26786, 19594,
     $   4234,  4490, 25994, 26506, 18826, 18830, 18318, 18314, 27026/
      DATA IF135/ 18338, 18850, 18834,  4490, 25994, 26522, 18338,
     $  27554, 19354,  4490, 25994, 26506, 18338, 27554, 19338, 26010,
     $  19866, 28050, 17810,  4490, 25994, 25998, 19342, 19858, 19350,
     $  18326, 17818, 18334, 19870, 27042, 18826,  4490, 25994, 25998,
     $  19870, 26526, 17822, 17826, 18338, 18334, 28042, 19338, 19342,
     $  19854, 19850,  4490, 25994, 28050, 18826, 18314, 17806, 17810,
     $  19354, 19358, 18850, 18334, 18326, 19850,  4490, 25994, 26522,
     $  18846, 18850,  4490, 25994, 27554, 18330, 18322, 19338,  4490,
     $  25994, 26530, 19354, 19346, 18314,  4490, 25994, 27022, 18846,
     $  28058, 17810, 26010, 19858,  4490, 25994, 27022, 18846, 26006/
      DATA IF136/ 19862,  4490, 25994, 18318, 18322,  4490, 25994,
     $  26006, 19862,  4490, 25994, 26506, 18314,  4490, 25994, 19874,
     $   4490, 25994, 25998, 17822, 18338, 19362, 19870, 19854, 19338,
     $  18314, 17806, 19870,  4490, 25994, 26506, 19338, 27018, 18850,
     $  18334,  4490, 25994, 26014, 18338, 19362, 19870, 19866, 17806,
     $  17802, 19850,  4490, 25994, 26018, 19874, 19870, 18838, 19350,
     $  19858, 19854, 19338, 18314, 17806,  4490, 25994, 27530, 19362,
     $  17814, 17810, 19858,  4490, 25994, 25998, 18314, 19338, 19854,
     $  19862, 19354, 17818, 17826, 19874,  4490, 25994, 26006, 19350,
     $  19858, 19854, 19338, 18314, 17806, 17818, 18850, 19874,  4490/
      DATA IF137/ 25994, 26018, 19874, 19870, 18322, 18314,  4490,
     $  25994, 26506, 19338, 19854, 19858, 19350, 18326, 17818, 17822,
     $  18338, 19362, 19870, 19866, 19350, 26518, 17810, 17806, 18314,
     $   4490, 25994, 18826, 19858, 19870, 19362, 18338, 17822, 17818,
     $  18326, 19862,  4490, 25994, 26506, 18314, 26514, 18322,  4490,
     $  25994, 26506, 18830, 18834, 27034, 18842,  4490, 25994, 27530,
     $  17814, 19362,  4490, 25994, 26002, 19858, 28058, 17818,  4490,
     $  25994, 26506, 19862, 18338,  4490, 25994, 27018, 18826, 27026,
     $  19866, 19870, 19362, 18338, 17822,  4490, 25994, 27530, 18314,
     $  17806, 17822, 18338, 19362, 19870, 19858, 18834, 18838, 19870/
      DATA IF138/  4490, 25994, 17818, 18850, 19866, 19850, 26002,
     $  19858,  4490, 25994, 17826, 19362, 19870, 19866, 19350, 17814,
     $  27542, 19858, 19854, 19338, 17802,  4490, 25994, 28062, 19362,
     $  18338, 17822, 17806, 18314, 19338, 19854,  4490, 25994, 19338,
     $  19854, 19870, 19362, 17826, 26530, 18314,  4490, 25994, 17826,
     $  19874, 27542, 17814, 25994, 19850,  4490, 25994, 17826, 19874,
     $  27030, 17814,  4490, 25994, 28062, 19362, 18338, 17822, 17806,
     $  18314, 19850, 19858, 19346,  4490, 25994, 17826, 26006, 19862,
     $  28066, 19850,  4490, 25994, 26506, 19338, 27018, 18850, 26530,
     $  19362,  4490, 25994, 25998, 18314, 19338, 19854, 19874,  4490/
      DATA IF139/ 25994, 17826, 28066, 17814, 19850,  4490, 25994,
     $  17826, 25994, 19850,  4490, 25994, 17826, 18838, 19874, 19850,
     $   4490, 25994, 17826, 26014, 19854, 28066, 19850,  4490, 25994,
     $  25998, 18314, 19338, 19854, 19870, 19362, 18338, 17822, 17806,
     $   4490, 25994, 17826, 19362, 19870, 19866, 19350, 17814,  4490,
     $  25994, 25998, 18314, 19338, 19854, 19870, 19362, 18338, 17822,
     $  17806, 27026, 19850,  4490, 25994, 17826, 19362, 19870, 19866,
     $  19350, 17814, 27030, 19850,  4490, 25994, 25998, 18314, 19338,
     $  19854, 19858, 19350, 18326, 17818, 17822, 18338, 19362, 19870,
     $   4490, 25994, 26018, 19874, 27042, 18826,  4490, 25994, 26018/
      DATA IF140/ 17806, 18314, 19338, 19854, 19874,  4490, 25994,
     $  26018, 18826, 19874,  4490, 25994, 26018, 18314, 18838, 19338,
     $  19874,  4490, 25994, 17806, 19870, 19874, 26018, 17822, 19854,
     $  19850,  4490, 25994, 26018, 17822, 18838, 18826, 28066, 19870,
     $  18838,  4490, 25994, 26018, 19874, 19870, 17806, 17802, 19850,
     $   4490, 25994, 27042, 17826, 17802, 18826,  3466, 25994, 28042,
     $  17826,  4490, 25994, 18826, 18850, 17826,  3466, 25994, 26006,
     $  18846, 19862, 27038, 18830,  4490, 25994, 27022, 17814, 18846,
     $  26006, 19862,  4490, 25994, 26018, 19350,  4490, 25994, 25998,
     $  17814, 18330, 18842, 19858, 18826, 18314, 17806, 28058, 19850/
      DATA IF141/  4490, 25994, 17826, 26002, 18842, 19354, 19862,
     $  19854, 19338, 18826, 17810,  4490, 25994, 28058, 18330, 17814,
     $  17806, 18314, 19850,  4490, 25994, 28066, 19850, 28050, 18842,
     $  18330, 17814, 17806, 18314, 18826, 19858,  4490, 25994, 26002,
     $  19858, 19862, 19354, 18330, 17814, 17806, 18314, 19338,  4490,
     $  25994, 27018, 18846, 19362, 26518, 19350,  4490, 25994, 26498,
     $  19330, 19846, 19866, 28050, 18842, 18330, 17814, 17806, 18314,
     $  18826, 19858,  4490, 25994, 17826, 26010, 19354, 19862, 19850,
     $   4490, 25994, 26506, 19338, 27018, 18838, 18326, 27038, 18846,
     $   4490, 25994, 26506, 18826, 19342, 19354, 27554, 19362,  4490/
      DATA IF142/ 25994, 17826, 28062, 17806, 27030, 19850,  4490,
     $  25994, 26506, 19338, 27018, 18850, 18338,  4490, 25994, 17818,
     $  26006, 18330, 18838, 18826, 27030, 19354, 19862, 19850,  4490,
     $  25994, 17818, 26006, 18330, 19354, 19862, 19850,  4490, 25994,
     $  25998, 17814, 18330, 19354, 19862, 19854, 19338, 18314, 17806,
     $   4490, 25994, 25986, 17818, 26002, 18842, 19354, 19862, 19854,
     $  19338, 18826, 17810,  4490, 25994, 28034, 19866, 28050, 18842,
     $  18330, 17814, 17806, 18314, 18826, 19858,  4490, 25994, 17818,
     $  26002, 18842, 19866,  4490, 25994, 19338, 19854, 19346, 18322,
     $  17814, 18330, 19866,  4490, 25994, 26522, 19354, 27042, 18830/
      DATA IF143/ 19338,  4490, 25994, 26010, 17806, 18314, 19338,
     $  19854, 28058, 19850,  4490, 25994, 26010, 18826, 19866,  4490,
     $  25994, 26010, 18314, 18834, 19338, 19866,  4490, 25994, 19866,
     $  26010, 19850,  4490, 25994, 26498, 19330, 19846, 19866, 26010,
     $  17806, 18314, 19850,  4490, 25994, 26010, 19866, 17802, 19850,
     $   4490, 25994, 27018, 18318, 18322, 17814, 18330, 18334, 18850,
     $   3978, 25994, 27018, 18834, 27034, 18850,  4490, 25994, 26506,
     $  18830, 18834, 19350, 18842, 18846, 18338,  3978, 25994, 26002,
     $  18326, 19350, 19866,  4490, 25994, 17826, 19874, 19850, 17802,
     $  19874, 26018, 19850,  4490,     0,     0,     0,     0,     0/
      DATA IWD001/    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    10,
     $     20,    21,    20,    24,    20,    20,    14,    14,    16,
     $     26,    10,    26,    10,    22,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    10,    10,    24,
     $     26,    24,    20,    20,    18,    21,    21,    21,    19,
     $     18,    21,    22,     8,    16,    21,    17,    24,    22,
     $     22,    21,    22,    21,    20,    16,    22,    18,    24/
      DATA IWD002/    20,    18,    20,    20,    20,    20,    20,
     $     20,    20,    19,    19,    18,    19,    18,    12,    19,
     $     19,     8,    10,    17,     8,    30,    19,    19,    19,
     $     19,    13,    17,    12,    19,    16,    22,    17,    16,
     $     17,    20,     8,    20,    20,    20,    20,    10,    20,
     $     21,    20,    24,    25,    20,    14,    14,    16,    26,
     $     10,    26,    10,    22,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    10,    10,    24,    26,
     $     24,    18,    27,    20,    22,    21,    22,    21,    20,
     $     23,    24,    11,    15,    22,    18,    25,    23,    22/
      DATA IWD003/    22,    22,    22,    20,    19,    24,    20,
     $     24,    20,    21,    20,    14,    20,    14,    20,    20,
     $     20,    20,    21,    19,    21,    19,    13,    19,    22,
     $     11,    11,    21,    11,    33,    22,    20,    21,    20,
     $     17,    17,    15,    22,    18,    24,    20,    19,    18,
     $     14,     8,    14,    24,    20,    27,    18,    21,    17,
     $     18,    19,    20,    22,    22,     8,    21,    18,    24,
     $     22,    18,    22,    22,    21,    18,    16,    18,    20,
     $     20,    22,    20,    20,    20,    14,    20,    14,    20,
     $     20,    20,    21,    19,    19,    18,    16,    15,    20/
      DATA IWD004/    21,    11,    18,    16,    21,    18,    16,
     $     17,    22,    18,    20,    20,    20,    22,    18,    23,
     $     23,    20,    20,    14,     8,    14,    24,    20,    20,
     $     11,    20,    21,    20,    24,    25,    20,    14,    14,
     $     16,    26,    10,    26,    10,    22,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    11,    11,
     $     24,    26,    24,    21,    27,    20,    24,    21,    23,
     $     23,    22,    22,    26,    13,    18,    23,    20,    27,
     $     25,    22,    23,    22,    24,    23,    21,    25,    20,
     $     26,    22,    21,    22,    14,    20,    14,    20,    20/
      DATA IWD005/    20,    21,    19,    18,    21,    18,    15,
     $     20,    21,    13,    13,    20,    12,    33,    23,    18,
     $     21,    20,    17,    17,    14,    23,    20,    29,    20,
     $     21,    20,    14,     8,    14,    24,    20,    20,    10,
     $     20,    21,    20,    24,    25,    20,    14,    14,    16,
     $     26,    10,    26,    10,    22,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    10,    10,    24,
     $     26,    24,    18,    27,    20,    20,    21,    21,    19,
     $     18,    21,    22,     9,    17,    21,    17,    24,    22,
     $     22,    20,    22,    20,    20,    17,    22,    20,    26/
      DATA IWD006/    20,    19,    20,    14,    20,    14,    20,
     $     20,    20,    20,    20,    18,    20,    18,    14,    20,
     $     20,     9,     9,    19,     9,    31,    20,    19,    20,
     $     20,    14,    17,    11,    20,    16,    24,    18,    16,
     $     18,    14,     8,    14,    24,    20,    20,    24,    24,
     $     19,    20,    17,    24,    24,    25,    24,    24,    25,
     $     24,    24,    22,    26,    34,    10,    22,    21,    19,
     $     20,    20,    20,    22,    20,    20,    14,    20,    14,
     $     20,    20,    20,    20,    22,    20,    16,    16,    20,
     $     20,    24,    24,    20,    25,    20,    18,    20,    20/
      DATA IWD007/    24,    14,    14,     8,    20,    14,    20,
     $     22,    16,    20,    20,    20,    20,    20,    24,    20,
     $     27,    20,    22,    18,    20,    21,    20,    24,    22,
     $     11,    22,    20,    25,    23,    22,    22,    24,    22,
     $     21,    19,    19,    21,    20,    23,    22,    20,    20,
     $     14,    20,    14,    20,    20,    20,    23,    21,    20,
     $     19,    18,    18,    22,    23,    12,    20,    20,    23,
     $     20,    17,    18,    22,    19,    21,    20,    20,    22,
     $     18,    23,    23,    20,    20,    14,     8,    14,    24,
     $     20,    20,    10,    20,    21,    20,    24,    20,    20/
      DATA IWD008/    14,    14,    16,    26,    10,    26,    10,
     $     22,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    10,    10,    24,    26,    24,    18,    27,
     $     18,    21,    21,    21,    19,    18,    21,    22,     8,
     $     16,    21,    17,    24,    22,    22,    21,    22,    21,
     $     20,    16,    22,    18,    24,    20,    18,    20,    14,
     $     20,    14,    20,    20,    20,    19,    19,    18,    19,
     $     18,    12,    19,    19,     8,    10,    17,     8,    30,
     $     19,    19,    19,    19,    13,    17,    12,    19,    16,
     $     22,    17,    16,    17,    14,     8,    14,    24,    20/
      DATA IWD009/    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20/
      DATA IWD010/    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20,
     $     20,    20,    20,    20,    20,    20,    20,    20,    20/
      DATA IPT001/     1,     8,    19,    24,    28,    32,    38,
     $     43,    47,    55,    60,    73,    81,    86,    94,   109,
     $    116,   122,   129,   137,   139,   148,   153,   166,   187,
     $    220,   248,   267,   278,   278,   286,   295,   297,   298,
     $    310,   316,   324,   348,   377,   390,   395,   405,   415,
     $    421,   425,   433,   435,   440,   442,   459,   463,   477,
     $    492,   497,   514,   537,   541,   570,   593,   603,   615,
     $    618,   622,   625,   635,   648,   654,   675,   693,   707,
     $    715,   721,   742,   748,   750,   760,   766,   770,   778,
     $    784,   805,   817,   840,   854,   874,   878,   888,   892/
      DATA IPT002/   900,   904,   909,   915,   921,   925,   930,
     $    935,   939,   943,   959,   975,   989,  1005,  1022,  1029,
     $   1050,  1059,  1066,  1076,  1082,  1084,  1100,  1109,  1126,
     $   1142,  1158,  1165,  1182,  1189,  1198,  1202,  1210,  1214,
     $   1222,  1228,  1237,  1239,  1248,  1254,  1263,  1264,  1276,
     $   1282,  1290,  1328,  1357,  1403,  1408,  1426,  1444,  1450,
     $   1454,  1461,  1463,  1468,  1470,  1507,  1515,  1556,  1599,
     $   1608,  1642,  1687,  1713,  1770,  1815,  1825,  1837,  1840,
     $   1844,  1847,  1876,  1928,  1940,  1979,  2009,  2035,  2051,
     $   2065,  2100,  2118,  2126,  2143,  2161,  2171,  2191,  2205/
      DATA IPT003/  2246,  2270,  2329,  2367,  2399,  2411,  2430,
     $   2440,  2456,  2470,  2484,  2496,  2504,  2508,  2516,  2523,
     $   2530,  2534,  2569,  2597,  2623,  2653,  2681,  2699,  2753,
     $   2774,  2787,  2808,  2826,  2834,  2868,  2889,  2922,  2952,
     $   2980,  2998,  3028,  3041,  3062,  3072,  3088,  3102,  3119,
     $   3131,  3168,  3170,  3207,  3229,  3238,  3290,  3296,  3317,
     $   3321,  3327,  3335,  3341,  3347,  3370,  3372,  3378,  3382,
     $   3390,  3396,  3402,  3423,  3429,  3441,  3448,  3452,  3469,
     $   3488,  3492,  3508,  3524,  3533,  3542,  3550,  3554,  3562,
     $   3569,  3576,  3580,  3602,  3630,  3645,  3668,  3685,  3706/
      DATA IPT004/  3723,  3749,  3757,  3773,  3780,  3798,  3810,
     $   3836,  3853,  3863,  3881,  3898,  3904,  3919,  3939,  3951,
     $   3969,  3990,  3999,  4008,  4045,  4047,  4084,  4106,  4115,
     $   4116,  4129,  4135,  4143,  4180,  4209,  4255,  4260,  4278,
     $   4296,  4302,  4306,  4313,  4315,  4320,  4322,  4361,  4372,
     $   4410,  4456,  4463,  4497,  4540,  4565,  4622,  4665,  4674,
     $   4686,  4689,  4693,  4696,  4727,  4779,  4791,  4826,  4858,
     $   4884,  4900,  4914,  4952,  4970,  4978,  4996,  5014,  5024,
     $   5044,  5058,  5097,  5119,  5175,  5210,  5243,  5255,  5276,
     $   5286,  5302,  5316,  5330,  5342,  5350,  5354,  5362,  5369/
      DATA IPT005/  5376,  5380,  5415,  5446,  5469,  5506,  5530,
     $   5562,  5601,  5627,  5650,  5679,  5707,  5722,  5768,  5801,
     $   5830,  5867,  5895,  5918,  5944,  5959,  5992,  6016,  6053,
     $   6091,  6128,  6154,  6191,  6193,  6230,  6252,  6261,  6262,
     $   6274,  6280,  6288,  6334,  6363,  6409,  6414,  6436,  6458,
     $   6488,  6500,  6520,  6526,  6540,  6546,  6583,  6593,  6623,
     $   6663,  6676,  6720,  6775,  6784,  6847,  6893,  6903,  6915,
     $   6918,  6930,  6933,  6962,  7014,  7028,  7066,  7102,  7130,
     $   7149,  7164,  7206,  7222,  7228,  7246,  7262,  7272,  7290,
     $   7304,  7342,  7365,  7409,  7437,  7478,  7489,  7511,  7521/
      DATA IPT006/  7539,  7551,  7564,  7578,  7586,  7590,  7598,
     $   7605,  7612,  7616,  7648,  7680,  7710,  7742,  7776,  7795,
     $   7839,  7860,  7880,  7900,  7916,  7922,  7958,  7979,  8013,
     $   8045,  8077,  8094,  8136,  8148,  8169,  8179,  8197,  8209,
     $   8222,  8236,  8273,  8275,  8312,  8334,  8343,  8357,  8360,
     $   8363,  8404,  8414,  8436,  8443,  8450,  8470,  8500,  8547,
     $   8572,  8578,  8584,  8588,  8600,  8614,  8619,  8626,  8643,
     $   8682,  8690,  8698,  8706,  8748,  8756,  8764,  8772,  8776,
     $   8784,  8791,  8798,  8802,  8810,  8818,  8826,  8868,  8892,
     $   8900,  8906,  8911,  8916,  8927,  8973,  8985,  8991,  8997/
      DATA IPT007/  9002,  9024,  9027,  9030,  9032,  9069,  9082,
     $   9092,  9129,  9174,  9181,  9188,  9195,  9202,  9210,  9232,
     $   9241,  9293,  9305,  9344,  9354,  9364,  9380,  9392,  9410,
     $   9459,  9467,  9485,  9495,  9515,  9529,  9553,  9594,  9608,
     $   9632,  9647,  9659,  9687,  9728,  9742,  9776,  9814,  9823,
     $   9832,  9840,  9844,  9852,  9859,  9866,  9870,  9906,  9957,
     $   9981, 10022, 10050, 10079, 10107, 10148, 10161, 10185, 10204,
     $  10227, 10246, 10286, 10315, 10331, 10359, 10390, 10402, 10430,
     $  10464, 10484, 10514, 10554, 10563, 10572, 10609, 10611, 10648,
     $  10670, 10679, 10680, 10692, 10698, 10706, 10730, 10759, 10772/
      DATA IPT008/ 10777, 10787, 10797, 10803, 10807, 10815, 10817,
     $  10822, 10824, 10841, 10845, 10859, 10874, 10879, 10896, 10919,
     $  10923, 10952, 10975, 10985, 10997, 11000, 11004, 11007, 11036,
     $  11088, 11094, 11115, 11133, 11147, 11155, 11161, 11182, 11188,
     $  11190, 11200, 11206, 11210, 11218, 11224, 11245, 11257, 11280,
     $  11294, 11314, 11318, 11328, 11332, 11340, 11344, 11349, 11355,
     $  11363, 11367, 11375, 11382, 11389, 11393, 11409, 11425, 11439,
     $  11455, 11472, 11479, 11500, 11509, 11516, 11526, 11532, 11534,
     $  11550, 11559, 11576, 11592, 11608, 11615, 11632, 11639, 11648,
     $  11652, 11660, 11664, 11672, 11678, 11715, 11717, 11754, 11776/
      DATA IPT009/ 11785, 11786, 11797, 11803, 11813, 11825, 11839,
     $  11852, 11857, 11863, 11869, 11877, 11883, 11887, 11891, 11895,
     $  11898, 11910, 11917, 11927, 11939, 11946, 11957, 11969, 11976,
     $  11995, 12006, 12012, 12019, 12024, 12030, 12035, 12045, 12058,
     $  12066, 12079, 12089, 12098, 12106, 12112, 12123, 12130, 12138,
     $  12145, 12151, 12156, 12162, 12169, 12180, 12188, 12201, 12211,
     $  12225, 12231, 12239, 12244, 12251, 12260, 12269, 12277, 12283,
     $  12287, 12292, 12299, 12306, 12310, 12322, 12333, 12341, 12353,
     $  12364, 12371, 12385, 12392, 12401, 12409, 12416, 12423, 12434,
     $  12442, 12453, 12465, 12477, 12483, 12492, 12499, 12508, 12513/
      DATA IPT010/ 12520, 12525, 12535, 12541, 12550, 12556, 12565,
     $  12571,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0,
     $      0,     0,     0,     0,     0,     0,     0,     0,     0/
C
C
	DIMENSION OLDX(6),OLDY(6)	! LAST CHARACTER BUFFER
	DIMENSION OX(6),OY(6)		! WORKING BUFFER
	LOGICAL LENGTH
	DATA IF/1/,IFX/0/		! DEFAULT FONT
C
	N=NN				! NUMBER OF CHARACTERS
	AA=A				! PLOTTING ANGLE
	SI=SIN(AA*0.0174532)
	CO=COS(AA*0.0174532)
	LENGTH=.TRUE.			! PLOT (TRUE) OR LENGTH ONLY
	AL=0.0				! PLOTTED LENGTH
	ISS=IS				! CENTERING FLAG
	IF (ISS.EQ.-3) LENGTH=.FALSE.
	IF (ISS.GT.-1) THEN		! SAVE CURRENT POSITION ARRAY
		DO 3 IP=1,6
			OX(IP)=OLDX(IP)
			OY(IP)=OLDY(IP)
3		CONTINUE
		LENGTH=.FALSE.
	ENDIF
1100	X1=X				! LOWER LEFT CORNER
	Y1=Y
	IF (ISS.EQ.0) THEN		! CENTERED
		X1=X-AL/2.
		Y2=Y-S/2.
	ENDIF
	IF (ISS.EQ.1) X1=X-AL		! LOWER RIGHT CORNER
	AL=0.0
	IF (X.GT.998.0.OR.Y.GT.998.0) THEN
		IF (X.LT.998.0) THEN
			DO 5 IP=1,6
				OLDX(IP)=OLDX(IP)+X1
5			CONTINUE
		ENDIF
		IF (Y.LT.998.0) THEN
			DO 8 IP=1,6
				OLDY(IP)=OLDY(IP)+Y1
8			CONTINUE
		ENDIF
	ELSE
		DO 10 IP=1,6
			OLDX(IP)=X1
			OLDY(IP)=Y1
10		CONTINUE
	ENDIF
	IF (LENGTH.AND.N.LT.0) CALL PLOT(OLDX(6),OLDY(6),2)	! PLOT TO START
	SS=S/21.		! SCALE FACTOR
	SSS=1.			! SUB/SUPERSCRIPT SCALING
	ISUB=0			! SUB/SUPERSCRIPT Y OFFSET
	I=0			! CHARACTER COUNTER
50	I=I+1
	IF (I.GT.IABS(N)) GOTO 1000		! END OF STRING COUNT
		IFIRST=1
		CALL PXPCGT(T,I,ICC)		! GET ITH ASCII CHARACTER
		IF (ICC.EQ.0.AND.I.GT.1) GOTO 1000	! END OF STRING REACHED
		IF (ICC.EQ.124) THEN			! CONTROL CHARACTER (|)
			I=I+1
			IF (I.GT.IABS(N)) GOTO 1000
			CALL PXPCGT(T,I,ICC)		! GET ITH ASCII CHARACTER
			IF (ICC.EQ.124) GOTO 60		! PLOT CONTROL CHARACTER
			IF (ICC.GT.47.AND.ICC.LT.58) THEN	! NEW FONT COMMAND
				IFX=0
				IF=ICC-47			! FONT NUMBER
				GOTO 100
			ENDIF
			GOTO (46,47,48,49,45,51,52,53,54,55,56,57) ICC-86 ! SPECIAL FUNCTIONS
			I=I-1			! COMMAND ERROR -- PLOT CHAR
			GOTO 50
46				CONTINUE	! FORWARD 1 SPACE (W)
				IW=20
47				CONTINUE	! FORWARD 1/2 SPACE (X)
				IW=10
				GOTO 90
48				CONTINUE	! BACKUP 1 SPACE (Y)
				IW=-20
				GOTO 90
49				CONTINUE	! BACKUP 1/2 SPACE (Z)
				IW=-10
				GOTO 90
45				CONTINUE	! RESET TO DEFAULTS ([)
				IF=1		! DEFAULT FONT
				IFX=0
				SS=S/21.	! SCALE FACTOR
				SSS=1.		! SUB/SUPERSCRIPT SCALING
				ISUB=0		! SUB/SUPERSCRIPT Y OFFSET
				GOTO 50
51				CONTINUE	! SUBSCRIPT (\)
				ISUB=ISUB-10
				SSS=.7*SSS
				GOTO 50
52				CONTINUE	! BACKSPACE (])
				DO 1252 IP=1,5
					IK=6-IP
					OLDX(IK+1)=OLDX(IK)
					OLDY(IK+1)=OLDY(IK)
1252				CONTINUE
				GOTO 50
53				CONTINUE	! SUPERSCRIPT (^)
				ISUB=ISUB+15
				SSS=.7*SSS
				GOTO 50
54				CONTINUE	! UN SUB/SUPERSCRIPT (_)
				ISUB=0
				SSS=SSS/.7
				IF (SSS.GT.1.0) SSS=1.0
				GOTO 50
55				CONTINUE	! SCALE CHANGE (`)
				I=I+1
				IF (I.GT.IABS(N)) GOTO 1000
				CALL PXPCGT(T,I,ICC)		! GET ITH ASCII CHARACTER
				SPLUS=2.
				IF (ICC.EQ.45) SPLUS=0.75
				SSS=SSS*SPLUS
				GOTO 50
56				CONTINUE	! OVER-PRINT (a)
				SSS=SSS*.7
				ISUB=ISUB+30
				GOTO 50
57				CONTINUE	! UNDER-PRINT (b)
				SSS=SSS*.7
				ISUB=ISUB-30
				GOTO 50
		ENDIF
60		CONTINUE			! CHECK FOR VALUE IN FONT
		IFU=IF
		IF (ICC.LT.IFMIN(IF).OR.ICC.GT.IFMAX(IF)) IFU=1
		IXOFF=10			! OFFSET
		IYOFF=11
		IF (ICC.LT.32) THEN		! DIFFERENT SYMBOL OFFSET
			IXOFF=32
			IYOFF=32
		ENDIF
		IC=ICC-IFMIN(IFU)+IFOFF(IFU)
		IL=IPNT(IC)			! STARTING INDEX
		IW=IBITS(IWID(IC),0,7)		! CHARACTER WIDTH
C		IF (IFX.NE.0) IW=IFX		! FIXED CHARACTER WIDTH
		IF (IL.EQ.0) GOTO 90		! NO PLOTING INFO
70		CONTINUE
		IY=IBITS(IFNT(IL),0,6)
		IX=IBITS(IFNT(IL),7,6)
		IF (IFX.NE.0.AND.(ICC.EQ.73.OR.ICC.EQ.76)) IX=IX+10
		IPEN=IBITS(IFNT(IL),13,2)
		XX=SS*SSS*(IX-IXOFF)
		Y1=SS*SSS*(IY-IYOFF+ISUB)
		X1=XX*CO-Y1*SI+OLDX(6)
		Y1=XX*SI+Y1*CO+OLDY(6)
		IP=IPEN
		IF (IPEN.EQ.0) GOTO 90		! ERR, END OF CHARACTER
		IF (IP.EQ.1) IP=2		! LAST LINE OF CHARACTER
CCC		IF (IFIRST.EQ.1.AND.IS.GT.0) IP=3
		IF (LENGTH) CALL PLOT(X1,Y1,IP)
		IL=IL+1
		IFIRST=IFIRST+1
		IF (IPEN.NE.1) GOTO 70
90		XX=SS*SSS*IW			! END OF CHARACTER
		AL=AL+SS*SSS*IW
		DO 95 IK=1,5
			OLDX(IK)=OLDX(IK+1)
			OLDY(IK)=OLDY(IK+1)
95		CONTINUE
		OLDX(6)=XX*CO+OLDX(6)
		OLDY(6)=XX*SI+OLDY(6)
100	GOTO 50
1000	IF (.NOT.LENGTH) THEN	! FINISHED LENGTH-ONLY PASS
		LENGTH=.TRUE.
		IF (ISS.EQ.-3) THEN	! RETURN END POSITION
			X=OLDX(6)
			Y=OLDY(6)
		ENDIF
		DO 1003 IP=1,6	! RESTORE OLD POSITION
			OLDX(IP)=OX(IP)
			OLDY(IP)=OY(IP)
1003		CONTINUE
		IF (ISS.EQ.0.OR.ISS.EQ.1) GOTO 1100
	ELSE
		IF (ISS.EQ.-2) THEN	! RETURN END POSITION
			X=OLDX(6)
			Y=OLDY(6)
		ENDIF
	ENDIF
	SYMS=AL
	RETURN
	END
